#
# spec file for package openSUSE-release-tools
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global __provides_exclude ^perl.*
%define source_dir openSUSE-release-tools
%define announcer_filename factory-package-news
%define services osrt-slsa.target osrt-relpkggen@.timer osrt-relpkggen@.service osrt-pkglistgen@.timer osrt-pkglistgen@.service
Name:           openSUSE-release-tools
Version:        20250217.651e507
Release:        1.1
Summary:        Tools to aid in staging and release work for openSUSE/SUSE
License:        GPL-2.0-or-later AND MIT
Group:          Development/Tools/Other
URL:            https://github.com/openSUSE/openSUSE-release-tools
Source:         %{name}-%{version}.tar.xz
BuildArch:      noarch
# Requires sr#704176
BuildRequires:  osc >= 0.165.1
BuildRequires:  python3-PyYAML
BuildRequires:  python3-cmdln
BuildRequires:  python3-colorama
BuildRequires:  python3-lxml
BuildRequires:  python3-osc
BuildRequires:  python3-pycurl
BuildRequires:  python3-python-dateutil
BuildRequires:  python3-pyxdg

# Spec related requirements.
%if 0%{?is_opensuse}
BuildRequires:  apache-rpm-macros
%else
%define apache_sysconfdir %{_sysconfdir}/apache2
%endif
BuildRequires:  apache2-devel
BuildRequires:  rsyslog
BuildRequires:  systemd-rpm-macros

BuildRequires:  sysuser-shadow
BuildRequires:  sysuser-tools

Requires:       python3-PyYAML
Requires:       python3-cmdln
Requires:       python3-colorama
Requires:       python3-lxml
# issue-diff.py, legal-auto.py, and openqa-maintenance.py
Requires:       python3-pycurl
Requires:       python3-python-dateutil
Requires:       python3-pyxdg
Requires:       python3-requests
# typing extensions are needed on SLE & Leap
%if 0%{?suse_version} <= 1500
Requires:       python3-typing_extensions
%endif

# Spec related requirements.
Requires:       osclib = %{version}

# no longer supported
Obsoletes:      osc-plugin-check_dups < 20210528
# vdelreq is no longer needed/supported; delete requests are handled immediately again
Obsoletes:      osc-plugin-vdelreq < 20210528

# Avoid needlessly building on s390x and such in various repos.
# Must include noarch for older systems even though it makes no sense due to
# https://bugzilla.redhat.com/show_bug.cgi?id=1298668.
ExclusiveArch:  noarch x86_64

%description
Tools to aid in staging and release work for openSUSE/SUSE

The toolset consists of a variety of stand-alone scripts, review bots, osc
plugins, and automation aids.

%package abichecker
Summary:        ABI review bot
Group:          Development/Tools/Other
Requires:       osclib = %{version}
BuildArch:      noarch

%description abichecker
ABI review bot for checking OBS requests.

%package announcer
Summary:        Release announcer
Group:          Development/Tools/Other
BuildArch:      noarch
# TODO Update requirements.

%description announcer
OBS product release announcer for generating email diffs summaries.

%package check-source
Summary:        Check source review bot
Group:          Development/Tools/Other
Requires:       obs-scm-bridge
Requires:       obs-service-download_files
Requires:       obs-service-source_validator
Requires:       osclib = %{version}
Requires:       perl-Text-Diff
Requires(pre):  shadow
BuildArch:      noarch

%description check-source
Check source review bot that performs basic source analysis and assigns reviews.

%package docker-publisher
Summary:        Docker image publishing bot
Group:          Development/Tools/Other
BuildArch:      noarch
Requires:       python3-lxml
Requires:       python3-requests
Requires(pre):  shadow

%description docker-publisher
A docker image publishing bot which regularly pushes built docker images from
several sources (Repo, URL) to several destinations (git, Docker registries)

%package maintenance
Summary:        Maintenance related services
Group:          Development/Tools/Other
# TODO Update requirements.
Requires:       osclib = %{version}
Requires(pre):  shadow
BuildArch:      noarch

%description maintenance
Maintenance related services like incident check.

%package metrics
Summary:        Ingest relevant data to generate insightful metrics
Group:          Development/Tools/Other
# TODO Update requirements.
Requires:       osclib = %{version}
Requires(pre):  shadow
Suggests:       grafana
BuildArch:      noarch
%if 0%{?suse_version} > 1500
Requires:       influxdb
Requires:       python3-influxdb
Requires:       telegraf
%else
Suggests:       influxdb
Suggests:       python3-influxdb
Suggests:       telegraf
%endif

%description metrics
Ingest relevant OBS and annotation data to generate insightful metrics.

%package metrics-access
Summary:        Ingest access logs to generate metrics
Group:          Development/Tools/Other
Requires:       %{name}-metrics = %{version}
# Used to stream log files.
Requires:       curl
Requires:       php > 7
# Used to install influxdb/influxdb-php.
Requires:       php-composer
# pgrep used in aggregate.php
Requires:       procps
# xzcat for decompressing log files.
Requires:       xz
BuildArch:      noarch

%description metrics-access
Ingest download.o.o Apache access logs and generate metrics.

%package origin-manager
Summary:        Package origin management tools
Group:          Development/Tools/Other
Requires:       osc-plugin-origin = %{version}
Requires:       osclib = %{version}
Requires(pre):  shadow
BuildArch:      noarch

%description origin-manager
Tools for managing the origin of package sources and keeping them in sync.

%package publish-distro
Summary:        Tool for publishing ftp-stage to ftp-prod
Group:          Development/Tools/Other
Requires:       rsync
Requires(pre):  shadow
BuildArch:      noarch

%description publish-distro
publish_distro tool and related configuration in publish_distro to rsync
content from OBS to ftp-stage/ftp-prod on pontifex host.

%package repo-checker
Summary:        Repository checker service
Group:          Development/Tools/Other
# write_repo_susetags_file.pl
Requires:       build
# TODO Update requirements.
Requires:       osclib = %{version}
Requires:       perl-XML-Simple
Requires(pre):  shadow
BuildArch:      noarch

%description repo-checker
Repository checker service that inspects built RPMs from stagings.

%package staging-bot
Summary:        Staging bot services
Group:          Development/Tools/Other
# devel-project.py
Requires:       %{name} = %{version}
Requires:       osc-plugin-staging = %{version}
Requires(pre):  shadow
BuildArch:      noarch

%description staging-bot
Staging bot services and system user.

%package pkglistgen
Summary:        Generates package lists in 000product
Group:          Development/Tools/Other
# for compressing the .packages files in 000update-repos
Requires:       %{_bindir}/xz
Requires:       obs-service-product_converter
Requires:       osclib = %{version}
Requires:       python3-requests
Requires:       python3-solv
Requires:       zstd
%if 0%{?suse_version} > 1500
# slfo-packagelist-uploader.py
Requires:       python3-GitPython
%endif
# we use the same user as repo-checker
PreReq:         openSUSE-release-tools-repo-checker
BuildArch:      noarch

%description pkglistgen
Generates package lists based on 000package-groups and puts them
in 000product, resp 000release-packages

%package slsa-build-service
Summary:        Build service
Group:          Development/Tools/Other
# TODO Update requirements, but for now base deps.
Requires:       %{name} = %{version}
Requires:       openSUSE-release-tools-pkglistgen
%sysusers_requires
Recommends:     logrotate
BuildArch:      noarch

%description slsa-build-service
Service to run repo-checker and pkglistgen.

%package -n osclib
Summary:        Supplemental osc libraries
Group:          Development/Tools/Other
# TODO Update requirements, but for now base deps.
Requires:       %{name} = %{version}
Requires:       osc >= 0.165.1
Requires:       python3-osc
BuildArch:      noarch

%description -n osclib
Supplemental osc libraries utilized by release tools.

%package -n osc-plugin-cycle
Summary:        OSC plugin for cycle visualization
Group:          Development/Tools/Other
Requires:       osc >= 0.165.1
Requires:       osclib = %{version}
BuildArch:      noarch

%description -n osc-plugin-cycle
OSC plugin for cycle visualization, see `osc cycle --help`.

%package -n osc-plugin-pcheck
Summary:        OSC plugin to support devel project maintainers
Group:          Development/Tools/Other
Requires:       osc >= 0.165.1
Requires:       osclib = %{version}
BuildArch:      noarch

%description -n osc-plugin-pcheck
OSC plugin for devel project maintainers. Helps them check the submit
state (done, todo, missing links) of a devel project to the parent project.
See 'osc pcheck --help'

%package -n osc-plugin-origin
Summary:        OSC plugin for origin management
Group:          Development/Tools/Other
Requires:       osc >= 0.165.1
Requires:       osclib = %{version}
BuildArch:      noarch

%description -n osc-plugin-origin
OSC plugin for for working with origin information, see `osc origin --help`.

%package -n osc-plugin-staging
Summary:        OSC plugin for the staging workflow
Group:          Development/Tools/Other
# devel-project.py needs 0.160.0 for get_request_list(withfullhistory) param.
Requires:       osc >= 0.160.0
Requires:       osclib = %{version}
BuildArch:      noarch

%description -n osc-plugin-staging
OSC plugin for the staging workflow, see `osc staging --help`.

%prep
%setup -q
# slfo-packagelist-uploader requires python-GitPython but 15.6 providing
# python311-GitPython only, therefore do not ship slfo-packagelist-uploader
# in 15.6 since python3-GitPython is not available
%if 0%{?suse_version} <= 1500
rm slfo-packagelist-uploader.py
%endif

%build
%make_build
%sysusers_generate_pre slsa/osrt-slsa-user.conf %{name} %{name}.conf

%install
%make_install \
  grafana_provisioning_dir="%{_sysconfdir}/grafana/provisioning" \
  oscplugindir="%{osc_plugin_dir}" \
  VERSION="%{version}"

install -Dpm0644 slsa/osrt-slsa-user.conf %{buildroot}%{_sysusersdir}/%{name}.conf

%pre -f %{name}.pre
%service_add_pre %{name}.service

%pre announcer
getent passwd osrt-announcer > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-announcer" osrt-announcer
exit 0

%pre check-source
getent passwd osrt-check-source > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-check-source" osrt-check-source
exit 0

%pre docker-publisher
getent passwd osrt-docker-publisher > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-docker-publisher" osrt-docker-publisher
exit 0

%pre maintenance
getent passwd osrt-maintenance > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-maintenance" osrt-maintenance
exit 0

%pre metrics
getent passwd osrt-metrics > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-metrics" osrt-metrics
exit 0

%postun metrics
%systemd_postun osrt-metrics-telegraf.service
# If grafana-server.service is enabled then restart it to load new dashboards.
if [ -x %{_bindir}/systemctl ] && %{_bindir}/systemctl is-enabled grafana-server ; then
  %{_bindir}/systemctl try-restart --no-block grafana-server
fi

%pre origin-manager
getent passwd osrt-origin-manager > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-origin-manager" osrt-origin-manager
exit 0

%pre repo-checker
getent passwd osrt-repo-checker > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-repo-checker" osrt-repo-checker
exit 0

%pre slsa-build-service
%service_add_pre %{services}

%post slsa-build-service
%service_add_post %{services}

%preun slsa-build-service
%service_del_preun %{services}

%postun slsa-build-service
%service_del_postun_with_restart %{services}

%pre staging-bot
getent passwd osrt-staging-bot > /dev/null || \
  useradd -r -m -s /sbin/nologin -c "user for openSUSE-release-tools-staging-bot" osrt-staging-bot
exit 0

%files
%doc README.md
%{_bindir}/osrt-biarchtool
%{_bindir}/osrt-bugowner
%{_bindir}/osrt-build-fail-reminder
%{_bindir}/osrt-checknewer
%{_bindir}/osrt-check_bugowner
%{_bindir}/osrt-check_tags_in_requests
%{_bindir}/osrt-compare_pkglist
%{_bindir}/osrt-container_cleaner
%{_bindir}/osrt-deptool
%{_bindir}/osrt-fcc_submitter
%{_bindir}/osrt-issue-diff
%{_bindir}/osrt-legal-auto
%{_bindir}/osrt-openqa-maintenance
%{_bindir}/osrt-repo2fileprovides
%{_bindir}/osrt-requestfinder
%{_bindir}/osrt-totest-manager
%{_datadir}/%{source_dir}
%exclude %{_datadir}/%{source_dir}/abichecker
%exclude %{_datadir}/%{source_dir}/%{announcer_filename}
%exclude %{_datadir}/%{source_dir}/check_maintenance_incidents.py
%exclude %{_datadir}/%{source_dir}/check_source.py
%exclude %{_datadir}/%{source_dir}/devel-project.py
%exclude %{_datadir}/%{source_dir}/docker_publisher.py
%exclude %{_datadir}/%{source_dir}/docker_registry.py
%exclude %{_datadir}/%{source_dir}/metrics
%exclude %{_datadir}/%{source_dir}/metrics.py
%exclude %{_datadir}/%{source_dir}/metrics_release.py
%exclude %{_datadir}/%{source_dir}/origin-manager.py
%exclude %{_bindir}/osrt-staging-report
%exclude %{_datadir}/%{source_dir}/pkglistgen
%exclude %{_datadir}/%{source_dir}/pkglistgen.py
%exclude %{_datadir}/%{source_dir}/maintenance-installcheck.py
%exclude %{_datadir}/%{source_dir}/project-installcheck.py
%exclude %{_datadir}/%{source_dir}/suppkg_rebuild.py
%exclude %{_datadir}/%{source_dir}/skippkg-finder.py
%exclude %{_datadir}/%{source_dir}/slfo-packagelist-uploader.py
%exclude %{_datadir}/%{source_dir}/osclib
%exclude %{_datadir}/%{source_dir}/osc-cycle.py
%exclude %{_datadir}/%{source_dir}/osc-origin.py
%exclude %{_datadir}/%{source_dir}/osc-pcheck.py
%exclude %{_datadir}/%{source_dir}/osc-staging.py
%exclude %{_datadir}/%{source_dir}/publish_distro
%exclude %{_datadir}/%{source_dir}/findfileconflicts
%exclude %{_datadir}/%{source_dir}/generate-release-packages
%exclude %{_datadir}/%{source_dir}/verify-build-and-generatelists
%exclude %{_datadir}/%{source_dir}/verify-repo-built-successful.py
%exclude %{_datadir}/%{source_dir}/write_repo_susetags_file.pl
%dir %{_sysconfdir}/openSUSE-release-tools

%files abichecker
%{apache_sysconfdir}/vhosts.d/opensuse-abi-checker.conf.in
%{_datadir}/%{source_dir}/abichecker
%{_tmpfilesdir}/opensuse-abi-checker.conf

%files announcer
%doc %{announcer_filename}/README.asciidoc
%{_bindir}/osrt-announcer
%{apache_sysconfdir}/conf.d/%{announcer_filename}.conf.in
%{_datadir}/%{source_dir}/%{announcer_filename}
%config(noreplace) %{_sysconfdir}/openSUSE-release-tools/announcer
%config(noreplace) %{_sysconfdir}/rsyslog.d/%{announcer_filename}.conf

%files check-source
%{_bindir}/osrt-check_source
%if 0%{?suse_version} > 1500
%{_bindir}/osrt-slfo-packagelist-uploader
%{_datadir}/%{source_dir}/slfo-packagelist-uploader.py
%endif
%{_datadir}/%{source_dir}/check_source.py

%files docker-publisher
%{_bindir}/osrt-docker_publisher
%{_datadir}/%{source_dir}/docker_publisher.py
%{_datadir}/%{source_dir}/docker_registry.py
%{_unitdir}/osrt-docker-publisher.service
%{_unitdir}/osrt-docker-publisher.timer

%files slsa-build-service
%{_bindir}/osrt-generate-release-packages
%{_bindir}/osrt-verify-build-and-generatelists
%{_datadir}/%{source_dir}/generate-release-packages
%{_datadir}/%{source_dir}/verify-build-and-generatelists
%{_datadir}/%{source_dir}/verify-repo-built-successful.py
%{_sysconfdir}/openSUSE-release-tools/ibsapi
%{_sysusersdir}/%{name}.conf
%{_unitdir}/osrt-pkglistgen@.service
%{_unitdir}/osrt-pkglistgen@.timer
%{_unitdir}/osrt-relpkggen@.service
%{_unitdir}/osrt-relpkggen@.timer
%{_unitdir}/osrt-slsa.target
%config(noreplace) %attr(0640,osrt-slsa,osrt-slsa) %{_sysconfdir}/openSUSE-release-tools/oscrc
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%dir %attr(755,osrt-slsa,osrt-slsa) %{_localstatedir}/log/openSUSE-release-tools/
%dir %attr(750,osrt-slsa,osrt-slsa) %{_sharedstatedir}/osrt-slsa
%dir %attr(750,osrt-slsa,osrt-slsa) %{_sharedstatedir}/osrt-slsa/pkglistgen
%dir %attr(750,osrt-slsa,osrt-slsa) %{_sharedstatedir}/osrt-slsa/relpkggen

%files maintenance
%{_bindir}/osrt-check_maintenance_incidents
%{_datadir}/%{source_dir}/check_maintenance_incidents.py

%files metrics
%{_bindir}/osrt-metrics
%{_datadir}/%{source_dir}/metrics
%exclude %{_datadir}/%{source_dir}/metrics/access
%exclude %{_datadir}/%{source_dir}/metrics/grafana/access.json
%{_datadir}/%{source_dir}/metrics.py
%{_datadir}/%{source_dir}/metrics_release.py
# To avoid adding grafana as BuildRequires since it does not live in same repo.
%dir %{_sysconfdir}/grafana
%dir %{_sysconfdir}/grafana/provisioning
%dir %{_sysconfdir}/grafana/provisioning/dashboards
%dir %{_sysconfdir}/grafana/provisioning/datasources
%{_sysconfdir}/grafana/provisioning/dashboards/%{name}.yaml
%{_sysconfdir}/grafana/provisioning/datasources/%{name}.yaml
%{_unitdir}/osrt-metrics@.service
%{_unitdir}/osrt-metrics@.timer
%{_unitdir}/osrt-metrics-release@.service
%{_unitdir}/osrt-metrics-release@.timer
%{_unitdir}/osrt-metrics-telegraf.service

%files metrics-access
%{_bindir}/osrt-metrics-access-aggregate
%{_bindir}/osrt-metrics-access-ingest
%{_datadir}/%{source_dir}/metrics/access
%{_datadir}/%{source_dir}/metrics/grafana/access.json
%{_unitdir}/osrt-metrics-access.service
%{_unitdir}/osrt-metrics-access.timer

%files origin-manager
%{_bindir}/osrt-origin-manager
%{_datadir}/%{source_dir}/origin-manager.py

%files publish-distro
%{_bindir}/osrt-publish_distro
%{_datadir}/%{source_dir}/publish_distro

%files repo-checker
%{_bindir}/osrt-project-installcheck
%{_bindir}/osrt-staging-installcheck
%{_bindir}/osrt-findfileconflicts
%{_bindir}/osrt-maintenance-installcheck
%{_bindir}/osrt-write_repo_susetags_file
%{_datadir}/%{source_dir}/project-installcheck.py
%{_datadir}/%{source_dir}/findfileconflicts
%{_datadir}/%{source_dir}/write_repo_susetags_file.pl

%files staging-bot
%{_bindir}/osrt-devel-project
%{_bindir}/osrt-staging-report
%{_bindir}/osrt-suppkg_rebuild
%{_datadir}/%{source_dir}/devel-project.py
%{_datadir}/%{source_dir}/suppkg_rebuild.py

%files pkglistgen
%{_bindir}/osrt-pkglistgen
%{_bindir}/osrt-skippkg-finder
%{_datadir}/%{source_dir}/pkglistgen
%{_datadir}/%{source_dir}/pkglistgen.py
%{_datadir}/%{source_dir}/skippkg-finder.py

%files -n osclib
%{_datadir}/%{source_dir}/osclib
%{osc_plugin_dir}/osclib

%files -n osc-plugin-cycle
%{_datadir}/%{source_dir}/osc-cycle.py
%{osc_plugin_dir}/osc-cycle.py

%files -n osc-plugin-pcheck
%{_datadir}/%{source_dir}/osc-pcheck.py
%{osc_plugin_dir}/osc-pcheck.py

%files -n osc-plugin-origin
%{_datadir}/%{source_dir}/osc-origin.py
%{osc_plugin_dir}/osc-origin.py

%files -n osc-plugin-staging
%{_datadir}/%{source_dir}/osc-staging.py
%{osc_plugin_dir}/osc-staging.py

%changelog
* Mon Feb 17 2025 opensuse-releaseteam@opensuse.org
- Update to version 20250217.651e507:
  * gocd: slfo-stagings: Avoid stopping due to summary-staging.
* Mon Jan 27 2025 opensuse-releaseteam@opensuse.org
- Update to version 20250127.107d023:
  * Remove unecessary packagelist status report from SLFO 1.1
* Tue Jan 21 2025 opensuse-releaseteam@opensuse.org
- Update to version 20250121.32785d6:
  * devel-project: skip to update reminder repeatedly for particular projects
* Tue Jan 14 2025 opensuse-releaseteam@opensuse.org
- Update to version 20250114.0d374c1:
  * gocd: checkers.suse: Drop Marble pipelines and add SLFO checkers.
* Thu Jan  9 2025 opensuse-releaseteam@opensuse.org
- Update to version 20250109.0f73b87:
  * Adjust the staging configuration of ALP to maintenance needs
* Thu Dec 19 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241219.396fe69:
  * gocd: SLES 16.0: Remove duplicate pipeline.
* Mon Dec 16 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241216.9b8e794:
  * Look for images and sbom assets also in the iso/ folder
* Tue Dec 10 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241210.17af565:
  * Add Leap Micro 6.2 pipeline and publish_distro part
* Tue Dec 10 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241210.157bf13:
  * Make check_source ignore patchinfo using same rules as meta
* Wed Dec  4 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241204.ac74d91:
  * osclib/list_command.py: Allow overriding reviews filter from the command line.
* Thu Nov 21 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241121.c222573:
  * skippkg-finder: make skippkg-finder is able to support productcompose
* Fri Nov 15 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241115.b39e201:
  * Add Leap Micro 6.1 publish_distro configs
* Thu Nov 14 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241114.81e4759:
  * Add TTM config for Leap Micro 6.1
* Tue Nov 12 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241112.ec75d57:
  * Add Leap Micro 6.1 TTM / Pkglist workflows
* Tue Nov 12 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241112.83ca9a3:
  * gocd: slfo-stagings: slfo-stagings: fail on broken/failed products (SLFO:Main)
* Tue Nov 12 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241112.e15d46c:
  * gocd: slfo-stagings: properly escape comments
  * gocd: slfo-stagings: fail on broken/failed products
* Mon Nov 11 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241111.bc9b1c6:
  * Add 180 minutes timeout to SLFO product building pipelines.
* Mon Nov 11 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241111.0d5e755:
  * Fix makeurl() usage in is_repo_dirty()
* Thu Nov  7 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241107.88108f7:
  * osclib/list_command.py: Show details also for requests targeted to packages not in rings.
* Mon Nov  4 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241104.817ceac:
  * Added SUSE:SLFO prefix for Agama SLES 16
* Thu Oct 31 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241031.dcb6998:
  * pcheck: fix creation of submit requests
* Wed Oct 30 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241030.a6db18b:
  * cleanup_rings: Also keep the main package if a multibuild flavor is needed
  * cleanup_rings: Drop vagrant from the whitelist
  * osclib/memoize: Fix memoize without session=True
  * cleanup_rings: Make package_get_requiredby more memoize cache friendly
* Wed Oct 30 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241030.fca81c8:
  * gocd: Let the BCI role trigger BCI repo publishing
* Tue Oct 29 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241029.a883e20:
  * BCI repo pipeline for SP7
* Thu Oct 24 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241024.40192e1:
  * docker_publisher.py: Decouple opensuse/leap:15.6 from :15 and :latest
  * docker_publisher.py: Add option to remove archs from published images
* Thu Oct 24 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241024.d0f75c3:
  * gocd: Add pipelines for Micro 6.2.
* Fri Oct 18 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241018.97b7170:
  * Specify project and repository when release SLES16
* Wed Oct 16 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241016.841fa84:
  * Add new pipeline to release SLES to :PUBLISH
* Thu Oct 10 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241010.e8fa1ac:
  * Fix broken relase to :PUBLISH pipeline for SLES16
* Wed Oct  9 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241009.eb17b6b:
  * Add Agama installer in SLES release pipeline
* Tue Oct  8 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241008.8e13319:
  * Fix SLFO Snapshot pipeline
* Tue Oct  8 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241008.5a19ca5:
  * slfo-packagelist-uploader: Leap 16.0 should stay with main branch
* Mon Oct  7 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241007.0d331ee:
  * slfo-packagelist-uploader: add a 'branch' argument and use 1.1 branch for Leap 16.0
* Tue Oct  1 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241001.96def08:
  * gocd: Add SUSE:SLFO:1.1 pipelines.
* Tue Oct  1 2024 opensuse-releaseteam@opensuse.org
- Update to version 20241001.90ee9c2:
  * Use f-strings where possible
* Wed Sep 25 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240925.ba61d20:
  * gocd: to update weakremovers.inc via pkglistgen --only-update-weakremovers
  * pkglistgen: add an ability to update weakremovers.inc only
* Tue Sep 24 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240924.af10cfa:
  * Sync Agama Live ISO to OSD for all architectures
* Mon Sep 16 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240916.6615422:
  * gocd: slfo_stagings: Fix openSUSE-release-tools path.
* Sat Sep 14 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240914.29d8faa:
  * ttm: fix repo handling in is_snapshotable for Leap 16
* Fri Sep 13 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240913.f823b3d:
  * gocd: enable Leap 16.0 TTM
  * ttm: support Leap 16.0 development structure
* Thu Sep 12 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240912.637be99:
  * Enable update-repos for Leap 16.0
* Wed Sep 11 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240911.239a205:
  * gocd: slfo-stagings: Fix osc staging plugin setup.
* Wed Sep 11 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240911.44779bb:
  * gocd: run slfo-packagelist-uploader.py once a day at 4AM
  * Add slfo-packagelist-uploader.py for uploading SLFO packagelist to meta package
  * check_source: decline the request if target package exist in SLFO project
* Fri Sep  6 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240906.9054fef:
  * gocd: slfo-stagings: Fix syntax error.
* Fri Sep  6 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240906.f4cbf0b:
  * Upload project-installcheck result for Leap 16.0 Ring1 project
* Thu Sep  5 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240905.8e12150:
  * gocd: SUSE.SLFO.Main.Staging.Weekly.Freeze: Add osc staging bot oscrc.
* Wed Sep  4 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240904.da9a918:
  * gocd: slfo-stagings: Avoid busy waiting for 50 minutes, instead rely on scheduling from GoCD.
* Wed Sep  4 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240904.94791de:
  * docker_publisher.py: Add riscv64 to opensuse/tumbleweed
* Fri Aug 30 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240830.9384211:
  * Add state acceptable_by_lawyer
* Fri Aug 30 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240830.82f193b:
  * gocd: slfo-stagins: Minor syntax hot fix.
  * gocd: slfo-stagings: Freeze the Stagings each Sunday.
* Tue Aug 27 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240827.4114946:
  * gocd: reuse Leap as pipeline group and fix the format error
  * gocd: add checks for letter stagings in Leap 16.0
* Thu Aug 22 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240822.ca5f1d4:
  * Revert "legal-auto: Link to legal review via comment"
* Wed Aug 21 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240821.83ca4c0:
  * Add pipelines for SLFO Snapshot
  * Cleanup pipelines from Dolomite project
* Tue Aug 20 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240820.648451d:
  * legal-auto: Link to legal review via comment
* Tue Aug 20 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240820.6d79e25:
  * Check devel pkg maintainers in devel_project_review_needed
* Tue Aug 20 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240820.37e5c33:
  * pipeline: remove unneeded pipelines and add needed ones for Leap 16.0
* Fri Aug 16 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240816.83685f8:
  * dashboard: add openQA group for RISC-V
* Thu Aug 15 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240815.4962071:
  * metrics: Use https for openQA influxdb endpoint
* Thu Aug 15 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240815.bdf9527:
  * Work around test failure due to osc missing a fix
  * Add TTM for openSUSE:Factory:RISCV
* Thu Aug 15 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240815.d3ff6c6:
  * Adding openSUSE:Backports:SLE-15-SP7
  * Adding openSUSE:Backports:SLE-15-SP7 for install-check
* Tue Aug  6 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240806.376cbb3:
  * Use f-strings everywhere
  * Improve decline message (openSUSE/scm-staging#51)
* Tue Aug  6 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240806.82c53af:
  * Install docker-compose before running it
  * Add Leap 16.0 to the products regex
  * Add openSUSE Slowroll access metrics
  * pkglistgen: add sort reasonings in product_composer mode
  * pkglistgen: use f-strings in Group.tocompose()
* Tue Jul 30 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240730.7caf9a6:
  * osclib: freeze_command: handle 'product' repositories if used
  * osclib: project_has_repo: allow specifying the project to look at
* Tue Jul 30 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240730.5194d43:
  * gocd: sle15: Split publish pipelines
* Tue Jul 16 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240716.1a95eb1:
  * Monitor the release of Mimimal-VM images in SLES16
* Tue Jul 16 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240716.f3350aa:
  * Add Mimimal-VM images SLES16 release pipeline
* Wed Jul 10 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240710.b7e71a0:
  * gocd: changes to checkers, stagings and target for SLE15SP7
* Mon Jul  8 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240708.a906506:
  * Ignore patchinfo packages when checking for duplicated binaries
* Wed Jul  3 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240703.7797359:
  * Install tools explicitly to avoid busybox variants being picked
* Tue Jun 25 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240625.9e0d0ae:
  * Also consider spdx.json an iso for the purpose of openQA
* Mon Jun 24 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240624.c6ba819:
  * Leap 16 pkligsten use correct project
  * Leap 16 use pkglistgen with product-composer
* Thu Jun 20 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240620.31704ab:
  * Trigger publish at 0:50 and 12:50 every day
  * Automatic publishing of repos for LEAPM 6.0
* Tue Jun 18 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240618.3244aa8:
  * leap-micro55_appliances empty flavor list
  * leap156 commented version of flavors without net images
  * update publish_leap-micro60_appliances.config
* Tue Jun 18 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240618.f155c32:
  * Use tabs for indentation
  * add back openSUSE- prefix for LeapMicro 6.0 DVD media
  * update dvd filename for the leapmicro6.0 and new productcompose
  * use new 000productcompose only
  * Add pkglistgen for LeapMicro 6.0 000productcompose (maint workflow)
* Mon Jun 17 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240617.0b60495:
  * Switch CI to Leap 15.6
* Mon Jun 17 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240617.9b466e6:
  * slfo-stagings: add a timeout for Build.product, and do not run if repo is missing
  * verify-repo-built-successful: properly handle missing repositories
  * verify-repo-built-successful: mark project and repository args required
* Mon Jun 17 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240617.0928376:
  * cleanup_rings: whitelist 'devscripts'
* Mon Jun 17 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240617.abf142e:
  * verify-build-and-generatelists: Adjust to use --engine and --git-url for SLFO based products.
* Mon Jun 17 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240617.864dffa:
  * check_source: fix crash AttributeError: 'CheckSource' object has no attribute 'review_message'
* Thu Jun 13 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240613.9d63fee:
  * docker_publisher.py: Set 15.6 as latest
* Wed Jun 12 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240612.1679c72:
  * Remove codecoverage reporting
* Tue Jun 11 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240611.4d0b152:
  * Restore SLFO pipelines
* Tue Jun 11 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240611.dc9d44d:
  * gocd: slfo-stagings: wait for product to be built before enabling images
  * pkglistgen: cli: Explicitly enable product-composer instead of detecting directories.
* Tue Jun 11 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240611.7999809:
  * announcer: inject hostname in case fqdn cannot be found
* Mon Jun 10 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240610.fe74cce:
  * gocd: sl-micro: Decouple publishing to :PUBLISH project, from publishing to :ToTest.
* Wed Jun  5 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240605.63b8547:
  * Adjust the staging configuration of ALP to maintenance needs
* Tue Jun  4 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240604.2a36623:
  * Add SLES16.0 release pipelines
* Mon Jun  3 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240603.cba9d9b:
  * ttm: Print all failing packages before exiting
  * ttm: Use _result of the whole project instead of separately for each pkg
* Thu May 30 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240530.408936d:
  * gocd: Allow SLFO to have pkglists generated.
* Thu May 30 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240530.787cdb9:
  * gocd: slfo: RelPkgs are not generated anymore.
* Thu May 30 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240530.db1c4dc:
  * gocd: # must be followed by a parameter pattern or escaped by another #.
  * fix slfo stagings pipelines
* Wed May 29 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240529.3f58f3e:
  * pkglistgen: Support working on git branches
* Wed May 29 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240529.34947e2:
  * Leap 15: disable skippkg-finder for 15.6
* Mon May 27 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240527.d25c6ef:
  * gocd: micro: Wait also for kiwi images to finish building.
* Mon May 20 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240520.c5122b8:
  * gocd: Add SLFO Stagings pipeline.
* Fri May 17 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240517.d3deb40:
  * gocd: microos-stagings: Switch to SL-Micro 6.1.
  * gocd: Add SL-Micro 6.1 release pipelines.
  * gocd: SL-Micro.Images: Rename to SL-Micro6.0-Images.
* Thu May 16 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240516.b854784:
  * build-fail-reminder: don't escape characters
* Thu May 16 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240516.2c8dfbe:
  * add missing whitespace to please linter
  * fix typo in variable
  * Report errors if weakremover.inc status is inconsistent between staging and parent projects.
  * Don't abort if weakremover.inc don't exist on source project
* Wed May 15 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240515.123ba53:
  * SLCS has no images
* Wed May 15 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240515.f2820d7:
  * add SLCS 6.0
* Tue May 14 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240514.7b5a3b7:
  * pkglistgen: tool: decouple summary dict creation
* Tue May 14 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240514.ed30d28:
  * pkglistgen.py: Run productcomposer iif there's a *.productcompose.in file and a 000productcompose directory.
* Sat May 11 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240510.91ddc8a:
  * Use f-strings where possible
  * avoid shell usage
  * Make it optional to have a classic product-builder setup
  * write group support status
  * Add support for git project handling
  * Initial support for productcompose files
  * fix issue #3073
  * Add Leap 15.6 to access metrics
* Mon May  6 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240506.d9659f7:
  * Add codecov upload token
  * Use "not in" not "not X in"
* Mon Apr 29 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240429.94b4fd3:
  * gocd: microos: Stop releasing 000product.
  * Reapply "gocd: microos: Release both 000product and 000productcompose ."
* Thu Apr 11 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240411.58b3d97:
  * Revert "gocd: microos: Release both 000product and 000productcompose ."
* Fri Apr  5 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240405.6094898:
  * gocd: microos: Release both 000product and 000productcompose .
* Mon Mar 25 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240325.9d60e62:
  * gocd: Rename SLE-Micro to SL-Micro.
* Fri Mar 15 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240315.b086253:
  * gocd: sp/micro-targets: ensure the pipeline exits on failures
* Tue Mar 12 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240312.5f5f9db:
  * pkglistgen: Don't always regenerate .changes
* Mon Mar 11 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240311.a2edca4:
  * build-fail-reminder: send mail to the 'new' mailing list address
  * Create .changes files for reproducible builds
* Mon Mar  4 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240304.fd5b7a6:
  * Skip SLSA scripts in smoke-test.
  * Create SLSA user (osrt-slsa) on specfile like others osrt-* users and remove logrotate file
  * Packaging release and pkglistgen services (slsa-build-service)
  * Add a timeout for verify-repo-built-successful.py
  * Changes to avoid parallel execution issue on SLSA services
  * Change pkglistgen timer and relpkggen service
  * Change sleep location and improve log messages
  * Refactor SLSA services to avoid parallel execution
  * Fix SLSA systemd target
  * Add working dir for SLSA services
  * Add systemd target for SLSA
  * Add osrt-slsa dir
  * Change how verify-build-and-generatelists checks when run pkglistgen
  * Change SLSA systemd services
  * Add SLSA osrc config
  * Add relpkg support
  * Add log support to slsa-build-service
  * Add slsa-build-service
* Fri Feb 23 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240223.f941f9d:
  * Call rabbit-repoid.py for openSUSE:Slowroll
* Thu Feb 22 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240222.1748b20:
  * osclib/repochecks.py: Use libsolv for checking conflicts between packages
  * findfileconflicts: Quote version and release in YAML output
* Thu Feb 22 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240222.db4bd75:
  * Introduce new openSUSE|SUSE.Legal group and move pipelines into them
* Wed Feb 21 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240221.84b76ec:
  * Fix mkdir permissions argument
  * Add IPv4 and IPv6 handling in one file
* Tue Feb 20 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240220.9919e02:
  * Maintenance setup for Leap 15.6
* Thu Feb 15 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240215.54075b0:
  * Remove 15.4 and add 15.6 where missing
* Thu Feb 15 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240215.9e5a7f9:
  * ttm: Remove livecd size checks
* Wed Feb  7 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240207.602b3d2:
  * gocd: fix name of task
  * gocd: add rebuild pipeline for ALP
* Fri Feb  2 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240202.2e3b614:
  * Initial pipeline setup for Leap Micro 6.0
* Mon Jan 22 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240122.105eea5:
  * skippkg-finder: sort conditionals set
* Wed Jan 10 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240110.8329809:
  * check_source.py: Use correct function for getting maintainer of the devel pkg
  * Fix --osc-debug option with new osc
* Wed Jan  3 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240103.6ab1d35:
  * Slightly more useful info logging for source changes
  * use list comprehension instead of set comparison
  * publish bci repo right away on package set changes
  * Remove SP3 and SP4 BCI repos
* Wed Jan  3 2024 opensuse-releaseteam@opensuse.org
- Update to version 20240103.6478168:
  * Add timer to monitor release finished for SLE-Micro
  * Create Staging pipelines for ALP Dolomite 1.0
* Wed Dec 13 2023 opensuse-releaseteam@opensuse.org
- Update to version 20231213.02b3886:
  * Revert "factory-package-news.py: Compress data files with zstd"
* Tue Dec 12 2023 opensuse-releaseteam@opensuse.org
- Update to version 20231212.8e4cdc3:
  * factory-package-news.py: Port from pyzstd to zstandard
  * factory-package-news.py: Compress data files with zstd
* Tue Dec  5 2023 opensuse-releaseteam@opensuse.org
- Update to version 20231205.2925abf:
  * osclib/repomirror.py: Small cleanups
* Fri Dec  1 2023 opensuse-releaseteam@opensuse.org
- Update to version 20231201.6367d8f:
  * ttm: fix regexp to match 'livecd-x11' check
  * ttm: Allow bigger images for livecd-x11 on aarch64 since no CD will be used, but usb sticks
* Thu Nov 30 2023 opensuse-releaseteam@opensuse.org
- Update to version 20231130.29c388e:
  * Drop bs_mirrorfull
  * Rewrite bs_mirrorfull as osclib component
* Thu Nov 23 2023 opensuse-releaseteam@opensuse.org
- Update to version 20231123.24f3d6b:
  * Handle ZSTD compressed primary.xml.zst
* Sun Nov 19 2023 opensuse-releaseteam@opensuse.org
- Update to version 20231119.6bcc046:
  * Revert "Temporary disable checks for ALP"
* Sat Nov  4 2023 opensuse-releaseteam@opensuse.org
- Update to version 20231104.5fed802:
  * Update factory dashboard rsync target
* Fri Oct 27 2023 opensuse-releaseteam@opensuse.org
- Update to version 20231027.c46db9b:
  * Only treat aarch64 and x86_64 as mandatory
  * Docstring improvements
  * Wait a randomized interval
  * Release bci repositories per architecture independently
* Fri Oct 27 2023 opensuse-releaseteam@opensuse.org
- Update to version 20231027.3a138b5:
  * gocd/rabbit-openqa.py: Ignore jobs without group
* Thu Oct 26 2023 opensuse-releaseteam@opensuse.org
- Update to version 20231026.fcdc535:
  * Remove QR and some SLE-Micro pipelines
* Thu Oct 26 2023 opensuse-releaseteam@opensuse.org
- Update to version 20231026.2891f13:
  * Only check for products to be built successfully
* Wed Oct 25 2023 opensuse-releaseteam@opensuse.org
- Update to version 20231025.4331902:
  * Temporary disable checks for ALP
* Tue Oct 24 2023 opensuse-releaseteam@opensuse.org
- Update to version 20231024.d9ca0bb:
  * Update SLE-Micro pipelines (5.5->6.0)
* Tue Oct 17 2023 opensuse-releaseteam@opensuse.org
- Update to version 20231017.c439ad7:
  * project-installcheck.py: Support arch-specific ignore-conflicts config
* Thu Sep 28 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230928.864b176:
  * Disable aggregating over financial year
* Mon Sep 25 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230925.6075c72:
  * ttm: Check for build success of containerfile_products before releasing
  * ttm: Print the full list of missing products before exiting
* Mon Sep 25 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230925.04febcb:
  * check_source.py: Add review-team review on meta packages
* Mon Sep 18 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230918.9d6c197:
  * check_source.py: Don't skip various checks and reviews for non-spec packages
* Tue Sep 12 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230912.fe4936c:
  * Remove unused IBS release pipelines
  * Add ALP installer pipelines
* Tue Sep 12 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230912.75e93b7:
  * Attempt to publish BCI repos more often
* Tue Aug 29 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230829.44bcd82:
  * Don't crash when trying to fetch owner for 404 devel prjs
* Mon Aug 28 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230828.37393de:
  * gocd: add checkers for ALP:Source:Standard:1.0
  * gocd: add stagings for ALP:Source:Standard:1.0
  * gocd: remove old LEO group
* Mon Aug 28 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230828.02a6b36:
  * Switch Leap dashboard to 15.6
* Thu Aug 24 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230824.337d2ce:
  * gocd: enable SP6 jobs on BCI
* Wed Aug 23 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230823.3d34cbb:
  * Fix E721: Use isinstance instead of comparing types
* Tue Aug 22 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230822.4be49e9:
  * add Leap 15.6 publish_distro config
* Tue Aug 15 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230815.03a7aaa:
  * version_calculate: chdir to the osclib dir
* Fri Aug 11 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230811.65a86bd:
  * publish_distro config for Leap Micro 5.5
* Thu Aug 10 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230810.166affb:
  * factory-package-news: walk through every directory in the iso image
* Wed Aug  9 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230809.3232664:
  * factory-package-news: use a nicer name for the forcestr function
* Fri Aug  4 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230804.9200c9e:
  * factory-package-news: support newer python3 rpm bindings
* Tue Aug  1 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230801.82c067d:
  * Don't specify flavors for Leap 15.4 appliances
* Mon Jul 31 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230731.178896c:
  * Add LeapMicro 5.5 pipelines
* Sat Jul 29 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230729.e576376:
  * added 15 SP5 QR
* Wed Jul 26 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230726.2a0b30a:
  * gocd: Run BCI RepoPublisher at 9:23 daily
  * gocd: Add missing directory to BCI RepoPublisher pipeline
* Tue Jul 25 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230725.2253789:
  * project-installcheck.py: Don't include ignored errors in rebuildpacs.yaml
* Fri Jul 21 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230721.2396b32:
  * docs/staging: remove obsolete references
  * Add backup server URL and update source map
* Fri Jul 21 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230721.2d37d5b:
  * gocd: enable Leap 15.6 checkers
  * Revert temporary fixups, these are working now
  * Add a simple smoke test launching all scripts with --help
  * Require typing_extensions on SLE & Leap
  * Fallback import Literal & TypedDict from typing_extension
* Fri Jul 21 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230721.3301485:
  * Add BCI repo publishing bot
* Fri Jul 21 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230721.5bc933b:
  * gocd: fix image names for Dolomite
* Tue Jul 18 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230718.15a1347:
  * stagingapi: fix execution with OSC 1.x
* Tue Jul 18 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230718.1252857:
  * gocd: rename alp micro to Dolomite
* Tue Jul 11 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230711.3bf8fdf:
  * Fix review_mode being set from a str and not from the enum
* Mon Jul 10 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230710.395857d:
  * Remove unused variable
  * Convert namedtuples into a typed NamedTuples
  * Raise a concrete exception type, not the generic exception base class
  * ReviewBot: convert REVIEW_CHOICES into an enum
  * Add some type hints
* Mon Jul 10 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230710.b1b5536:
  * Update SLE Micro to 5.5
* Tue Jul  4 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230704.bb6afc9:
  * Update checkers,stagings and target pipelines for SLE15 (SP5 -> SP6)
* Thu Jun 29 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230629.009689f:
  * gocd/rabbit-openqa.py: Ignore projects without a staging setup
* Thu Jun 29 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230629.3b612be:
  * Cleanups for accepting scm-staging bot submissions
* Tue Jun 27 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230627.8b1c308:
  * check_source: fix condition checking for <scmsync> for git packaging
* Tue Jun 27 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230627.8db5f62:
  * Don't decline SRs from non-devel project for scmsync packages from the bot
  * Add type hints to action_ methods of ReviewBot
* Thu Jun 22 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230622.459489f:
  * gocd: Add Leap 15.5 to the Vagrant publisher
* Wed Jun 21 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230621.d0aaa85:
  * dist: Add python3-requests
* Mon Jun 19 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230619.f8254e9:
  * Add prefix for agama so botmaster notifies openQA about builds
* Mon Jun 19 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230619.bd7d620:
  * skippkg-finder.py: Handle empty configuration values properly
* Fri Jun 16 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230616.d798b51:
  * Switch to Leap 15.5
* Thu Jun 15 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230615.97267e1:
  * docker_publisher.py: Add armv7l to 15.4
* Thu Jun 15 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230615.59e3288:
  * dist: Pick osc from repo built against published Tumbleweed
* Thu Jun 15 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230615.82c9054:
  * docker_publisher.py: Set 15.5 as latest
* Tue Jun 13 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230613.f09ff89:
  * project-installcheck.py: Honour installcheck-ignore-conflicts config
  * project-installcheck.py: target_packages is a dict, not a list
  * project-installcheck.py: Move some code out of a with block
* Tue Jun  6 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230606.7297d89:
  * also monitor the SUSE:ALP repositories
* Tue Jun  6 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230606.893b74f:
  * Schedule Leap15.5 updates tests
* Mon Jun  5 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230605.f39ef8f:
  * Move factory-package-news-web.py script to gunicorn
* Mon Jun  5 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230605.bf97015:
  * fixed pipe line name
  * added ALP.Target group to the list
  * dist: fix rpm scriptlets call to systemd_postun
  * Add ALP Micro image release
* Fri Jun  2 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230602.41b6a00:
  * dist: fix rpm scriptlets call to systemd_postun
* Thu May 25 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230525.002c3c0:
  * Add Leap 15.5 to access metrics
* Tue May 23 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230523.bb5a644:
  * Drop redundant `unique_product_flavor`
  * Do not drop the database on every run
  * Fixes
  * Refactor 'unique_product' object
  * Fix merging and syntax errors
  * Write points with flavor tag
  * Parse flavor type to cached data
  * Aggregate unique flavor access data
* Fri May 12 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230512.422701c:
  * devel-project: limit request has review state only
* Thu Apr 20 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230420.372c67d:
  * staging-installcheck.py: Detect some edge cases in check_required_by
* Wed Apr 19 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230419.c0f2057:
  * Filter out access logs with error code
* Tue Apr 18 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230418.aebe39c:
  * Publish kiwi-templates-Minimal-s390x for SLE15
* Tue Apr 11 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230411.8639ce3:
  * repo2fileprovides.py: Support file deps in boolean dependencies
* Tue Apr 11 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230411.f596472:
  * docker_publisher.py: Add 15.5, remove 15.3
* Tue Apr 11 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230411.7f92b23:
  * Fix the OBS CI workflow (#2950)
* Tue Apr 11 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230411.363c84c:
  * dist: Package osrt-repo2fileprovides
* Tue Apr 11 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230411.816d0eb:
  * cleanup_rings.py: Add snobol4 to whitelist
* Thu Apr  6 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230406.c548870:
  * Add repo2fileprovides.py
* Wed Mar 29 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230329.af36a03:
  * osclib: Skip debuginfo, debugsource and src rpms in fileinfo_ext_all
  * Remove try/catch around code which must not fail
  * Rewrite core algorithm of cleanup_rings.py
  * cleanup_rings.py: Fix links handling
* Fri Mar 24 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230324.4a241c4:
  * Allow cleanup_rings without locking the stagings
  * cleanup_rings.py: Expand whitelist
  * cleanup_rings.py: Look at all enabled images
* Thu Mar 23 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230323.0d10247:
  * Handle deletion of packages with _multibuild (#2943)
* Wed Mar 15 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230315.982c565:
  * pkglistgen: handle published repos using sha512 nistead of sha256
* Tue Mar 14 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230314.143a171:
  * skippkg-finder: add conditionals support for the product ftp-tree
* Thu Mar  9 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230309.7eca6b9:
  * Drop flavors in Leap155 appliances
* Thu Mar  9 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230309.8252602:
  * add eruby generated pkglistgen.opensuse.gocd.yaml
  * remove pkglistgen for leap16 completely
  * Comment out skippkgfinder for now
  * Initial Leap 16.0 pkglistgen
* Thu Mar  9 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230309.846b7c0:
  * dashboard: leap: fix openQA IDs
* Fri Mar  3 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230303.db6249f:
  * gocd: add Micro and Bedrock packagelistgenerator call
* Fri Mar  3 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230303.e6dbbae:
  * Create new pipeline to deploy sle-prjmgr-tools scripts
* Fri Mar  3 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230303.08e0489:
  * Switch testing from Leap 15.3 to openSUSE Leap 15.4
* Fri Mar  3 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230303.85a08f7:
  * Fix handling of preinstall images
* Thu Mar  2 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230302.a0cb736:
  * Port from mock to unittest.mock
* Fri Feb 10 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230210.1cf4e6b:
  * leapmicro: fix the wrong Leap Micro version in RelPkgs pipeline
* Thu Feb  9 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230209.cdbe773:
  * Update totestmanager.gocd.yaml.erb
  * Add LeapMicro 5.4 pipelines
* Thu Feb  2 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230202.cbaa2d4:
  * Release the multibuild container itself, that will cover all flavors
* Thu Feb  2 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230202.d737b9f:
  * Tag the previous image in the cleanup script
  * Add cleanup script running at night on botmaster
* Tue Jan 31 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230131.9980d01:
  * Remove trailing whitespace in gocd/sp.target.gocd.yaml
  * Port over more uses of Request.get_creator()
* Mon Jan 30 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230130.8e810cc:
  * More gocd errors in the new SLE pipelines
  * Fix gocd config ident - listing a stage as a job
  * gocd: Add parametrized pipeline for automatic release
  * gocd: Add parallel stage for totest release
* Sun Jan 29 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230129.a7da0b8:
  * Don't schedule Leap 15.3 tests in O3
* Wed Jan 25 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230125.2b3c045:
  * Allow specifying a devel project that has "Factory" in its name
* Wed Jan 25 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230125.2c0e252:
  * Add explicit deprecation warning
* Wed Jan 25 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230125.be71541:
  * Handle special DVD+Image BUILD values in SLE Micro Staging jobs
* Wed Jan 25 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230125.61fdf0f:
  * accept_command: cleanup redundant ports_prjs assignment
* Wed Jan 25 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230125.394f8ee:
  * use request.creator rather than request.get_creator() which is deprecated
  * Use old function to pass tests
  * Restore old xpathsearch for fullhistory searches
  * Use the 15.4 container
  * Fixes for osc-1.x
* Wed Jan 25 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230125.29aed3c:
  * Make REGEX_LINE backwards compatible
  * Fix regex for access logs parsing
* Wed Jan 25 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230125.4d5b976:
  * Switch to 15.4, 15.3 has been deleted
* Tue Jan 24 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230124.c53e264:
  * gocd/rabbit-openqa.py: Always include flavor, name and machine in the check
* Tue Jan 10 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230110.5f7806f:
  * Switch to ci-test.yml to actions/checkout@v3 and codecov/codecov-action@v3
  * Drop gocd pipelines for 15.3
* Thu Jan  5 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230105.9011ec4:
  * consistency: remove .sh suffix from openh264_release_to_publish.sh
  * add set -e to remaining openh264 scripts as well
  * add set -e to not hide any failures
  * add openh264 tools into CONTENTS.md
  * reflect change in script name
  * fix date pattern %%M->%%m
  * Add date into archive name
  * Spellcheck from cboltz
  * Use api.opensuse.org instead
  * Scriptw for manual release workflow of OpenH264
* Tue Jan  3 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230103.b4e2549:
  * retab publish_distro
  * check_source_tests: Adopt expected error to latest changes
  * metrics.py: Fix E741 ('l' may look like 'I')
  * More fixes for editor config compliance
  * gocd: Apply editorconfig standards
  * publish_distro_conf: Apply editor config standards
  * Validate that the files match the editor config
* Mon Jan  2 2023 opensuse-releaseteam@opensuse.org
- Update to version 20230102.e49b449:
  * dashboard: remove 15.3 (EOL)
* Fri Dec 16 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221216.84941bd:
  * gocd: ensure timeout is set for packagelist generation
* Tue Dec 13 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221213.82ee694:
  * dashboard: add openQA information to Legacy x86
* Mon Dec 12 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221212.41dbcc8:
  * dashboard: Add LegacyX86 port and sort the list
  * staging_accept: update Factory version in LegacyX86 port on accept
* Mon Dec 12 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221212.5effc63:
  * retab the line use spaces instead
  * publish_distro add  --now to set PUBLISH_DELAY=0
* Thu Dec  1 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221130.db5d69f:
  * gocd: drop SUSE:ALP:ARM project from pkglistgen
* Tue Nov 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221129.8ed5c06:
  * Update publish_distro_conf/publish_leap155_appliances.config
  * Limit flavors to just one
  * Use correct Minimal-VM reference
  * comment out 15.5 flavors that do not build yet
* Mon Nov 28 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221128.1e849ff:
  * ignore more jar version of yaml validator
  * gocd: add more subprojects to ALP pkglistgen
* Fri Nov 25 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221125.1eb9923:
  * gocd: Add configuration for openSUSE:Factory:LegacyX86
* Thu Nov 24 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221124.c0644df:
  * readd ToTest 15.4_ARM manager
* Thu Nov 24 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221124.fd471a3:
  * ci: Adjust path to memcached as done in the package
* Thu Nov 24 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221124.a808aa2:
  * gocd/rabbit-openqa.py: Also try to match disk images (#2888)
  * gocd/rabbit-openqa.py: Ignore isos which don't have an OpenQAMapping
* Wed Nov 23 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221123.d483a44:
  * gocd/rabbit-openqa.py: Ignore jobs in "Development" groups
  * gocd/rabbit-openqa.py: Add --dry option
  * gocd/rabbit-openqa.py: Remove unused parameters
* Thu Nov 17 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221117.de9316e:
  * gocd: fix another double quote in BCI
* Thu Nov 17 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221117.db274c7:
  * gocd: fix typo in BCI release pipeline
* Thu Nov 17 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221117.6e6e1ec:
  * Move comment out of the value block - script executor plugin doesn't like it
  * Update version of the config plugin
  * Update SLE Micro to 5.4
  * gocd: change erb template file and not just the generated file
  * include review feedback and adapt script for SP5
  * gocd: allow to publish SLE BCI repository using a token
* Fri Nov 11 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221111.5c2645c:
  * Improve bs_mirrorfull help text
* Fri Nov 11 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221111.ffbab4f:
  * Adapt check_source test to latest source validator output
  * check_bugowner: Don't get tripped over trailing space
* Fri Nov 11 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221111.8fe27f7:
  * Move the copy & pasted bci blocks into a template
* Fri Nov 11 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221111.37857f9:
  * Added BCI 15SP5 parts
* Tue Oct 25 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221025.1ef34941:
  * add configuration for ALP staging
* Tue Oct 25 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221025.f4999b32:
  * Don't hard code bash as interpreter for source_validator scripts
* Mon Oct 24 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221024.39e322e2:
  * gocd: add openSUSE:Leap:15.4:Images to pkglistgen pipeline for the Leap 15.4 CR
* Thu Oct 20 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221020.4765ffae:
  * osclib: Correct syntax error in typing
  * osclib: Submit summary-staging.txt to the devel project
  * osclib: Add typehints
  * ignore: venv, vscode and IDEA config directories
* Thu Oct 13 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221013.5e2a1716:
  * pkglistgen: Convert sections to class
  * Docs: Fix typos
  * pkglistgen: Add type annotations
  * osclib: Add type annotations
* Thu Oct 13 2022 opensuse-releaseteam@opensuse.org
- Update to version 20221013.21411e52:
  * Fix the syncing of rebuild failures for multibuild flavors
* Thu Sep 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220929.aad22912:
  * Check 'textmode' test on 15.4
* Wed Sep 14 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220914.8eb34c45:
  * Remove publish_distro dependency on python-mb
* Wed Sep 14 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220914.7abe1a52:
  * skippkg-finder: remove installation-images from the forbidden list
* Fri Sep  2 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220902.9ea68a61:
  * TTM: Do not save SeenIssues if they didn't change
  * TTM: Add log message for changing status
* Thu Sep  1 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220901.e6d11c4d:
  * dashboard: Remove Leap Micro 5.2
  * dashboard: add Leap 15.5
  * check_source: expand check_source be able to handle Leap/Backports submission
  * Ignore starting white space in bugowner lines
* Mon Aug 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220829.5a8f3dbe:
  * Add test for group in bugowner line
* Mon Aug 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220829.fc36daa0:
  * gocd: Increase the timeout for Legal.Import pipeline
  * Set timeout on the suse checkers
* Mon Aug 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220829.a5ef99ba:
  * Fix E275: missing whitespace around keywords
  * Setup for SLE15 SP4 Quarterly Update
* Mon Aug 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220829.80f24611:
  * Use HTTP GET for /search/request/id API endpoint
* Fri Aug 26 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220826.f861a750:
  * Trigger aarch64 updates jobs
* Fri Aug 26 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220826.79f900e7:
  * publish_distro: Provide missing link target in %%files
* Tue Aug 23 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220823.34659a46:
  * install and link publish_dist
* Thu Aug 11 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220811.b3ea77e9:
  * project-installcheck: Don't record unresolvables/fails during building
* Thu Aug 11 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220811.a79aecee:
  * MirrorCache does not require mb makehashes
  * Add publish-distro subpackage to spec
  * Add basic README for publish_distro
  * Correct publish_distro_conf path in CONTENTS.md
  * Copy of publish_distro configuration 817e024
  * Add basic docs to the script
  * Add short summary to publish_distro
  * Move publish_distro 817e024 into openSUSE-release-tools
* Thu Aug 11 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220811.ed451591:
  * Fix cache handling with osc from git master
* Wed Aug 10 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220810.97f838f2:
  * StagingBot: call staging rebuild first (support random fails) and handle Factory:NonFree
* Tue Aug  9 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220809.46872b13:
  * Do not fail when there is no cloud image to be released to TEST
* Fri Aug  5 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220805.0414dd16:
  * gocd: keep LEO group name in botmaster
  * gocd: more rename from LEO to ALP
  * gocd: LEO is replaced with ALP
* Thu Aug  4 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220804.2601ff93:
  * Dont use garbled patches for test fixture
* Thu Aug  4 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220804.db4d05c0:
  * Change MicroOS announcer email addresses
* Fri Jul 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220729.5c03f149:
  * Enable Leap 15.5 rebuild-trigger
* Thu Jul 28 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220728.5b31dfff:
  * Enable Leap 15.5 TTM
  * Enable 15.5 and SLE15 SP5 Backports
* Fri Jul 22 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220722.0fe292df:
  * Update for SLE15.Target
* Mon Jul 18 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220718.1fe31ebf:
  * gocd: Fix previous change - comments don't work in scripts
  * gocd: Don't run staging-bot for SP5 (for now)
* Fri Jul 15 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220715.4fd15522:
  * rabbit-openqa: If OSRT:OpenQAMapping contains garbage, just continue
* Thu Jul 14 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220714.70a1c647:
  * Add Micro 5.3 into ttm
  * Add LeapMicro 5.3 bot configuration
* Wed Jul  6 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220706.9b973c9b:
  * Update checkers and stagings pipelines for SLE15 (SP4 -> SP5)
* Fri Jun 24 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220624.4137841c:
  * ci/testenv-tumbleweed: Add scm-obs-bridge for source_checker to container
  * package: require git-scm-bridge by osrt-check-source
* Mon Jun 20 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220620.4d3c1856:
  * freeze: always disable images repository after freeze
* Mon Jun 20 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220620.11235ac0:
  * ALP:Enable autosync
* Wed Jun  8 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220608.67d65358:
  * docker_publisher.py: Make 15.4 stable
* Fri Jun  3 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220603.05ff2914:
  * Run gocd/generate.sh
  * Remove all Kubic tooling
* Tue May 31 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220531.bd5f1a56:
  * dockerhub-publisher.gocd.yaml: Use this repo for docker_publisher.py now
  * dockerhub-publisher.yaml -> dockerhub-publisher.gocd.yaml
* Tue May 31 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220531.7e00d7d8:
  * Introduce a new docker-publisher bot
* Tue May 31 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220531.932157b8:
  * Use consistent URL for openSUSE-release-tools.git
* Thu May 26 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220526.eab9dc70:
  * skippkg-finder: ignore skelcd-control only on Leap project
* Wed May 25 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220525.a1ba599c:
  * Update Micro IBS project (Micro53) in botmaster
* Tue May 24 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220524.5a34df44:
  * Schedule Leap15.4 maintenance updates
* Thu May 12 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220512.551f2f3e:
  * Fix packages released to containers repo
  * Add annotations to the dashboard
  * Add annotation datasources
  * Add annotations for Leap 15.4
  * Update product pattern for Leap 15.4
  * Recreate the database on each run
* Wed May 11 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220511.d5ce68f7:
  * dashboard: Add openSUSE:Leap:Micro:5.2:Images
* Tue May 10 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220510.47294604:
  * Add support to containerfile repo to SLE15
* Thu Apr 14 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220415.b52c5a26:
  * TTM: add openSUSE:Leap:Micro:5.2:Images to pipeline for appliance and containerfile
* Wed Apr 13 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220413.aa57b28b:
  * dashboard: Add Leap 5.2 micro
* Tue Apr 12 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220413.218122dd:
  * skippkg-finder: remove unneeded package from the matches list
* Mon Apr 11 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220411.23ca4c85:
  * Write points to the DB only at the end of interval
* Fri Apr  8 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220408.1d368407:
  * accept: Catch requests without description
* Wed Apr  6 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220406.bd0bc306:
  * project-installcheck: Take 'excluded' as gone package
* Tue Apr  5 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220405.3982570a:
  * Accept_command: create set_bugowner requests
* Tue Apr  5 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220405.5d0676ce:
  * check_bugowner: Decline new packages without bugowner entry
* Tue Apr  5 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220405.b7d4dbdf:
  * gocd: Simplify the groups and restrict them in the CI
* Mon Apr  4 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220404.3e495a4f:
  * Don't play with the publish flag on freeze, images only switches build flag
* Mon Apr  4 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220404.60a2101e:
  * Add automatic notifications for D-Installer
* Sat Apr  2 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220402.0fac6e09:
  * Split the Update.Repos.leap pipeline into two
* Sat Apr  2 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220402.6ce3c9b2:
  * repo monitor: Only keep looking for scheduling repos
* Fri Apr  1 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220401.3c2ced48:
  * repo monitor: If a repo is in scheduler flux, just keep monitoring it
  * check.build.success check: Just keep checking on dirty repos
* Fri Apr  1 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220401.69e19f82:
  * Keep images repository disabled on freeze command
* Wed Mar 30 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220330.1114fbdd:
  * Add new aggregation periods to Grafana dashboard
* Wed Mar 30 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220330.68fa08aa:
  * Remove obsolete Leap 15.2 announcer config
  * Remove obsolete Leap 15.2 scheduling
* Wed Mar 30 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220330.a2fa6583:
  * dist: no longer package check_source_in_factory
  * Fix adi projects having no archs
* Wed Mar 30 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220330.adef152c:
  * Merge check_source_in_factory into check_tags_in_requests.py
* Wed Mar 30 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220330.39d635d6:
  * Make the build fail reminder email text more generic
* Tue Mar 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220329.3acf5457:
  * Add aggregates for fiscal quarter and year
* Tue Mar 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220329.c967b052:
  * build-fail-reminder: Several enhancements
* Tue Mar 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220329.e9c42f69:
  * Use all staging archs in adi projects
* Tue Mar 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220329.39d8309e:
  * project-installcheck: Also store first failed results
  * project-installcheck: Store when we first saw unresolvables
* Tue Mar 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220329.425fdc5f:
  * staging-installcheck: Fix syntax error
* Tue Mar 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220329.8e2e22a2:
  * project-installcheck: Fix off by one error
* Tue Mar 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220329.cc1b2e9d:
  * project-installcheck: Fix syntax error
* Tue Mar 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220329.53f00a2b:
  * project-installcheck: Only add comments for the run in openSUSE:Factory
* Tue Mar 29 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220329.5a25094e:
  * Extend build-fail-reminder to notify about uninstallable packages
* Mon Mar 28 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220328.c6d6df6b:
  * project-installcheck: Comment into openSUSE:Factory packages
  * project-installcheck: Remove problems for gone packages
* Fri Mar 25 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220325.205e07a9:
  * Do not decline requests with download_files errors
* Fri Mar 25 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220325.45c2fb1e:
  * check_source: Allow a .changes line to mention 2 patches
* Fri Mar 25 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220325.939beac7:
  * Stay with minversion 3.6 (and require module we already use elsewhere)
* Fri Mar 25 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220325.1f0c9fd1:
  * Move download URL check to check_source.py
  * Ignore patches that are listed as sources
  * Move the 'patch in changes' check from check_source.pl to .py
* Thu Mar 24 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220324.e25e4b7c:
  * Run source_validator scripts from check_source.py directly
  * Move license check from check_source.pl to .py
  * Move changes check from check_source.pl to .py
  * Move spec file checks from check_source.pl to .py
  * Unskip test for remote services - miniobs got updated
* Thu Mar 24 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220324.9dc35be9:
  * Fix staging accept approving package list changes
* Thu Mar 24 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220324.20d1bcbd:
  * Add test for remote services in factory-auto
  * dist: Enable the ability to run services in miniobs
  * Add test for setBadness in check_source
  * Move check for generated files from check_source.pl to .py
  * Move rpmlintrc checking from check_source.pl to .py
  * Remove diff preparations from check_source.pl
  * Move service check from check_source.pl to .py
  * Remove unused repo_checker config entries
* Wed Mar 23 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220323.bd336586:
  * Remove rpmlint check from check_source
  * Small fixes for staging-installcheck
  * Add osc-pcheck: support devel prj maintainers
* Wed Mar 23 2022 Stephan Kulow <coolo@suse.com>
- just testing
* Wed Mar 23 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220323.ad923e6f:
  * Add some documentation for pkglistgen staging workflow
  * accept: Create pkglistgen .changes entry and commit
  * Prepare applying pkglistgen diffs on staging accept
* Tue Mar 22 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220322.e78b5352:
  * staging-installcheck: Exit 1 for the letter stagings
* Mon Mar 21 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220321.48333852:
  * osc-cycle: add option list to help output
* Mon Mar 21 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220321.0b6739ce:
  * stagings: Report to standard repo if the images are enabled
  * Staging accept: build-disable the images repository
* Sat Mar 19 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220319.4424623d:
  * pkglistgen: pass the test if the comment was replied to with 'ignore'
  * installcheck: Annotate the duplicated binaries yaml
* Sat Mar 19 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220319.0f0a5ab6:
  * remove rebuild trigger for openSUSE:Step:*Update
* Fri Mar 18 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220318.33072b30:
  * gocd: Don't evaluate a repo as succeeded if all are disabled
* Thu Mar 17 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220317.76c89fd3:
  * pkglistgen: Fix packages disapparing in comments
* Thu Mar 17 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220317.42b3f302:
  * CI: adapt miniobs to use the ruby OBS was built with (3.1)
* Thu Mar 17 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220317.518f6f90:
  * pkglisten: Generate a comment for staging diffs
* Tue Mar 15 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220315.0bbf3b2b:
  * pkglistgen: If the groups contain a summary-staging.txt evaluate it
* Mon Mar 14 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220314.6cacf361:
  * Staging installcheck: Do not overwrite package variable
* Mon Mar 14 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220314.e77cce84:
  * pkglistgen: Remove very noisy debug output
* Sat Mar 12 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220312.c6232db2:
  * pkglist: Don't exit with 0 if the stagings didn't calculcate lists
* Fri Mar 11 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220311.8c945063:
  * Check Bugowner: Accept non handled actions (like set_bugowner)
* Fri Mar 11 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220311.02216420:
  * Fix filtering of unneeded.yml
* Thu Mar 10 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220310.c92d0ecd:
  * Add TTM workflow for Leap Micro 5.2
* Thu Mar 10 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220310.99e9d9a2:
  * package: Package /usr/bin/osrt-check_bugowner
  * check_bugowner: Relax check for patchinfo - patchinfo.* is good as well
  * gocd: Run check_bugowner on SLE side
  * Add a test case for check_bugowner
  * Add ReviewBot to check for bugowner lines in requests for new packages
* Tue Mar  8 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220308.807b0f93:
  * tests: Make use of fixtures to be able to test different workflows
* Mon Mar  7 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220307.0e859719:
  * CI: Split the tests in multiple runs
* Mon Mar  7 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220307.7fa0e0de:
  * leapmicro: add leapmicro to pipeline
  * installcheck: Report all delete requests
* Mon Mar  7 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220307.a7a1aa83:
  * Add some basic instructions on how our tests are written
  * docs: Remove testing.asciidoc - it's severely outdated
* Mon Mar  7 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220307.93f8244a:
  * Rename the pkglistgen config for ring1 as well
* Sun Mar  6 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220306.b5436de6:
  * gocd: Create release packages as early as possible
* Sat Mar  5 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220305.b93adbd9:
  * pkglistgen: Fix exit values - True is actually bad
* Sat Mar  5 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220305.040e91a1:
  * gocd: Fix subprocess.run usage
* Sat Mar  5 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220305.b51fd11b:
  * gocd: Fix rare failure to push to notifications repo
  * pkglistgen: Only solve one project at a time
  * Installcheck: Ignore requires to packages with delete requests
* Fri Mar  4 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220304.1479a628:
  * pkglistgen: Don't exit 1 if we skip weakremovers due to restarted builds
* Fri Mar  4 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220304.a0d68e4b:
  * staging-installcheck: Don't exit 1 if there is a problem found
* Fri Mar  4 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220304.93564783:
  * pkglistgen: Fix invalid import
* Fri Mar  4 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220304.57322b23:
  * pkglistgen: Deprecate scope 'all'
* Fri Mar  4 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220304.ebe2c528:
  * tests: Fix api_tests to mock attribute not mtime
  * tests: Create OSRT:FreezeTime for all tests
  * osclib: Add an helpful error on failed attribute save
  * Make frozenage less reliant on changing _frozenlinks
* Fri Mar  4 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220304.986ad21b:
  * docs: Add note that the origin manager is unmaintained
* Thu Mar  3 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220303.003f0105:
  * Treat all group*.yml like groups.yml
* Thu Mar  3 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220303.39bbc90c:
  * package: pkglistgen requires zstd
  * More origin manager cleanup
* Wed Mar  2 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220303.8ad49177:
  * skippkg-finder: use SLE update prior to GA for Respin
* Wed Mar  2 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220302.3654dc91:
  * Fix XML usage in openqa bot
* Fri Feb 25 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220225.65cf38f7:
  * freeze: Copy weakremovers.inc from target project to avoid bitrot
* Fri Feb 25 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220225.970e958e:
  * pkglistgen: Also support zstd for weakremovers.inc
* Thu Feb 24 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220224.e679863a:
  * pkglisten: Add option to remove refresh from target
* Tue Feb 22 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220223.4d2a5a2e:
  * skippkg_finder: fix unconditional matches if the first regex element is space
* Tue Feb 22 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220222.31e00873:
  * Remove the origin operator and its user scripts
* Tue Feb 22 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220222.897039d3:
  * OBS Workflow: Fix project
* Tue Feb 22 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220222.bb88862d:
  * Use official OBS integration and retire osrt-puller
* Tue Feb 22 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220222.d8ef5897:
  * Remove sentry integration
* Mon Feb 21 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220221.3e14e55f:
  * Fix output of staging reviews
  * Target F401 - Unused imports
  * Target E501 - Line too long
  * Target E128 - Continuation line under-indented for visual indent
  * Target E251 - Unexpected spaces around keyword
  * Remove E201 - Whitespace after '('
  * Target E202 - Whitespace before ')'
  * Target E302 - add two comment lines before class
  * Target E305 - Have two empty lines of a class
  * Target F841 - Remove unused variables
  * Target E261 - two spaces before inline comment
  * Handle E712 - don't compare with == to Booleans
  * Targetting E126 - Continuation line over-indented for hanging indent
  * Target E711 - compare against None with 'is' not !=
  * Target E125 - Continuation line with same indent
  * Target E124 - Closing bracket does not match visual indentation
  * Target E129 - Visually indented line with same indent
  * Targeting E123 - Closing bracket does not match indentation
* Fri Feb 18 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220218.a7ac9876:
  * rabbit-openqa: Don't crash on openqa jobs without BUILD
* Fri Feb 18 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220218.b3d0cc66:
  * Use the unversioned ruby interpreter
* Fri Feb 18 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220218.54d2979d:
  * Fix indent of statements E127
  * Replace variable name 'l' (x is fine)
* Fri Feb 18 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220218.5f2e5dc0:
  * Only have one statement in a line E701
* Fri Feb 18 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220218.52dbb52b:
  * Remove bare excepts - https://www.flake8rules.com/rules/E722.html
  * Harmonize imports on using lxml for XML parsing
* Thu Feb 17 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220217.8b1acc1d:
  * Remove --by-develproject for adi command
* Thu Feb 17 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220217.3f8763ae:
  * use set -e to catch more issues with the script
  * rename JeOS to Minimal and remove Vagrant images
* Thu Feb 17 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220217.28577584:
  * staging: consider first staging a target even without --move
* Tue Feb 15 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220215.c77acf53:
  * Factory staging: report pkglistgen status
* Tue Feb 15 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220215.34abdb2b:
  * Support to move one staging into another
* Tue Feb 15 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220215.805cd93d:
  * truncate overlong changelogs to 100 lines + last line
* Mon Feb 14 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220214.e0da44c3:
  * Include request submitters in staging report
* Mon Feb 14 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220214.bf7c5e16:
  * Introduce --remove-exclusion for staging select
* Thu Feb 10 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220210.5effbf8b:
  * ToolBase: use --osc-debug for osc's config value, not the tools own debug parameter
* Wed Feb  9 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220209.e936910b:
  * Include :Staging in :adi images and containerfile repo paths
* Tue Feb  8 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220208.00fbc991:
  * ci: We don't use coveralls anymore
* Wed Feb  2 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220202.75645389:
  * Check whether the FTP trees contain OSRT:ProductVersion before releasing
* Wed Jan 26 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220126.2d5e72db:
  * factory-package-news.py: Don't rely on changelogtime equality
* Tue Jan 25 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220125.1bfd0ca2:
  * skippkg-finder: add a supplement list for adding package to the skiplist
* Fri Jan 21 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220121.38112333:
  * gocd: Add Leap 15.4 vagrant boxes
  * gocd: Update link to Leap-15.3.aarch64-libvirt_aarch64.json
* Wed Jan 19 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220119.dfbb1b3a:
  * gocd: Monitor KDE:Medias as well
* Mon Jan 10 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220110.75f0d354:
  * gocd: Drop 15.2
* Mon Jan 10 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220110.e8319fa5:
  * spec-cleaner imposed cleanups
  * dist: include project-installcheck.py again
* Tue Jan  4 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220104.ae6175d3:
  * Dashboard: do not display containerfile values for Leap
* Sat Jan  1 2022 opensuse-releaseteam@opensuse.org
- Update to version 20220101.51f56098:
  * Add a dashboard for Leap
* Fri Dec 17 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211217.2681ad5e:
  * Update MicroOS IBS project (MicroOS52) in botmaster
* Thu Dec 16 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211216.50e8e352:
  * pkglistgen: Handle loops in project path expansion
* Thu Dec 16 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211216.8eed6fc7:
  * Add 15.4/ARM Images totestmanager
* Wed Dec 15 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211215.60b15582:
  * Run TTM for openSUSE:Leap:15.4:ARM (armv7)
* Tue Dec 14 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211214.a7644165:
  * gocd: Remove timeouts for the pipelines
* Fri Dec 10 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211210.dacaa5c5:
  * Dashboard: Add containerfile
* Wed Dec  8 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211208.fda88d31:
  * metrics: telegraf: Fix URL for openqa.opensuse.org after machines were moved to openSUSE internal network
* Wed Dec  1 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211201.2f3a762b:
  * gocd: Use https://legaldb instead of http
* Mon Nov 22 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211122.1875f66a:
  * legal-auto: Fix regression in product import
* Mon Nov 22 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211122.45e3d064:
  * legal-auto: Move the "ignore channels" feature in the proper function
* Fri Nov 19 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211119.ce4a3e37:
  * Add note about missing IPv4 logs
* Fri Nov 19 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211118.5f3b629b:
  * Skip empty cache files
  * Fix handling missing log files
* Sun Nov  7 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211107.bab90ef3:
  * devel-project: make "list" the default command work in Python 3.3
  * devel-project: Add a func callback to main parser
* Fri Nov  5 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211105.c4e7e358:
  * Retry GETs if they catch a TimeoutError
* Fri Nov  5 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211105.cd161f34:
  * add option to use newest package for resolving dependencies
* Thu Nov  4 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211104.5fa0da62:
  * Run TTM for openSUSE:Leap:15.4:Images
* Tue Nov  2 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211102.e777410a:
  * Move remaining vagrant publishers from Jenkins to botmaster
* Fri Oct 29 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211029.a924a9b0:
  * Revert container-cleaner experiments
* Fri Oct 29 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211029.4c20c475:
  * One more endless loop test against the API
* Fri Oct 29 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211029.b54a9360:
  * Make the container cleaner endless loop against login proxy without auth
* Fri Oct 29 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211029.c711dd57:
  * Now test endless loop on a different SSL host
* Fri Oct 29 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211029.80bb54c9:
  * Debug endless loop to verify the underlying problem
* Fri Oct 29 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211029.ca55ff6c:
  * gocd: Disable cache for container cleaner
* Fri Oct 29 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211029.faa760d6:
  * gocd: Run container cleanup with full debug
* Fri Oct 29 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211029.321c5259:
  * gocd: Experiment with a special sysctl for container cleanup
* Wed Oct 27 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211027.80b3fafb:
  * gocd: Also run the microos stagings only once per hour
  * miniobs: The upstream OBS project changed repo names
  * pkglistgen: Skip repos without state
  * gocd: Fix typo found by accident
* Wed Oct 27 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211027.014d1c7a:
  * gocd: Run release package generation for stagings only once an hour
* Tue Oct 26 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211026.f1790c67:
  * pkglistgen: Keep caching repo solv files but copy them away
* Tue Oct 26 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211026.417c4e6d:
  * pkglistgen: Skip relying on the global cache directory
* Tue Oct 26 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211026.802e0d64:
  * filter out 15-sp3 and 15-sp4 from factory-source review
* Mon Oct 25 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211025.11d2c9be:
  * Change vagrant publisher resource to staging-bot
* Sun Oct 24 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211024.0472da96:
  * pkglistgen: Do not generate weakremovers if in release package mode
  * pkglistgen: Generate the release packages first
* Fri Oct 22 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211022.c7c2beb4:
  * Adjust secret_config_id in the dashboard.generator pipeline
  * Add pipeline to publish the vagrant boxes to Vagrant Cloud
* Tue Oct 12 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211012.2f5f796d:
  * try to skip channel files as submitted with kernels and livepatches, as they cannot be legal reviewed
* Thu Oct  7 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211007.f5e62341:
  * Remove kubernetes setup
  * Remove devel package and make check target
* Fri Oct  1 2021 opensuse-releaseteam@opensuse.org
- Update to version 20211001.62170202:
  * Fix tests
  * CI: Run Tumbleweed container as priveleged in docker
* Thu Sep 30 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210930.155a1eb6:
  * Fix the only offense of E731
* Fri Sep 24 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210925.391bef87:
  * pkglistgen: add openSUSE:Leap:15.3:Update:Respin
  * totest-manager: add openSUSE:Leap:15.3:Update:Respin
  * skippkg-finder: add --alternative-project option overrides OPENSUSE_PROJECT for package checking
* Thu Sep 23 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210923.153aea36:
  * check_source: Fix revert case for patch detection (fix#2640)
* Thu Sep 23 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210923.8f4795d1:
  * Clarify status and deployment of check_source_in_factory
  * Delete scan_baselibs.py
  * Delete obs_clone.py
  * Delete unmaintained.py
  * Delete sync-rebuild.py
  * Delete leaper, update_crawler and manager_42
  * Delete status.py
* Wed Sep 22 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210922.75227421:
  * Adds dependency for full check_source testing
* Wed Sep 22 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210922.0dd8b501:
  * Remove redundant information from processes.md
* Tue Sep 21 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210921.009ead7b:
  * Remove E265 from flake ignore list
  * Make use of the 15.3 miniobs container
* Tue Sep 21 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210921.9fa0b78b:
  * Remove E713 offense from flaker
  * pkglistgen: Accept i686 as well
  * pkglistgen: replace if not a in with if a not in
  * pkglistgen: Fix architecture handling of weakremovers
  * gocd: Use python3 -u for pkglistgen
* Tue Sep 21 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210921.22ab5cba:
  * miniobs: Use 15.3 repos - 15.1 is EOL
* Mon Sep 20 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210920.e1eef928:
  * Link the new testcase from processes.md
  * Test to showcase a submit request to SLE
* Thu Sep 16 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210916.1cb39a18:
  * rabbit-openqa.py: Ignore PR verification runs with / in BUILD
* Thu Sep 16 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210916.57abe572:
  * Fix typo in documentation
  * OBSLocal: functions to easily manage several review bots
  * OBSLocal: rename assertReviewBot to assertReviewScript
  * OBSLocal: improve documentation about scripts and asserts
  * OBSLocal: small reorganization
  * Extract useful stuff to a base OBSLocal.StagingWorkflow class
  * OBSLocal: clarify some aspects of attributes management
  * Rename test file to ensure it is executed in CI
  * Rename OBSLocal.StagingWorkflow to OBSLocal.FactoryWorkflow
* Tue Sep 14 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210914.b25b3f35:
  * Add pipeline to setup QR home project
* Mon Sep 13 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210913.f61b2e79:
  * gocd: rename SLE_BCI to SLE_BCI_15SP3 and add SP4 flavor
* Fri Sep 10 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210910.877432d2:
  * do not use oscrc from fixtures (should fix #1989)
  * fix deprecation warning in parser
* Wed Sep  8 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210907.d2e3c9d2:
  * Add some comments
  * Create ProductVersion attribute
  * Remove attributes when destroying a workflow
* Tue Sep  7 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210907.d07908c4:
  * skippkg-finder: move extra packages to the OSRT attribute
* Mon Sep  6 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210906.2f7e2499:
  * Improve text
  * Add line breaks
  * Improve text
  * Document ADI projects
  * Add documentation
* Mon Sep  6 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210906.63613a92:
  * skippkg-finder: add two packages to the extra list for zypper dup reason
* Wed Sep  1 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210901.f75b5c1b:
  * gocd: fix a missing whitespace between command and argument for skippkg-finder
* Tue Aug 31 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210831.0de63caa:
  * Update specfile for skippkg-finder
  * Run skippkg-finder.py before pkglistgen
  * Add skippkg-finder.py to overwrite NON_FTP_PACKAGES for obsoleted and unneeded package
* Fri Aug 20 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210820.43b07171:
  * gocd: Fix timer specification for Update.Repos.Leap
* Thu Aug 19 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210819.0316d3b0:
  * Test to showcase a submit request to Factory
* Thu Aug 19 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210819.abe2f698:
  * gocd: increase the timer for fire Leap updaterepos every 3 days
* Thu Aug 12 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210812.b133ea61:
  * add release package and packagelist bots for LEO
* Tue Aug 10 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210810.918f32cc:
  * ttm: add new ttm pipeline for Leap 15.4
* Thu Aug  5 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210805.5b68d530:
  * OBSLocal: top-level classes documentation to clarify the scope
  * Point to osc.core to compare the APIs
  * More improvements in the OBSLocal.py documentation
  * In OBSLocal.StagingWorkflow.submit_package, package may not be None
  * Some convenience extensions to OBSLocal
  * OBSLocal: improved management of meta
  * Tiny fix in check_source_test.py
  * Improvements in the OBSLocal.py documentation
  * Convert OBSLocal documentation to reStructured Text
  * document OBSLocal.py
* Thu Jul 29 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210729.455dc99c:
  * Refactor code to split big method and improve doc
  * Add test for inherit maintainer role
  * Add note about explicit ignoring of inherited maintainership
  * Avoid creation of duplicate add_role requests (fixes #2609)
* Fri Jul 23 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210723.7e5bacec:
  * Fix README.md reference to docs/processes.md
  * Fix a few gocd links
  * Update more tools status
  * Update some tools status
  * Add some info about obsolete tools
  * Update gocd links
  * Mark sync-rebuild as obsolete
  * Extend container_cleanup description
  * Apply suggestions from the review to the inventory
  * Apply suggestions from the review to the inventory
  * Fix a few typos
  * Make clear that systemd units are not used by bots anymore
  * Fix a few typos
  * Add a document describing the contents of the repository
* Thu Jul 22 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210722.9d1e9c24:
  * Fix header level in processes.md
* Thu Jul 22 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210722.a9b5d53a:
  * Improvements in processes.md based on peer review
  * Add processes.md
* Mon Jul 19 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210719.16822566:
  * Fix typos
  * Review of the tricks section while debugging the CI
  * Extend docker-compose commands info when debugging the CI
  * Add to README hints how to debug failures in CI
* Fri Jul 16 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210716.80f24854:
  * gocd: update staging bot for Backports
  * gocd: update rbeuild-trigger for Backports and Step
* Fri Jul 16 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210716.7b59f334:
  * Properly handle required-source-maintainer when it is group
  * Updates from code review
  * Check for maintainers in the source project
  * Add descriptions to check_source tests
* Wed Jul 14 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210714.bc466636:
  * gocd: Drop openSUSE:Factory:WSL
* Wed Jul 14 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210714.5d5297cb:
  * pkglistgen: initialize pkglistgen for Leap 15.4
* Tue Jul 13 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210713.677b3163:
  * Make test CWD agnostic
  * Use pytest instead of nosetests (fixes #2524)
* Tue Jul 13 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210713.f9ab72aa:
  * Package: Fix rpm warning about unversioned obsoletes
  * Package: Drop systemd services
  * Add a check on the gocd config to github actions
  * Transpose #2568 into the proper format
  * Validate the yaml-config-plugin download
* Tue Jul 13 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210713.8e913573:
  * Preparation for switch from nosetests to pytest
* Fri Jul  9 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210709.f461ce7b:
  * gocd: fix path for script and use suse-repos.git
* Fri Jul  9 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210709.80bd9187:
  * Run perl checks as part of flaker ci task
  * fix perl warnings in check_source.pl
* Fri Jul  9 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210709.54eaaf82:
  * Document how to create the osc alias for the local CI instance
* Thu Jul  8 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210708.ecafba4f:
  * Test accepting a package from a devel project
  * Initial testcase for check_source.py
  * Small code reorganization in core.py
* Thu Jul  8 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210708.c80ddc2c:
  * Rename DVD-Backports to DVD-Backports-Incidents
* Thu Jul  8 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210708.b73d663f:
  * Add missing libraries to testenv image to run check_source.pl
* Wed Jul  7 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210707.82fd000a:
  * osclib/conf.py: Don't use same config for openSUSE:Leap:15.3:ARM and :Images
* Mon Jul  5 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210705.8922fa23:
  * Revert "Exclude .open-build-service/ from docker, flake8, and git."
  * Update exclude section in .flake8
* Fri Jul  2 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210702.b265c66f:
  * Staging: add 'rebase' as an alias to the 'freeze' command
* Fri Jul  2 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210702.d0f59b78:
  * Explain how to run a single test
  * Allow adjusting the exposed OBS port in Docker Compose
  * Replace Coveralls badge with Codecov one
  * Add some notes about CI
  * [CI] Expose port 3000 of the api service
* Thu Jul  1 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210701.9c0e048a:
  * paralelize running linter
  * use proper badge for ci
* Wed Jun 30 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210630.2c4d242c:
  * Use configparser from python3-base.rpm
  * Make the usage message more helpful
  * Add a meaningful one line description
  * Improve instructions for Readme / Development
* Wed Jun 30 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210630.a3151f0b:
  * update version of gh actions checkout action to speed up ci and codecov to be uptodate
* Fri Jun 25 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210625.f030cb17:
  * Setup for SLE15 SP3 Quarterly Update
* Wed Jun 23 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210623.f07ad86d:
  * check_source.py: Add the reason why a review was added (e.g. which whitelist warning was suppressed)
* Wed Jun 23 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210623.7899db11:
  * pkglistgen opensuse gocd: remove 15.3 pkglsitgen and updaterepos
* Tue Jun 22 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210622.3d879f53:
  * gocd: change how scripts are retrieved
* Tue Jun 22 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210622.b376746f:
  * accept_command: use the value of attribute to set ProductVersion if always_set_productversion_to option presents
* Mon Jun 21 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210621.a11cc821:
  * gocd/totestmanager.gocd.yaml: Update list of projects
* Mon Jun 21 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210621.f05d1f9e:
  * Switch off abi checker as it keeps failing
* Fri Jun 18 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210618.8e162872:
  * ttm/manager.py: Also find versions from plain tarballs
  * ttm/publisher.py: If force is set, ignore QA and other checks
* Fri Jun 18 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210618.4c407e7a:
  * Use codecov for coverage - easier GA integration
  * Increase timeout to 40 minutes
  * Remove travis CI
  * pkglistgen: Automatically merge old update repos
  * pkglistgen: Add a way to merge files from 000update-repos
* Fri Jun 18 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210618.9a8de07f:
  * Create ci-test.yml
* Fri Jun 18 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210618.660e75bd:
  * gocd: plug release in BCI pipeline
* Wed Jun 16 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210616.02b53c6b:
  * Fix Leap:15.3:ARM which was broken when Leap:15.3:ARM:Images has been introduced
* Mon Jun 14 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210614.d271a1a3:
  * Add 15-SP4 setup
* Mon Jun  7 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210607.ed56c252:
  * add bot for ARM:Images
  * Support Leap:15.3:ARM:Images as well
* Mon Jun  7 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210607.9b86fb95:
  * Enable pkglistgen for openSUSE:Factory:ARM rings
* Fri May 28 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210528.983c167a:
  * Add Backports to the updates being tested
* Fri May 28 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210528.c321aed8:
  * check_source.py: Decline if source_revision not set
* Thu May 27 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210527.973d7cea:
  * gocd: add SLE_BCI packagelist generation
* Thu May 20 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210520.9bd9aeb2:
  * Remove obsolete Leap 15.1
* Thu May 20 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210520.fdb7ec1d:
  * Update e-mail address for Factory:ARM mailing list
* Mon May 10 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210510.0d5a9cfe:
  * pkglistgen: Force outdir for the checkouts
* Fri May  7 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210507.a59ce12e:
  * Do rebuilds for Step
* Thu May  6 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210506.bdf351d3:
  * gocd: fix incorrect yaml for BCI
* Wed May  5 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210505.9888ea18:
  * add packagelist and release package bots for BCI
* Thu Apr 29 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210429.5470e3d1:
  * Update email address for Factory mailing list
* Mon Apr 26 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210426.57b78c17:
  * Fix for wrong indented json in #2537
* Thu Apr 22 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210422.ab2264e1:
  * Drop the old path for releasing SP3:GA/sles15-image
* Tue Apr 20 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210420.1c2151c4:
  * Update check_source.asciidoc
  * Update testing.asciidoc
  * Update staging.asciidoc
  * Update staging.asciidoc
  * grammar-gender
* Fri Apr 16 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210416.730e78b0:
  * Add automated rebuilds for step Backports
* Thu Apr 15 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210415.4a57f7a7:
  * gocd: Drop obsolete projects, fix whitespace
* Tue Apr 13 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210413.d92c1396:
  * Remove release from images-ndb repository
* Thu Apr  8 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210408.3990fecd:
  * Remove comment inside script
* Thu Apr  8 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210408.89c0136c:
  * Release SUSE:SLE-15-SP3:GA sles-image into :TEST and :PUBLISH
* Thu Apr  8 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210408.b593b12c:
  * Revert pkglistgen: ignore bootstrap_copy repo
* Tue Apr  6 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210406.a75bf5b7:
  * Update MicroOS IBS project (MicroOS51) in botmaster
  * pkglistgen: don't die on unset pkglistgen-ignore_repos
* Tue Apr  6 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210406.0e9a3e52:
  * Revert "Add bot for Camerleon project"
* Tue Apr  6 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210406.1055d062:
  * legal import: Scan openSUSE projects more often
  * legal-auto: Reopen obsolete reviews while scanning projects
* Tue Apr  6 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210406.6b65b00a:
  * pkglistgen: ignore bootstrap_copy repo
* Tue Apr  6 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210406.2fec2dbe:
  * pkglistgen: After solving check all packages listed
* Tue Mar 30 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210330.e6a45eb4:
  * legal: Only wait 2 hours for legal reviews for openSUSE:Factory
* Wed Mar 24 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210324.a747e490:
  * Add release to PUBLISH for containers
* Fri Mar 19 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210319.fd0124a9:
  * Add missing repos for 15.3
  * Add Leap 15.3 Maintenance configuration
* Fri Mar 19 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210319.de08ea9d:
  * findfileconflicts: hardcode exception for glibc and bash
  * handle usrmerge
* Mon Mar 15 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210315.d6cd0125:
  * Build containerfile and images repos against each other
  * Add containerfile_products type to totest-manager
  * Add a containerfile repo to adi stagings
  * Make Dockerfile builds pass check_source.py
* Mon Mar 15 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210315.167397b8:
  * Add Leap:15.3:ARM to test armv7 Step:15
* Thu Mar 11 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210311.1b7e79b9:
  * build-fail-reminder: don't use cgi.escape, but rather html escape the fixed string directly
* Wed Mar 10 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210310.18652691:
  * metrics: add sample Apache vhost config
  * metrics: accept more flavors
* Wed Mar  3 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210303.440e1a88:
  * Monitor release process
* Wed Mar  3 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210303.72b45750:
  * adi: stage Non-Ring delete requests in adi projects
* Mon Feb 15 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210215.e68b5e0b:
  * Fix repo state error handling in pkglistgen
* Wed Feb  3 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210203.2caa5a9e:
  * Switch to python3 shebang
* Fri Jan 22 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210122.29b776fd:
  * Calculate the i586 DVD as i686 package set
* Tue Jan 19 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210119.d564b3d0:
  * Accept: Don't crash on actions that aren't submit/delete
* Tue Jan 19 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210119.75c001c9:
  * pkglistgen: Check the return code of Popen calls
* Mon Jan 18 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210118.bb3c6e1c:
  * pkglistgen: Allow to set require_all for some groups to disable ignore
  * Update aggregate.php
* Tue Jan  5 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210106.deab50eb:
  * fix typo in pkglistgen.leap.15.3
  * monitor: remove Jump from monitor and add Backports to monitor
* Mon Jan  4 2021 opensuse-releaseteam@opensuse.org
- Update to version 20210104.7b7d4aa8:
  * gocd: enable staging bot and staging installcheck on SLE15 SP3 Backports
* Fri Dec 18 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201218.7cd9d749:
  * rebuild-trigger: run project-installcheck on SLE15-SP3 Backports
* Fri Dec 18 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201217.06e44bca:
  * Fix typo in the source checker
* Wed Dec 16 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201216.b9ce7bf1:
  * Also add required checks to adi stagings after adding architectures
* Wed Dec 16 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201216.bb412fe4:
  * Fix staging-installcheck.py being ignored if i586 is present
* Tue Dec 15 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201215.76b63b74:
  * Enable TTM for openSUSE:Leap:15.3:Images
* Fri Dec 11 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201211.df53c462:
  * check_source: mode='manual' is permitted in _service files
  * check_source.pl: One .changes file per package is enough
  * check_source: Advertise the usage of 'osc service runall $FOO'
  * Don't produce directory conflicts of ghost files
* Thu Dec 10 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201210.049f70f7:
  * Add 'kernel-64kb' to the list of kernel packages to reduce kernel spam
* Wed Dec  9 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201209.32338511:
  * Add bot for Camerleon project
* Wed Dec  2 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201202.0bafe324:
  * Add schedule for Leap 15.1, 15.2 and 15.3
* Wed Dec  2 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201202.7103cd65:
  * Use string instead of byte stream for configparser
  * Rename ConfigParser to configparser
  * Replace sys.maxint with sys.maxsize
* Fri Nov 27 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201127.8335cbff:
  * SLE15SP3: Release images-ndb to :TEST
* Mon Nov 23 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201123.5ffdcc9e:
  * Also release sles15-image to :ToTest in SLE15.SP3.ImagesManual
  * Don't publish sles15-image as part of Release.Images.To.Publish
* Mon Nov 23 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201123.10a2268e:
  * Release and publish SUSE:SLE-15-SP3:Update:CR/sles15-image as well
* Thu Nov 12 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201112.4a3abc91:
  * metrics: Update product pattern to match Leap 15.2
* Mon Nov  2 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201103.e77961f0:
  * pkglistgen gocd: rename Pkglistgen.openSUSE_Leap to avoid the dup'ed key
* Mon Nov  2 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201102.21e0b914:
  * Leap 15.3: Jump project discontinued but Leap 15.3 started
* Fri Oct 30 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201030.620b9480:
  * Merge common code of SP1 and SP2
  * Add back setup for 15SP1 quarterly updates
* Thu Oct 22 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201022.3934deb8:
  * pkglistgen gocd: remove wrong -s target option for Leap MicroOS
* Thu Oct 22 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201022.fccc3b92:
  * pkglistgen: add Leap 15.2 MicroOS back to pipeline
* Wed Oct  7 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201007.ccac00af:
  * Fix MQ timeouts in rabbit-repoid
* Wed Oct  7 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201007.706b6713:
  * Do not try to push empty changes in rabbit-repoid
* Wed Oct  7 2020 opensuse-releaseteam@opensuse.org
- Update to version 20201007.c336e60c:
  * Check git errors in rabbit-repoid
* Wed Sep 30 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200930.488b0fc7:
  * gocd: Run ttm for openSUSE:Jump:15.2:Images
* Wed Sep 23 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200923.c33e6a9e:
  * Change SP2 QU job to run on Thursday
  * Remove 15SP1 QU settings
  * Add setup for 15SP2 quarterly updates
* Mon Sep 21 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200921.26408ca6:
  * Dashboard: be more precise in percentage to avoid to display 'done' with few jobs remaining
* Fri Sep 18 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200918.4b77ae84:
  * Add a readme about TTM
* Wed Sep  9 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200909.0bb0f971:
  * TTM: Ignore arch check for multibuild containers
* Mon Sep  7 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200907.aa447872:
  * handle also GO_SERVER_URL when port is 8153
* Mon Sep  7 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200907.6c213476:
  * TTM: Verify that all successfully built products are mentioned in the config
* Thu Sep  3 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200903.6c099fbb:
  * Dashboard: Handle 'broken' state for OBS
* Thu Sep  3 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200903.1a4894ef:
  * Add release to TEST and PUBLIC for MicroOS
* Thu Sep  3 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200903.c28f1293:
  * added a 30 minute timeout to the openqa run
* Wed Sep  2 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200902.771d1db6:
  * Add the ARM rings
* Wed Sep  2 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200902.aea8d9fa:
  * Dashboard: Handle 'locked' state for OBS
* Wed Aug 26 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200826.3b33c0a6:
  * Revert "Retrieve packages download statistics"
* Wed Aug 26 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200826.f6a30eed:
  * Bugfixes
  * [metrics-access] Fix packages path
  * Optimize searching access logs
  * Parse and count packages
* Thu Aug 20 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200820.30a5ec58:
  * bugowner.py: fix typo
  * bugowner.py: switch to python3
* Tue Aug 11 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200811.7a216cd0:
  * fix tests
  * repoid monitor: monitoring events from openSUSE:Jump
  * gocd: remove Leap config and enable Jump project to pipeline if needed
  * conf: general config for openSUSE Jump
  * TTM: enable Jump project on totest manager and remove old main project
* Tue Aug 11 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200811.41fe9c2f:
  * Add MicroOSNG setup
* Mon Aug 10 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200810.6e220f02:
  * Remove SLE-15-SP2 setup
* Thu Jul 16 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200716.558f783b:
  * metrics/grafana/openqa: Add openSUSE Leap 15.1 and 15.2
  * factory-auto: add opensuse-review-team on submits to NonFree
  * fixed a whitespace
  * skip SUSE:Channel files harder
* Tue Jul 14 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200714.b826963d:
  * fix cutting off part of a stagings name
* Thu Jul  9 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200709.cef2425d:
  * Merge check images and release to TEST for 15-SP3
  * Add SLE15-SP3 setup.
* Wed Jul  8 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200708.6a13cb44:
  * WSL: Add output of gocd/generate.sh
  * Add openSUSE:Leap:15.2:WSL under gocd control
* Mon Jul  6 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200706.c31bc8f1:
  * Update version attribute also in o:F:RISCV
* Sun Jul  5 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200705.5aedaf1c:
  * Add pkglistgen instance for openSUSE:Factory:RISCV
  * Add rebuild trigger for openSUSE:Factory:RISCV
* Thu Jun 25 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200625.d66b16f2:
  * Forgot to add the erb file too...
* Tue Jun 23 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200623.49cd77b8:
  * gocd: pkglistgen for MicroOS
* Wed Jun 10 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200610.3c1b0160:
  * Fix flake error F541 in tests/origin_tests.py
  * Fix osc.core.repository_path_expand
* Sun May 17 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200517.e09639bc:
  * ignore packages that just have _channel inside
* Fri May 15 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200515.13e2fbe2:
  * Fix crash in project-installcheck if there are no packages in the pra
* Fri May 15 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200515.bfa069ee:
  * Trigger rebuilds on zSystem as needed
* Tue May  5 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200505.cd067a94:
  * gocd: add 15.2 MicroOS ttm
* Tue May  5 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200505.1e6677e6:
  * Update some ttm documentation
* Sat May  2 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200502.027727cc:
  * Check for 'weakremovers.inc' in in group_dir before attempting to move it
* Sat May  2 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200502.4cba11ba:
  * Fix httpretty using tests
* Thu Apr 30 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200430.fca4401c:
  * dist: drop bogus python-enum34 dependency
* Thu Apr 30 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200430.56213c5d:
  * Update docker to run tumbleweed container
  * miniobs: Fix database setup for rails 6
* Thu Apr 30 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200430.a354092d:
  * stagingapi: do not add multibuild flavor package to the ring package list
  * stagingapi: allow multibuild package spreads across ring
* Wed Mar 25 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200325.77a14833:
  * Wipe all multibuild flavors for delete requests
* Tue Mar 24 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200324.20869549:
  * Allow to disable the check of delete requests per config
* Fri Mar 20 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200320.2e3dc21c:
  * Fix check_source for repository specific package names
* Thu Mar 19 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200319.cdc271c2:
  * Support 'required' field for packages
* Thu Mar 19 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200319.37498292:
  * Work around OBS issue 8994
* Wed Mar 18 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200318.74ecff5c:
  * Use the new API from openqa to sync the right repositories
* Tue Mar 17 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200317.91ee0f41:
  * Take the interesting repos from the output for now
* Mon Mar 16 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200316.683bee4a:
  * Sync script for obs_rsync
* Mon Mar 16 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200316.08c8cd5d:
  * No longer trigger obsrsync directly from rabbitmq messages
* Mon Mar 16 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200316.ed7d3ce2:
  * Adopt fixture to changes in obs' xml output
  * Split the work done in rabbit-openqa into smaller chunks
* Tue Mar 10 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200310.d98dd909:
  * Switch metrics to use python3
* Tue Mar 10 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200310.e25d3bfb:
  * Add error message in case upload fails
* Fri Mar  6 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200306.ef1064e7:
  * Stop repo monitor earlier: 30 hours might be a little excessive
* Thu Mar  5 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200305.63aa406d:
  * Let the rabbit monitors run for 3 hours instead of one
  * Make rabbit-repoid more stable
  * cleanup_rings: fix python3 bytes/string type error
  * requestfinder: print all actions
* Tue Mar  3 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200303.fbc0a9e0:
  * Allow overriding the prefix for setrelease
* Mon Mar  2 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200302.0c376420:
  * Replace declined requests
* Mon Feb 24 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200224.f8ecad1d:
  * Make images release to TEST generic
* Mon Feb 24 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200224.7a060087:
  * Fix typos
  * Some refactoring
  * Add support for DoD repos to installcheck
* Thu Feb 20 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200220.3b5f8650:
  * fcc_submitter: update to 15.2
* Wed Feb 19 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200219.c0ab2c6b:
  * stagingapi: replace staging project URL to staging workflow on adi project
  * ttm: ignore parallel_failed jobs, but still list as failed
* Mon Feb 17 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200217.a9f37804:
  * Release FTP repos before ISOs
* Fri Feb 14 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200214.147dc94c:
  * use release team list also for build fails
* Wed Feb 12 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200212.07272268:
  * ttm: add appx support for WSL images
* Mon Feb  3 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200203.fe919b2b:
  * Added new images in 15-SP2 release tool config
  * dashboard: add groupid to have proper link for aarch64, powerpc, s390x
  * dashboard: fix openQA link
* Fri Jan 31 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200131.e3c26df9:
  * Staging accept: No longer set the version in .product files on accept
* Fri Jan 31 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200131.ff898552:
  * Unify the handling of standard and images repository
* Fri Jan 31 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200131.1f26d7bc:
  * Dashboard: add ARM:Live
* Fri Jan 31 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200131.38632736:
  * dashboard: Add openQA results
  * Add the same link to openqa than what is on obs_factory
  * Dashboard: link the product package
* Thu Jan 30 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200130.1ad5de89:
  * dashboard: Output the time in UTC
* Thu Jan 30 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200130.cb660d72:
  * Add timestamp to the page for update info
  * Add versions to the dashboard
* Thu Jan 30 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200130.063dd72a:
  * One more fix for the dashboard generator config
* Thu Jan 30 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200130.1335e55b:
  * Fix indentation of gocd config
* Thu Jan 30 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200130.02d3038b:
  * Rapid prototype of a Factory dashboard
* Wed Jan 29 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200129.7a3a7a36:
  * Use The openSUSE release team email for announcer
* Wed Jan 29 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200129.fce860f3:
  * Actually subscribe to the repo.build_finished event
* Tue Jan 28 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200128.8bd11b00:
  * Notify the obs_rsync plugin already when the scheduler is finished
* Mon Jan 20 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200120.1be035c9:
  * Drop openSUSE:Leap:15.0:Images from ttm list
* Mon Jan 20 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200120.0e07b678:
  * compare_pkglist: update to Leap 15.2 and SLE15 SP2
* Thu Jan 16 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200116.13dedee6:
  * Fix data for openQABot
* Wed Jan 15 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200115.aed727d8:
  * Remove data for EOL Leap_15.0
* Tue Jan  7 2020 opensuse-releaseteam@opensuse.org
- Update to version 20200107.c673e572:
  * Added new packages in 15-SP2 release tool
* Fri Dec 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191227.8630e6eb:
  * abi-checker: add prune command
  * abi-checker: recognize staging
  * abi-checker: fix it
* Tue Dec 17 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191217.e62caa7a:
  * findfileconflicts: Ignore kernel installed certificates in /etc/uefi/certs
* Tue Dec 10 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191210.9a8ba5b5:
  * More flake8 cleanups
  * Sanitize read rebuild yaml
  * Avoid crash when --store is not specified on save
* Tue Dec 10 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191210.10a6a78a:
  * stagingapi: StagingAPI doen't initial api itself
* Tue Dec 10 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191210.1a22a59c:
  * Do not return after adi project is accepted
* Tue Dec 10 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191210.4d7223f5:
  * Fix E203
  * Fix Flake E241
  * Avoid crash when store project isn't set
  * Fix installcheck for arm architectures
* Tue Dec 10 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191210.05e7447a:
  * Unify openqa checks over multiple ISOs
* Mon Dec  9 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191209.3bc7455e:
  * Always force accept into the API after checking for acceptable ourselves
* Fri Dec  6 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191206.7faf8118:
  * Have staging accept without argument take all green
  * Adopt help text for adi and accept
* Fri Dec  6 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191206.8f62f42c:
  * Don't take multibuild packages as subpackage of itself
  * Delete adi projects whenever we'd build disable them
* Thu Dec  5 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191205.67ccc5ae:
  * Improve _multibuild on accept
  * Extend tests for accept command
  * Add test for selecting multibuild with 2 spec
  * Remove support for ring2
* Thu Dec  5 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191205.24345fd4:
  * Pass the packages to rebuild in the POST's body
* Wed Dec  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191204.660ec7a7:
  * No longer close acceptable adi stagings
* Wed Dec  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191204.fe8bfc2c:
  * Align the announcer config with the template
  * Remove SLE12SP5 pipelines
  * Fix setprio command to use current API
* Wed Dec  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191204.0c6f43f4:
  * Reuse function of accept to check local links
* Tue Dec  3 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191203.2b4d57b2:
  * Only check for the rebuild project if cbuild has been set
* Fri Nov 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191129.411c0452:
  * staging-installcheck: Port to use XML to check delete requests
* Thu Nov 28 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191128.fe8e6c23:
  * check_source: query all repos if source info yields error
* Wed Nov 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191127.ae1b6ea1:
  * Fix all E22x errors
  * Some flake8 improvements
* Wed Nov 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191127.b07939d2:
  * Gracefully handle utf8 errors in installcheck
* Tue Nov 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191126.ac861592:
  * Remove linkpac code - the api is doing this (for the main package)
  * No longer ignore exceptions on unstage
  * Reenable the move test
  * stagingapi: Supersedes request is from the same project
  * Implement select --move by unselect+select
  * Repair repair command
  * Fix test suite for accept
  * Fix local links
  * Accept all stagings at the same time
  * remove links before accepting staging projects
  * Collect packages for all stagings and ready before accepting
  * Fix accept command to force accept through API
  * Move accept logic into accept_command
  * stagingapi: just superseding old obsoleted request
  * stagingapi: Don't do any change for excluded request
  * One more fix for unignore command
  * Reenable Locking (was disabled to ease testing)
  * Added release to PUBLISH for SLE15-SP2
  * Simplify request list calculation
  * Remove nonfree handling
  * stagingapi: Remove ignored requests part from rq_to_prj()
  * unignore: use dict iteration to matching the key
  * stagingapi: make sure the key of ignored_requests is integer type
  * Adopt to latest API changes
  * Disable splitter info until we find a better place to store it
  * Speedup select: Avoid supersede calculation if pointless
  * Fix unignore command
  * Remove comments tests for selecting
  * Fix check_tests - and reduce what we test there
  * Disable move test for now
  * Fix for frozen_enough test
  * Fix test_add_sr not to add twice
  * Fix rm_from_project test
  * Fix accept: first comment then cleanup (comments)
  * Run delayed job in the api container
  * Adopt accept_tests: Selecting no longer leaves a comment
  * stagingapi: Remove unneeded logging in get_package_for_request_id()
  * suppkg_rebuild: Move to new staging api
  * Fix supersede: we need to unstage always with new api
  * Fix for unselect with message: need to ignore afterwards
  * Fix for reviews (OBS issue is fixed)
  * Fix rebuild command
  * adi_command: another adi command fixes (#3)
  * Fix for staging-report
  * Fix for ignore command
  * Setup staging workflow in tests
  * Fix request list: the API was changed not to require status for obsolete
  * Fix for unselect command
  * Fix adi command for checks
  * Optimize request_id_for_package
  * Fixes for adi command
  * Fix for status checks in check command
  * Adopt to the new staging_projects api not revealing all infos
  * Some fixes for supersede and unselect
  * Started to fix the adi command
  * fix for staging-installcheck
  * Fix for unselect
  * Fix select command
  * Fix for check command
  * Work on adi command
  * Work on select command
  * Work on accept command - not yet done
  * Remove config command - the config isn't used any more
  * Remove update comments - are now obs history
  * Port unselect command to new API
  * Adopt check command to the new staging API
  * Register new adi projects
* Wed Nov 20 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191120.6abc7942:
  * Added release to PUBLISH for SLE15-SP2
* Mon Nov 18 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191118.0d0290f1:
  * Announcer config: use different Name's for :ARM
* Mon Nov 18 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191118.10c6c1cd:
  * Enable announcer for ARM for Tumbleweed, Kubic and MicroOS
* Mon Nov 11 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191111.509ec8f3:
  * QR update: submit with --yes
* Mon Nov 11 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191111.df3ac6a1:
  * Update the package list of SP1's quarterly updates
* Mon Nov 11 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191111.0f94671d:
  * unselect: only set origin-manager for whitelist cleanup
* Fri Nov  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191108.6b1fd618:
  * dist/obs/attribute-update: provide script for updating attribute definitions.
* Fri Nov  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191108.4d09eda6:
  * docs/origin-manager: provide comprehensive documentation.
* Fri Nov  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191108.2a32702b:
  * osclib/origin: policy_input_calculate(): s/unkown/unknown/.
  * dist/obs: remove namespace from attribute names.
* Fri Nov  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191108.03a954ae:
  * osclib/origin: origin_update(): support blacklist patterns for initial updates.
  * osc-origin: extract osrt_origin_update_packages().
* Fri Nov  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191108.a83e40e0:
  * osclib/origin: origin_history(): include non-annotated requests.
* Fri Nov  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191108.a0488c3f:
  * osclib/origin: origin_annotation_dump(): include pending information.
* Fri Nov  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191108.d271224d:
  * osclib/core: request_action_list_maintenance_incident(): support another form.
  * osclib/conf: configure maintenance staging review options for origin-manager.
  * osclib/origin: add maintenance staging equivalent reviews to pending_submission_allowed_reviews.
  * osclib/origin: drop repo-checker from pending_submission_allowed_reviews.
  * osclib/origin: provide pending_submission_allowed_reviews_update option.
  * osclib/origin: reviews_filter_allowed(): support negation rules.
  * osclib/origin: provide reviews_filter_allowed().
  * osclib/origin: project_source_pending(): include psuedo incident review.
  * osclib/core: reviews_remaining(): provide incident_psuedo option.
* Fri Nov  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191108.c7e1800d:
  * origin-manager: indicate the decision may be overridden via command.
* Fri Nov  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191108.558e9d65:
  * userscript/origin: handle HTTP failure.
* Thu Nov  7 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191107.9503a04b:
  * tests/OBSLocal: randomString() use fixed length of 2.
  * tests/OBSLocal: Request: print message once created.
  * dist/ci/docker-compoose-test: include which test file is be executed.
  * osclib/origin: provide automatic update mode controls.
  * osclib/core: request_create_submit(): provide frequency option.
  * osclib/core: request_create_submit(): provide supersede flag.
  * osclib/core: request_action_simple_list(): include full history.
  * osclib/core: provide package_source_{changed,age}() functions.
  * osclib/core: provide attribute_value_delete().
  * osclib/core: support package in attribute_value_{load,save}() functions.
* Thu Nov  7 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191107.3dd0fbe7:
  * osc-origin,osclib/origin_listener: sync package kind logic.
* Thu Nov  7 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191107.79679520:
  * Do a rebuildtrigger for Leap 15.2 ARM as well
* Thu Nov  7 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191107.b147cf2b:
  * osclib/core: package_kind(): require releasename to differ from package for maintenance_update.
* Thu Nov  7 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191107.3c156843:
  * web/origin-manager: paginate request history.
* Wed Nov  6 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191106.547e954a:
  * osclib/origin: origin_update_pending() utilize project_remote_prefixed().
  * osclib/core: provide project_remote_prefixed().
* Tue Nov  5 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191105.9f80ea19:
  * origin-manager: origin_maintainer_review_ensure(): check for devel meta.
* Tue Nov  5 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191105.931b7604:
  * osclib/origin_listener: consume package deletes.
  * tests/origin_tests: provide test for new package submission.
  * osc-origin: osrt_origin_update(): include potential new packages.
  * osclib/origin_listener: update packages that do not exist in target project.
  * osclib/origin: provide origin_updatable_initial().
  * osclib/origin: origin_update(): support initial submissions.
  * osclib/origin: provide automatic_updates_initial origin config option.
  * osclib/core: request_create_submit(): provide ignore_if_any_request.
* Tue Nov  5 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191105.bfaa89d7:
  * requestfinder: ConfigParser has been renamed to configparser in python3
* Tue Nov  5 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191105.7e560478:
  * Remove dependency from cache to config
  * Remove old python2 code from cache
* Tue Nov  5 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191105.efee5429:
  * Fix conflicts/obsoletes while picking dependencies
* Mon Nov  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191104.de4ff14a:
  * tests/origin_tests: provide split product origin tests.
  * tests/origin_tests: provide devel origin tests.
  * tests/origin_tests: provide harness and basic tests.
  * tests/OBSLocal: provide randomString() for ensuring tools not name dependent.
  * tests/OBSLocal: provide assertReviewBot() for review script workflows.
  * tests/OBSLocal: submit_package(): provide optional project argument.
  * tests/OBSLocal: StagingWorkflow: provide and utilize remote_config_set().
  * tests/OBSLocal: Request: extract change_state() from revoke.
  * tests/OBSLocal: tearDown(): ensure user is Admin before cleanup.
  * tests/OBSLocal: StagingWorkflow: stop hiding valid errors.
  * tests/OBSLocal: correct python 3 port attempt for subprocess output handling.
  * tests/OBSLocal: provide osc_user_pop() to make user switching cleaner.
  * tests/OBSLocal: osc_user(): indicate when switching user.
  * tests/OBSLocal: disable request cache during testing.
  * osclib/origin_listener: ultilize origin_updatable_map() include_self option.
  * osclib/origin: origin_updatable_map(): provide include_self option.
  * osclib/origin: origin_update() generate change_devel requests.
  * origin-manager: handle change_devel request review.
  * origin-manager: when appropriate simulate devel project during source change review.
  * origin-manager: provide devel_project_simulate_check().
  * origin-manager: provide devel_project_simulate_check_command().
  * origin-manager: provide and utilize origin_maintainer_review_ensure().
  * osclib/origin: policy_input_calculate(): handle change from None origin.
  * osclib/origin: allow for identical source if origin changed.
  * osclib/origin: provide and utilize origin_devel_projects().
  * osclib/origin: provide origin_devel_project() and utlize.
  * osclib/origin: provide origin_devel_project_requests().
  * osclib/origin: provide devel_project_simulate enterable.
  * osclib/origin: require origin key in origin_annotation_load().
  * osclib/origin: provide origin_workaround_strip().
  * osclib/core: provide request_state_change() and utilize.
  * osclib/core: provide request_create_change_devel() RequestFuture.
  * osclib/core: provide package_role_expand() to expand package role to users.
  * osclib/core: provide project_role_expand() to expand project role to users.
  * osclib/core: provide meta_role_expand() to expand a role to users given meta.
  * osclib/core: break apart request_age() to provide request_created().
  * osclib/cache: provide osrt.cache.disable config option to disable cache.
  * dist/ci/flake-extra: include origin_listener in product check.
  * ReviewBot: include request description in search for comment commands.
  * ReviewBot: rework override check to operate on actions.
  * osclib/comments: provide request description as comment.
* Mon Nov  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191104.75836fec:
  * Start searchd in api container
  * Add a dummy user/password to the openSUSE:Factory section
  * Make exceptions easier to debug in OBSLocal
* Mon Nov  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191104.3d0d7312:
  * build-fail-reminder: Fix indentation of emails
* Tue Oct 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191029.330f0b1b:
  * Use python3 in shebang to not pull in python2 dependency
* Mon Oct 28 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191028.3162cc5b:
  * Remove openqa-obs bot data for SLE
* Thu Oct 24 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191024.46e12504:
  * add pkglistgen and stuff for Leap staging F
* Wed Oct 23 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191023.521a30a0:
  * Add a review user for factory-auto so it can be overridden in SLE
* Tue Oct 22 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191022.68be1855:
  * Fix check_source on public cloud images
* Tue Oct 22 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191022.d893565b:
  * Convert factory-package-news-web.py to python3
* Mon Oct 21 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191021.8bb85c5f:
  * Fix test plan URL for 15.2
* Sat Oct 19 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191019.a97469df:
  * conf.py: remove delreq-review default setting
  * StagingAPI: complex delete requests are no longer used
* Sat Oct 19 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191019.24a8cf2b:
  * testenv: install shadow for useradd
* Thu Oct 17 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191017.180e4464:
  * userscript/origin: run in no-conflict mode.
* Thu Oct 17 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191017.16ae84df:
  * suppkg_rebuild: decode bytes before comparing
* Thu Oct 17 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191017.23d4c737:
  * build-fail-notification: Fix how we address the user
* Wed Oct 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191016.ad934285:
  * Added Vagrant box in 15-SP2 release tool
* Wed Oct 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191016.455c1428:
  * build-fail-reminder: update api path to projects/:project/status
* Tue Oct 15 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191015.0c4d62c5:
  * adi: build kiwi images in a /images repository
* Tue Oct 15 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191015.35d7bf0c:
  * pkglistgen: fix wrong parsing way on pkglistgen-locale
* Mon Oct 14 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191014.e7be100b:
  * rebuild_support: enable Leap 15.2
* Tue Oct  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191008.7451a6ad:
  * osc-staging,issue-diff: open temporary file in write without binary mode.
* Mon Oct  7 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191007.6c39d95d:
  * BuildFailReminder: fix inversion of to and fullname
* Mon Oct  7 2019 opensuse-releaseteam@opensuse.org
- Update to version 20191007.c1cb6a0c:
  * Replace kiwi-templates-SLES15-JeOS with kiwi-templates-JeOS. Package was rename in SLE-15-SP2.
* Mon Sep 30 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190930.3d04dde8:
  * check_source: avoid crash if filename is not set
* Fri Sep 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190927.6cbf1e6a:
  * Enable images repo once 000product was updated
* Thu Sep 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190926.456b203a:
  * Kill review bots if they didn't output anything for 30 minutes
* Thu Sep 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190926.40a88ace:
  * rebuildpacs: Ignore order of problems
* Thu Sep 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190926.6ed04ab7:
  * osclib/origin_listener: change from package.update to package.commit event.
* Thu Sep 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190926.1942065b:
  * osclib/origin: origin_annotation_load(): only return dict annotation.
  * osclib/origin: origin_annotation_load(): only consider accepted reviews.
  * osclib/core: review_find_last(): provide states filter.
* Thu Sep 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190926.b8ec607f:
  * origin-manager: utilize ReviewBot.request_age_wait().
  * ReviewBot: provide request_age_wait().
* Thu Sep 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190926.0acfbc28:
  * osclib/core: rename request_action_single_list() to request_action_simple_list().
  * osclib/core: switch request_action_single_list() users to request_action_list().
  * osclib/core: request_action_single_list(): handle miltiple actions.
  * osclib/core: request_action_single_list(): exclude sourced requests.
* Wed Sep 25 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190925.438b38fc:
  * gocd/checkers: revert Origin.Manager.Update frequency back to daily.
* Wed Sep 25 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190925.8a0e6ed3:
  * check_source: when kind is None then it can be a new package
* Wed Sep 25 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190925.9af682c9:
  * check_source: don't enforce name for kiwi images
* Tue Sep 24 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190924.e9a2774a:
  * origin-manager: skip package of type not (None or source).
  * check_source: decline package of kind not (meta or source).
  * check_source: replace meta check with package_kind() == meta.
  * osclib/core: package_kind(): include underscore as meta prefix.
* Tue Sep 24 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190924.faf6a82e:
  * origin-manager: drop sub-classed CommandLineInterface as parent will suffice.
* Tue Sep 24 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190924.96ca2080:
  * osclib/stagingapi: rebuild_check(): utilize -4096 offset for build log.
  * osclib/stagingapi: buildlog_get(): support negative offset.
* Mon Sep 23 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190923.83f1d51c:
  * osclib/cache: utilize rmtree_nfs_safe().
  * osclib/util: provide rmtree_nfs_safe().
* Fri Sep 20 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190920.155606e3:
  * factory-package-news: fixes for Tumbleweed
* Thu Sep 19 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190919.8df44507:
  * gocd/monitors: *.OriginManagerUpdate: set timeout to 10 minutes.
* Thu Sep 19 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190918.c185be8c:
  * ReviewBot: add_review(): handle 403 as expected when superseded/rovoked.
* Thu Sep 19 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190918.abb40adc:
  * ReviewBot: _set_review(): handle review being revoked or superseded.
* Thu Sep 19 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190918.abd6f65f:
  * osclib/core: request_create_delete(): utilize pusedo osc.core function.
  * osclib/core: provide create_delete_request().
* Wed Sep 18 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190918.d0e2b71e:
  * osclib/origin_listener: skip patchinfo packages.
* Wed Sep 18 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190918.1d4c6836:
  * osclib/origin_listener: indicate when checking for update to package.
  * osc-origin: osrt_origin_update(): include thread name in logger format.
  * osc-origin: osrt_origin_update(): remove duplicate logging import.
  * osclib/origin_listener: utilize apiurl as thread name for remote listener.
* Fri Sep 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190913.9d119079:
  * gocd: remove PackageHub15SP1.Manager42 as project is locked.
* Fri Sep 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190913.d83c08a9:
  * gocd: rabbit-openqa needs a config file installed
* Thu Sep 12 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190912.9c45fc37:
  * osclib/origin_listener: start additional listeners for remote origins.
  * osclib/origin_listener: change skipping log message to mention origin.
  * osclib/origin_listener: provide origin_updatable_map().
* Thu Sep 12 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190912.f5a9538d:
  * check_source: only log as info if we can't get build log. This needs a more general solution but for now we'll reduce the level to not pollute the log
* Thu Sep 12 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190912.6dd6428d:
  * Move the monitors to a agent type of their own
* Thu Sep 12 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190912.49029a0e:
  * gocd/checkers: reduce Origin.Manager.Update frequency to weekly.
  * gocd/monitors: provide OriginManagerUpdate pipelines for listener.
  * osc-origin: update: provide --listen option.
  * gocd: utilize `origin update` without the need to indicate a project.
  * osc-origin: support invoking update without a project.
  * osclib/origin: provide origin_updatable_map().
  * osclib/origin: provide origin_updatable().
  * dist/obs: provide OSRT:OriginUpdateSkip attribute definition.
  * osc-origin: utilize osclib.core.RequestFuture.print_and_create().
  * osclib/core: provide RequestFuture.print_and_create().
  * osclib/core: provide RequestFuture.create_tolerant().
  * osclib/core: provide project_attributes_list().
  * osclib/core: project_attribute_list(): provide locked parameter.
  * osclib/core: project_attribute_list(): drop value parameter.
  * osclib/core: provide devel_projects().
  * Move PubSubConsumer to osclib.PubSubConsumer to allow for proper import.
* Wed Sep 11 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190911.d06fa8af:
  * build fail reminder: change mail address
* Tue Sep 10 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190910.9e21e757:
  * check_source: We need to use the user supplied REs to check if one of those match the list of entries we want to check
* Mon Sep  9 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190909.514a0f5e:
  * check_source: check_action_delete_repository(): simplify decline message.
  * check_source: check_action_delete_repository(): gate behind conf.mail-release-list.
  * Fix for python 3.6
* Mon Sep  9 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190909.2ca2925a:
  * osclib/request_splitter: utilize osclib.util.sha1_short() for encoding.
* Thu Sep  5 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190905.783a0674:
  * osclib/comments: command_find(): allow seperators after user.
* Thu Sep  5 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190905.b269bf48:
  * announce.gocd.yaml: escape the : in pipeline names
* Thu Sep  5 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190905.a24bcf0f:
  * Fix syntax of build-fail-reminder.gocd.yaml (endless story)
* Thu Sep  5 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190905.87de492d:
  * New basic test case
  * Don't use the webui for project status
  * Add little SMTP server that does not send mails for testing
  * Fix filename of the build-fail-reminder gocd config
  * Inline the mail text for the mailing list post - easier to map
  * Deduplicate the 2 mail sending functions
  * build-fail-notification: Mail to -factory after 4, dr after 6 weeks
* Wed Sep  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190904.1b3a6e1f:
  * osclib/core: request_action_key(): handle add_role/set_bugowner against project.
  * osclib/core: request_action_key(): include set_bugowner in top level condition.
* Wed Sep  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190904.41587803:
  * Continue python3 port of abichecker
  * Fix cron for openqa - it's supposed to run every 10 minutes
* Wed Sep  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190904.3d286c35:
  * Fix group name for the abichecker pipeline
* Wed Sep  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190904.f5eee13e:
  * Run abichecker on botmaster as well
* Wed Sep  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190904.fb0c4142:
  * oqamaint: fix more python3 issues and add _OBSOLETE=1
* Wed Sep  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190904.3ba02675:
  * also remove 42.3 from apimap
  * remove leap 42.3 add 15.2
* Wed Sep  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190904.0f9d84a0:
  * oqamaint: Take the default modules
* Wed Sep  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190904.72915933:
  * Python3 port of openqa maintenance bot
  * Run openqa-maintenance on botmaster as well
* Tue Sep  3 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190903.79a13ddd:
  * osclib/request_splitter: replace map() calls with loop and call.
* Thu Aug 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190829.72c1e9b4:
  * obs_operator: override HTTPServer.handle_error() to capture exceptions.
  * osclib/sentry: tag osc version.
  * osclib/sentry: provide dummy client.
  * osclib/sentry: sentry_client(): handle 0.11.x API change.
* Thu Aug 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190829.e912e9d2:
  * obs_operator: allow illegal cookie keys.
* Thu Aug 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190829.f74d0c1d:
  * osc-origin: update: indicate which package is being checked.
* Thu Aug 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190829.64280909:
  * web/origin-manager: allow a request to be diffed against a potential origin.
  * web/origin-manager: display the reason for a diff failure.
  * web/origin-manager: properly handle potential origin de-selection.
  * web/origin-manager: properly handle package de-selection.
  * web/origin-manager: clear table data before loading new data.
  * web/origin-manager: table_selection_set(): handle undefined table.
  * osclib/origin: origin_history(): expose source_(project,package,revision).
  * obs_operator: handle_package_diff(): expose target package and revision.
* Wed Aug 28 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190828.14971e2d:
  * osc-origin: capture exception with sentry to ensure they are reported.
  * check_source: check for target package not found when checking out.
  * ReviewBot: action_method(): drop request.type sentry extra in favor or action.key.
  * ReviewBot: simplify sentry_sdk initialization line since defined globally.
  * ReviewBot: provide request.id and action.key as sentry extras.
  * ReviewBot: action_method(): reduce sentry extra to filter(None, ...).
  * osclib/common: provide version_calcuate() and utilize by default.
  * osclib/git: provide describe().
  * osclib/git: remove unnecessary CacheManager import.
* Wed Aug 28 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190828.97f37e80:
  * gocd: use sep pipeline for build-fail-reminder
  * gocd: add Leap 15.2 announcer
  * checknewer.py: Use python3 shebang
* Wed Aug 28 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190828.30c7a9a2:
  * update_repo_handler: properly extract factory build string
* Tue Aug 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190827.7f92a226:
  * ReviewBot: reduce unhandled request type log message from error to info.
* Mon Aug 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190826.cf98ac16:
  * osclib/origin: origin_annotation_dump(): allow origin_info_new to be None.
* Thu Aug 22 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190822.bf48f33a:
  * check_source: add a review for the security team if there are warnings about missing whitelist entries and this is submitted to a project that has this check activated via attribute OSRT:Config (add to bad-rpmlint-entries)
* Tue Aug 20 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190820.b9c7635c:
  * gocd: *.Origin.Manager.Update: shift timer to account for seconds.
* Fri Aug 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190816.a1d076d0:
  * Revert "userscript/origin: hide request card when no OSRT:OriginConfig."
* Fri Aug 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190816.a7d8e044:
  * gocd: include :NonFree in OS.Origin.Manager.Update.
* Fri Aug 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190816.74b9714a:
  * osclib/sentry: expose environment configuration.
  * obs_operator: provide sentry_sdk integration.
  * osc-origin: provide sentry_sdk integration.
  * osc-staging: provide sentry_sdk integration.
  * ReviewBot: provide sentry_sdk integration.
  * osclib/sentry: provide initial sentry_sdk handling.
* Fri Aug 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190816.723e45f3:
  * userscript/origin: update release request handling.
  * userscript/origin: hide request card when no OSRT:OriginConfig.
  * userscript/origin: update request card column xpath.
* Wed Aug 14 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190814.0bb5815b:
  * Add rebuild trigger for openSUSE:Factory:ARM
* Tue Aug 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190813.1e238223:
  * gocd: duplicate Duplicated.Binaries check for Leap.
  * osclib/request_splitter: quick strategy: s/leaper/origin-manager/.
  * osclib/request_splitter: quick strategy: remove repo-checker from whitelist.
* Fri Aug  9 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190809.d73531de:
  * config/manager_42: drop openSUSE:Leap:15.2 config.
  * config/manager_42: drop SUSE:SLE-15-SP2:GA config.
  * gocd/checkers.suse: drop SLE-SP2.Manager42 job.
  * gocd/checkers.suse: add S15.SP2.Origin.Manager.Update job.
* Thu Aug  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190808.33b58c3b:
  * gocd/checkers.opensuse: wrap OS.Origin.Manager.Update with osc-origin install.
* Thu Aug  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190808.410ee514:
  * gocd: provide OS.Origin.Manager.Update.
  * osc-origin: provide update command.
  * osclib/origin: provide origin_update() to process updating single package.
  * osclib/core: provide request_create_delete().
  * osclib/core: provide request_create_submit() and RequestFuture.
  * osclib/core: provide message_suffix() and utilize in source_file_save().
* Tue Aug  6 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190806.914d1061:
  * osclib/origin: always include project link when fetching source history.
* Tue Jul 30 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190730.07c607e6:
  * Fix parsing of the --no-rebuild option
  * Don't pollute Factory dashboard package with powerpc infos
* Mon Jul 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190729.3d7e928c:
  * Fix leap 15.2: no problems in a repo wasn't tested :)
* Mon Jul 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190729.b3ec5fd8:
  * Filter out release numbers from problem output
* Mon Jul 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190729.e13c08e3:
  * Have the storage commit include the details what is was for
* Mon Jul 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190729.36a995fe:
  * Combine project_only and rebuild into check
* Mon Jul 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190729.9f0aee45:
  * Remove project_only for Factory and update projects
* Mon Jul 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190729.70133114:
  * Kill rebuildpacs.pl in gocd config
  * Rely on remote config and storage
  * Replace rebuildpacs.pl with project-installcheck functionality
* Fri Jul 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190726.df07bcc2:
  * Fix fvogt's fix by putting the project in the template
  * Fix staging bot to actually run on SP2
* Mon Jul 22 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190722.14459251:
  * Fix 15.1 images by introducing them again
* Mon Jul 22 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190722.35dabf52:
  * rabbit-openqa: Catch exceptions as PUT to openqa might result in 404
* Fri Jul 19 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190719.297ecd02:
  * factory-package-news: add aarch64 to search path
* Fri Jul 19 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190719.556387c2:
  * rabbit-openQA: Notify openQA about images repositories published
* Fri Jul 19 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190719.590e2886:
  * gocd: update 15.1 jobs to 15.2.
* Fri Jul 19 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190719.dada45f0:
  * config/manager_42: add previous Leap :Update and :NonFree 15.2.
* Thu Jul 18 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190718.c4bd3fef:
  * config/manager_42: update for Leap 15.2.
  * config/announcer: update for Leap 15.2.
* Tue Jul 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190716.f688158f:
  * origin-manager: always accept review when no OSRT:OriginConfig.
  * osclib/origin: correct import order.
  * osclib/origin: support pending source lookup against maintenance origin.
  * osclib/origin: handle nested annotation loading and support maintenance incidents.
  * osclib/core: provide a series of request list generators.
  * origin-manager: allow for skipping actions with no config when multiple.
  * ReviewBot: nest review messages by action key when multiple actions.
  * osclib/origin: origin_annotation_dump() provide raw option.
  * osclib/core: provide request_action_key().
  * osclib/core: enhance attribute_value_load() to handle boolean attributes.
  * osclib/core: provide action_is_patchinfo() from ReviewBot.
  * osclib/core: provide simplified search() and utilize.
* Fri Jul 12 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190712.4693df7f:
  * fix git repository and ensure return value is not ignored
* Fri Jul 12 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190712.238abef3:
  * dist: package /etc/grafana with the same mode as grafana
* Thu Jul 11 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190711.a1d38b79:
  * Fix SP2 config
* Wed Jul 10 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190710.282c7d6a:
  * Integrate installcheck into the sp2 pipeline
* Tue Jul  9 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190709.b3522549:
  * gocd: call generate.sh to fixup previous commit
* Tue Jul  9 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190709.ee061754:
  * gocd: add origin-manager to SLE checkers.
* Tue Jul  9 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190709.280c206c:
  * Run staging bot on SP2
* Mon Jul  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190708.7f37712f:
  * rebuildpacs: ignore issues of petsc:openmpi
* Mon Jul  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190708.365dacdd:
  * Add a script scan_baselibs.py to verifying importing 32bit binaries
* Fri Jul  5 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190705.052a5abc:
  * Fix some python2/python3 confusion with pkglistgen (for sle)
* Fri Jul  5 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190705.cd7cbf3e:
  * Change name of the staging pipeine - gitlab is historical
* Fri Jul  5 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190705.e743fab0:
  * Change target from SLE15-SP1 to SLE15-SP2
* Thu Jul  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190704.4e728eb8:
  * Run pkglistgen on sp2 stagings
* Thu Jul  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190704.500184e1:
  * Add the Package Hub 15 SP1 config to gocd
  * Add manager_42 configuration for Package Hub 15 SP1
* Thu Jun 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190613.dd9c9d45:
  * Run MicroOS & Kubic announcers at different times
  * Add MicroOS announcer instance
* Wed Jun 12 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190612.c85f9d9d:
  * Send Kubic announcements to correct mailinglist
* Thu Jun  6 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190606.a44d2886:
  * Readd whitelist for installcheck
* Thu Jun  6 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190606.bc7fb9f9:
  * Adapt packaging to the repo_checker.py split
  * Reduce repo_checker to check a project (and rename)
  * staging-installcheck: remove unused imports/variables
  * No longer ignore existing problems in adi projects
  * Add maintenance-installcheck next to staging-installcheck
  * Remove things no longer needed in repo_checker.py
  * Retire repo_checker.pl
* Thu Jun  6 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190606.e70c7624:
  * ttm: remove code to update pinned openQA comment
* Mon Jun  3 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190603.8b4ad7de:
  * Switch rebuildpac user to factory-maintainer
* Mon Jun  3 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190603.337648ba:
  * Remove --add from select command
* Mon Jun  3 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190603.49a5e95b:
  * Support licensedigger as reviewer for SUSE and openSUSE
* Mon Jun  3 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190603.c4a82136:
  * Switch reviewer factory-auto from group to user
* Sun Jun  2 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190602.850eca98:
  * Fix inner-staging links to use cicount=copy
* Sat Jun  1 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190601.2ec55156:
  * Extend namespace for SLE projects to monitor
* Sat Jun  1 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190601.882d97cd:
  * Merged special resources into staging-bot
  * Run origin manager reviews on gocd as well
* Fri May 31 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190531.3ecf53c9:
  * Reuse the staging-bot container for manager_42
  * The last leaper service from packagelists
* Fri May 31 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190531.716b6367:
  * Fix filename for repo checker's oscrc
* Fri May 31 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190531.6c5cf2ce:
  * Remove comments from gocd scripts
  * Trying to fix gocd error (on valid yaml)
* Fri May 31 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190531.537ad9df:
  * Fix the rebuild trigger config
* Fri May 31 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190531.d9b871ad:
  * Trigger rebuilds from gocd
* Fri May 31 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190531.e97e388d:
  * Add daily cleanup of Factory ignore list
* Fri May 31 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190531.dcc007cf:
  * dist/k8s: drop OBS operator origin-manager report cron.
  * systemd: drop OBS operator origin-manager report service/timer.
  * dist/k8s: provide OBS operator origin-manager cron.
  * systemd: provide OBS operator origin-manager cron service and timer.
  * osc-origin: provide cron command to automate lookup management.
  * osc-origin: do not update lookup information if project is locked.
  * osclib/core: provide project_locked().
* Fri May 31 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190531.2be3c4ee:
  * Add the tumbleweed URL to kubic config
* Fri May 31 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190531.cf0368b0:
  * Avoid crons triggered by git changes
* Fri May 31 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190531.93127927:
  * Fix support for multiple spec files
* Fri May 31 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190531.6f4621dc:
  * Run factory announcer on gocd
* Fri May 31 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190531.c354f8c8:
  * Export PYTHONPATH pointing to scripts checkout
* Fri May 31 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190531.9e35b50a:
  * Run one more leaper service from packagelists
* Fri May 31 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190530.f099b690:
  * osc-origin: add missing command descriptions.
  * Use a temporary directory for staging plugin
  * Fix projects import into legaldb
* Thu May 30 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190530.5db13774:
  * Remove check_dups plugin
* Thu May 30 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190530.8434e554:
  * Take pkglistgen from git - avoid deployment loop
* Thu May 30 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190530.ba617bfb:
  * Fix resource name for check duplicated config
* Thu May 30 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190530.39f3935d:
  * Do not crash on packages without spec file
* Thu May 30 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190530.6d93fc45:
  * Ignore current Factory duplicates
  * Run check_duplicate_binaries once in night
  * Report duplicated binaries in install check
  * Introduce osclib.core.duplicated_binaries_in_repo
* Wed May 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190529.5b46d05f:
  * Remove the 3 suffix - python3 is now everywhere
* Wed May 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190529.f2d0f953:
  * No need to install flake8, it's part of the image now
* Wed May 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190529.3d9c681d:
  * Update the list of devel projects from gocd
* Wed May 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190529.b9594ea6:
  * Run gnome review bot on gocd
  * Run suppkg_rebuild.py on gocd
* Wed May 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190529.d6937865:
  * Need to use http urls for obs to map it
* Wed May 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190529.54db9aca:
  * Fix staging rebuild on python3
  * Run build fail reminder on botmaster
* Wed May 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190529.291828b1:
  * Run devel projects reminder on gocd
* Wed May 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190529.7bf08ffb:
  * Run check_source_in_factory on gocd
  * Run check_maintenance_incidents.py on gocd
* Tue May 28 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190528.b16ab7c0:
  * gocd: Fix rendering of missing linebreak in README
* Tue May 28 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190528.0ad5ef7f:
  * Remove debug from autosubmit - so it actually submits
* Tue May 28 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190528.b8193352:
  * Run obs-autosubmit on gocd
* Tue May 28 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190528.0e7f9616:
  * virtually accept: fix string type handling in Python3
* Tue May 28 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190528.d7183777:
  * Run staging bot now in python3 as well
* Tue May 28 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190528.77612961:
  * legal-auto: Port prints to logger calls
  * legal-auto: the pickle path needs to be a file
* Mon May 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190527.8363fe38:
  * Move legaldb import of projects into gocd
  * Remove debug output left in ReviewBot
* Mon May 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190527.1a9bfa3a:
  * Run legal-auto on botmaster as well
* Mon May 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190527.a0475878:
  * Fix repo_checker path in gocd config
* Mon May 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190527.8328b5ec:
  * Run project_only reports on 15.1:Update and no longer on 15.1
* Mon May 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190527.7f657d82:
  * Run the SP5 installcheck per staging project and triggered by repo changes
  * Run project_only reports in python3 containers
* Mon May 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190527.dd327556:
  * Fix whitelist handling of repo checker in python3
* Mon May 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190527.edbb8573:
  * Exit with an error if there were exceptions caught
  * ReviewBot: Simplify the !interval case
* Fri May 24 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190524.65b73f1d:
  * userscript/staging*: only utilize the last two domain components.
  * osclib/core: package_version(): drop lxml element and return string version.
  * systemd: increase timeout to 24 hours for origin-manager report services.
* Fri May 24 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190524.86919f96:
  * README: Add explanation of developing against git osc.
  * .gitignore: ignore osc symlink commonly used to develop against pre-release osc.
* Fri May 24 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190524.fa2a17cf:
  * accept_command: fix missing the url for uploading product file change
* Thu May 23 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190523.823c5142:
  * Fix factory-package-news to work with Python 3
* Thu May 23 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190522.4ee44da8:
  * dist/k8s/heroes: include openSUSE:Leap:15.1:NonFree in origin_manager_report.
  * osclib/util: correct python3 port by casting to list directly after filter.
* Wed May 22 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190522.4707e237:
  * Require python3-osc and python3 only
  * Require newly released osc for python3 fixes
* Wed May 22 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190522.5ac61a01:
  * There is no use of urlgrabber left
* Tue May 21 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190521.d64a1336:
  * TTM: Add new failed status 'timeout_exceeded'
* Mon May 20 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190520.ad7abc06:
  * Add SLES15-SP1-SAP-Azure-LI-BYOS cloud image
* Mon May 20 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190520.c8cc0dd1:
  * Fix rabbitmq acknowledge: first ACK then check the content
* Sun May 19 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190519.fd3bbccf:
  * Acknowledge the rabbitmq message
* Sat May 18 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190518.34ca7128:
  * Fix typo in gocd config
* Sat May 18 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190518.e101da78:
  * Need a destionation if there are multiple materials
* Sat May 18 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190518.32a1e725:
  * Switch miniobs to use 15.1
  * Add staging-report entries (moved from packagelists)
  * gocd: Move SP1 config here
  * Move verify-repo-built-successful.py here
  * Fix python3 for staging-report
* Sat May 18 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190518.896c4185:
  * Submit openSUSE-release-tools even if there are no changes
* Thu May 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190516.fab9b27f:
  * Convert stdout of repo checker perl part to string
  * Fix check_source with python3
* Thu May 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190516.63108381:
  * Run container cleaner as python3
  * sha1_short: support bytes and str
* Thu May 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190516.4e26ac93:
  * Sort architectures to fix #2021
* Thu May 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190516.6dce9a79:
  * Run even more bots in python3
  * Run source and repo checker in python3
* Thu May 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190516.69527f81:
  * origin-manager: switch to python3.
  * osclib/origin: cast filter() to list() to improve debug output [python3].
  * osc-origin, osclib/origin: port first dict key/value access [python3].
  * osclib/util: sha1_short(): encode data as utf-8 [python3].
* Thu May 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190515.8221df00:
  * osclib/core: rework as package_list_kind_filtered().
  * osclib/core: provide package_kind().
* Wed May 15 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190515.33b36945:
  * Run ttm in python3 containers as well
* Wed May 15 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190515.b5131ba8:
  * Run the monitors in python3 containers
* Wed May 15 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190515.5a1b08d8:
  * osclib: make source_file_load() always return string
  * Switch to newly created account to update OSRT
  * pkglistgen: Output strings on the console
* Wed May 15 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190515.077c32aa:
  * check_tags_in_requests: escalate loss of issue references to a decline.
  * check_tags_in_requests: make issue singular since references is plural.
  * check_tags_in_requests: issue state is deleted not removed.
* Wed May 15 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190514.a1e436cb:
  * Add CNAME for github pages serving.
* Tue May 14 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190514.3df85367:
  * userscript/origin: rework to handle requests and interface link.
* Tue May 14 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190514.681a59ac:
  * Only impose a maxsize for a selected list of packages
* Tue May 14 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190514.60b9a909:
  * Add SUSE checkers config here
* Tue May 14 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190513.c5e7d06d:
  * userscript/origin: do not show failed when no OriginConfig.
* Mon May 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190513.2657cadc:
  * web/origin-manager: scroll to value after selecting.
* Mon May 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190513.0c46b2ca:
  * obs_operator: do not require session for OPTIONS method.
* Mon May 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190513.f2460434:
  * Run staging-installcheck exclusively on python3
* Mon May 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190513.b0d4f352:
  * Even more fixes for pkglistgen on python3
* Mon May 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190513.9c9e6e94:
  * suppkg_rebuild: Fix TypeError on python3
* Mon May 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190513.b98a02f3:
  * pkglistgen needs to run in the python3 container
* Mon May 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190513.03a54802:
  * Close the rabbit connection more carefully
* Mon May 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190513.ccca194f:
  * Even more python3 fixes for pkglistgen
* Mon May 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190513.780404f4:
  * Fix path to pkglistgen.py
  * Fix update_repo_handler in python3
* Sun May 12 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190512.90426046:
  * Fix repository_path_expand to also work in Factory stagings
* Sun May 12 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190512.e68bcda3:
  * Fix problems with pkglistgen under python3
* Sun May 12 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190512.4ef0c623:
  * Move to python3 containers for testing
* Sat May 11 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190511.a31c3724:
  * Fix string/bytes confusion with installcheck
  * Fix and test repository_path_expand on SLE12-SP5
  * Avoid warning on using .warn (python3)
  * Simplify travis setup even more: deploy in gocd
* Sat May 11 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190511.ffc9b22e:
  * Remove more references to vcr
* Sat May 11 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190510.fbd1bbd4:
  * obs_operator: handle multi-level host domains.
  * obs_operator: handle multi-level origin domains.
* Fri May 10 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190510.a18d69a6:
  * web/origin-manager: handle multi-level domains.
  * web/origin-manager: correct indentation of bootstrap import.
  * travis: restore deployment functionality.
  * systemd: drop --debug from obs_operator service.
  * systemd: include OBS Operator origin manager report service template.
  * metrics: reduce request period to after 450000.
  * vdelreq: ensure package does exist before checking binary
  * Run flake8 from Tumbleweed
  * Redo select tests to test package with multiple spec files
  * Fix delete requests with multiple spec files
  * freeze: Stop ignoring inter project links
  * freeze: Remove code handling Test-DVD
  * For consistency reasons always link the sub packages we're selecting
  * Ignore tests in coverage report
  * Merge vcrhelpers into OBSLocal
  * Simplify httpretty usage
  * Python3 fixes
  * Create fixtures for devel_project_tests
  * Fix comment_tests to create fixtures
  * Create user before using it
  * Rename OBSLocal.OBSLocalTestCase to OBSLocal.TestCase
  * Create a real staging setup for freeze tests
  * Run the nosetests in a tumbleweed container instead of travis environment
  * Remove fake OBS in favor of using generated test data
  * Fix OBSLock to always write full ISO format
  * Fix crash on staging project without flag section
  * obs_clone: remove watchlist from persons
  * Do not build packages in travis but in OBS
  * userscript/origin.user.js: nice icons
  * Add container for testing in leap 15.1
  * dist/package: handle python 2 vs python 3 dependencies.
  * dist/package: require influxdb and telegraf for Tumbleweed.
  * dist/package: drop %%check and related build requirements.
  * osclib/conf: convert all non-string defaults to string equivalents.
  * osclib/origin: handle origin_info when None.
  * osclib/origin: origin_revision_state(): do not find origin when None.
* Thu May  2 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190502.410ee689:
  * dist/package: add osclib dependency to all osc plugin packages.
* Thu May  2 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190502.e4b5f68f:
  * [ttm] do not wait publishing if dryrun
* Thu May  2 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190502.94176960:
  * PubSubConsumer: Fix cancel callbacks
  * PubSubConsumer: fix timer API and close callbacks
  * PubSubConsumer: add SSL options and fix reason API
  * PubSubConsumer: adopt to Pika 1.0 change
* Thu May  2 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190502.9cdbc9ac:
  * obs_operator: do not validate apiurl when set by flag.
  * dist/ci/flake-extra: include osc-origin.py in product grep.
  * web/origin-manager: provide initial interface utilizing operator handlers.
  * obs_operator: provide request/submit handler.
  * obs_operator: provide package/diff handler.
  * obs_operator: provide origin/projects handler.
  * obs_operator: provide origin/potentials handler.
  * obs_operator: provide origin/history handler.
  * obs_operator: add format support to origin/list handler.
  * obs_operator: handle empty body POST request.
  * obs_operator: support CORS preflight check OPTIONS requests.
  * osc-origin: add command to list package origin history.
  * osclib/origin: add origin_history().
  * osc-origin: add command to list potential origins for a package.
  * osclib/origin: add origin_potentials().
  * osc-origin: add projects command to list managed projects.
  * osc-origin: provide format flag and add support to list command.
  * osc-origin: include revision state information in lookup cache.
  * osc-origin: correct import order of origin_find().
  * osclib/origin: provide origin_revision_state().
  * osclib/core: review_find_last(): compare by_user instead of who.
  * osclib/core: provide project_attribute_list().
  * osclib/core: provide package_version().
  * obs_operator: change to two-level POST paths and same func naming as GET.
* Thu May  2 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190502.09332504:
  * Skip latest m2crypto for python3 branches as well
  * Fix imports, python3 doesn't import from .
  * Convert iterator to list to avoid RuntimeError
  * family_prior: Cast the filtered list to a list
* Tue Apr 30 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190430.491142d2:
  * osclib/pkgcache: drop as no more uses.
  * abichecker: remove PkgCache usage and instead always download.
* Tue Apr 30 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190430.a4924ffb:
  * Add small OBS instance without data
* Tue Apr 30 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190430.49f20d45:
  * Don't take latest m2crypto - fails to compile
* Wed Apr 24 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190424.b4083b08:
  * Fix container_cleaner timer trigger
  * Add osrt-container_cleaner to openSUSE-release-tools package
  * Use openSUSE-release-tools.git
  * More tests in container_cleaner_tests.py
  * Add container-cleaner.gocd.yaml
  * Add program for cleaning up maintenance_release projects for containers
* Tue Apr 23 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190423.971a080f:
  * More porting to python3
* Thu Apr 18 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190418.6b9c1c8f:
  * userscript/origin: rename to include user.js suffix.
* Wed Apr 17 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190417.39960a3e:
  * Add option to release image_products into a separate repo
* Tue Apr 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190416.00308ba8:
  * TTM: Remove confusing debug output
  * TTM: Fix another migration problem on publishing
* Tue Apr 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190416.0862a640:
  * TTM: add fixup command to update attribute
* Mon Apr 15 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190415.d9e7dcbe:
  * TTM: Ignore bootstrap - user will have to use --force
  * Extend the migration code
  * TTM: Add migration for the 'testing' status attribute
  * package: TTM needs python-enum34 (until we're on python3)
  * TTM: Fix conversion of QAResult to string
* Mon Apr 15 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190415.8911f2b7:
  * Fix exit handling of release and publish commands
  * TTM: Don't set 'published' snapshot before it's done
  * Add info log to wasted publish calls
  * TTM: reset failed status if no longer failing
  * TTM: Do not touch attributes if dry run
  * TTM: Fix release_package to be available to publisher as well
  * TTM: Check the publish state in releaser
  * Set the 'testing' status in releaser
  * Add published comment to openqa
  * TTM: Simplify (and fix) openqa status
  * Split manager into publisher and release
* Sat Apr 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190413.989fecad:
  * Improve error msg that the project was not frozen
* Thu Apr  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190404.0016e77e:
  * Make the ignore whitelist always a set()
* Wed Apr  3 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190403.36af69dc:
  * Ignore packages listed in comments
* Fri Mar 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190329.d14cf59a:
  * ReviewBot: handle any exception raised by check_one_request().
* Fri Mar 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190329.5c3f44b5:
  * origin-manager: require fallback review for delete requests.
* Fri Mar 29 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190329.b0371a1d:
  * osc-staging: exclude NonFree requests from staging proposals.
* Thu Mar 28 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190328.456ec244:
  * Remove the special logic for 000product
* Thu Mar 28 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190328.f449f81:
  * Release/Publish container_products first
  * Fix yet another crash because of self.project
  * Don't use version_images prefix for Images projects
  * Fix indenting - this is really hard :(
  * Move some more pipelines from citest to official repo
* Thu Mar 28 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190328.7f59878:
  * Replace all left self.project with self.project.name
  * Fix crash on images projects (openSUSE:Leap:15.0:Images)
* Thu Mar 28 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190328.1dc8e17:
  * Skip ttm subdir in nosetests
  * Remove is_image_product all together
  * Rename the snapshot functions and add gocd config
  * Moved the config into OBS/IBS
  * Calculate is_image_product instead of configuring it
  * Parse the config from yaml
  * Split totest manager into multiple files
  * Add config
  * Stop the fallback - we pass the real project name
  * Make is_image_product a config
  * Remove bad quotes (flake)
  * ToTestBaseNew is history
  * Merge _release functions
  * Merge is_snapshottable variants
  * Change the current_source override to a config
  * Move set_snapshot_number to ToTestBase
  * Remove overloaded iso_ and ftp_ function for SLE
  * Remove basically duplicated release_version function
  * Harmonize get_current_snapshot to take first main_product
  * Remove interval option - we run it as systemd timer for a while
* Wed Mar 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190327.d8487cd:
  * dist/k8s: drop --debug flag from obs_operator service.
  * dist/k8s: provide obs_operator origin-manager report sub component.
  * dist/k8s: add service cache to obs_operator.
  * dist/k8s: provide service level cache similar to reviewbot cache.
* Wed Mar 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190327.a8bf788:
  * Fix one more newline - not just in print
* Wed Mar 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190327.eae8884:
  * Fix newline in SI report
* Wed Mar 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190327.b3f1624:
  * Include the delete request analysis in the text file
* Tue Mar 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190326.83e05fa:
  * obs_operator: verify that origin root-domain matches host domain.
  * obs_operator: raise exceptions when osc request environment cannot be aquired.
  * obs_operator: calculate apiurl from host instead of origin header.
* Tue Mar 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190326.9d00ba0:
  * userscript/origin: use cross-domain request with credentials.
* Tue Mar 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190326.2b58c02:
  * check_source: update grammar
* Tue Mar 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190326.4aa89f7:
  * Don't hardcode build.opensuse.org
* Tue Mar 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190324.9a25908:
  * Don't add repo-checker from factory-auto in Leap
* Fri Mar 22 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190322.83c6eb0:
  * origin-manager: include annotation in fallback review comment.
* Fri Mar 22 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190322.f36bb8b:
  * userscript/origin: provide initial supplementary interface.
  * obs_operator: expose osc-plugin-origin commands via GET.
  * obs_operator: extract osc environment setup as with object.
  * osc-origin: osrt_origin_lookup(): print time since generated.
  * osc-origin: osrt_origin_lookup_file(): include project in cache file name.
* Fri Mar 22 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190322.07dc46f:
  * osclib/origin: policy_input_calculate(): s/inital/initial/.
  * osc-origin: list: sort by package name.
  * osclib/origin: policy_input_evaluate(): only add additional review if not already set.
  * osclib/core: package_source_hash(): handle non-existant revision.
* Wed Mar 20 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190320.d3c0e8b:
  * Avoid gocd warning on 9 minutes without print
* Wed Mar 20 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190320.2f35ae2:
  * Remove repository (not set for letter stagings)
* Wed Mar 20 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190320.7fc7a53:
  * SI: upload the result to OBS and link that on failure
  * SI: continue with other stagings on failures
  * Package the osrt- symlink in bin
  * Allow project comments to ignore delete requests for listed packages
  * SI: exit 1 if there was an error
  * Don't throw 404 on disappeared adi project
  * Do not repeated failed reports either
  * SI: Cache existant problems - they are always the same
  * SI: Go through all staging projects
  * Refactor a little
  * Repo checker: work on staging projects as a whole
* Wed Mar 20 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190320.d9b4fee:
  * gocd: Fix PYTHONPATH for the monitor scripts
* Wed Mar 20 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190320.c76e0d9:
  * Fix compat with pyYaml 5.1
  * origin-manager: include origin annotation in comment when waiting.
* Wed Mar 20 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190320.ab8a614:
  * No longer package rabbit-openqa but add gocd config for it
  * Add rabbit-repoid
  * PubsubConsumer: Implement max runtime
* Wed Mar 20 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190320.bb48831:
  * Replace deprecated (and not advised) yaml.load() with yaml.safe_load().
  * [openqa-maintenance] Add openSUSE Leap 15.1 configuration
  * osclib/origin: policy_input_evaluate(): do not list disallowed reviews.
* Wed Mar 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190313.b7eeea5:
  * Added livecd-tumbleweed-xfce in livecd_products
* Mon Mar 11 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190311.149e290:
  * pkglistgen: Don't upper case the staging letter
* Sat Mar  9 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190309.bb2cb5c:
  * Fix adi command if there are actually checks
  * devel-project: notify: catch smtp exceptions rather than crashing.
* Fri Mar  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190308.7f2195f:
  * No longer add repo checker as reviewer for Factory
  * Remove 15.1:ARM:Live
* Fri Mar  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190308.44cbc3a:
  * Block adi command from accepting if checks aren't succeeding
  * Add all checks from staging-required-checks-adi to main repo of adi projects
* Wed Mar  6 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190306.819d437:
  * dist: provide origin-manager report service and timer.
  * dist/package: provide osc-plugin-origin package.
  * osc-origin: provide initial origin osc subcommand.
  * osclib/core: package_list_without_links(): ignore meta packages (00 prefix).
  * osclib/origin: provide __str__ method that indicates pending.
  * osclib/origin: config_resolve_create_family(): force origin_expanded to string.
  * osclib/util: mail_send(): allow a from_key of None to indicate osc user.
  * osclib/util: mail_send() utilize Config.get() pattern.
  * osclib/util: mail_send(): use to as config key if no at sign.
* Wed Mar  6 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190306.ef6e30c:
  * dist/ci/Dockerfile: change from Tumbleweed to Leap for build host.
* Wed Mar  6 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190305.9f97c15:
  * cycle: Add command line parameter support
  * Use the JeOS-efi binaries for 15.1 arm images version reading
  * Use different base class for ToTest151ARMImages
  * Add openSUSE:Leap:15.1:ARM:Images
* Wed Feb 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190227.214f8bb:
  * origin-manager: support ReviewBot override comment using origin workaround.
  * ReviewBot: request_override_check(): default to accept.
  * ReviewBot: request_override_check(): provide force option.
* Wed Feb 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190227.b16cc9a:
  * Add openSUSE-Tumbleweed-Kubic images
* Wed Feb 27 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190227.ca7c4fd:
  * legal: Fix crash on declining obsrq#670770
* Tue Feb 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190226.6d72812:
  * dist/package: include origin-manager source file in source_dir.
  * dist/kubernetes: disable origin-manager component.
  * dist/kubernetes: add origin-manager component.
  * dist/kiwi: add origin-manager subpackage.
* Fri Feb 22 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190222.9b58ce5:
  * Fix project/status route
* Thu Feb 21 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190221.324b92a:
  * Output something every 5 minutes to show activity on the console
* Wed Feb 20 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190220.d43faf0:
  * tests/obs: provide offering to appease the re-implementation of OBS.
  * travis: add check to complain about product references in origin-manager.
  * dist/package: provide origin-manager sub-package.
  * systemd: provide osrt-origin-manager service and timer.
  * origin-manager: provide ReviewBot utilizing osclib.origin.
  * osclib/origin: provide origin management functions.
  * dist/obs: provide OSRT:OriginConfig definition.
  * osclib/util: project_version(): return 0 instead of None for invalid project.
  * osclib/util: provide project_list_family_prior_pattern().
  * osclib/util: project_list_family_prior(): provide include_updates option.
  * osclib/util: project_list_family(): cache via memoize.
  * osclib/util: project_list_family(): provide include_update option.
  * osclib/util: project_list_family(): handle :NonFree suffix.
  * osclib/cache: handle repetative package_source_hash_history() calls.
  * osclib/conf: properly load config for innerconnect projects.
  * osclib/core: provide request_remote_identifier() for printable identifier.
  * osclib/core: provide issue_tracker*() functions.
  * osclib/core: provide review_*() functions for summarizing review state.
  * osclib/core: provide project_remote_*() functions for innerconnect projects.
  * osclib/core: provide package_source_hash*() functions.
  * osclib/core: provide entity_source_link().
  * osclib/conf: add repo-checker key since it does review :Update requests.
  * osclib/core: provide entity_exists() and use in StagingAPI.item_exists().
* Tue Feb 19 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190219.8d3c53c:
  * Need apiurl for staging report
* Mon Feb 18 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190218.0f466a0:
  * Add kubic-kured-image and kubic-pause-image to container_products
* Fri Feb 15 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190215.53bbe03:
  * Add missing dependency
* Wed Feb 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190213.be751cc:
  * compare_pkglist: fix return code handling introduced by 2e339acffb03b6786c902c2ebd250d1c3720e315
* Wed Feb 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190213.af2471e:
  * compare_pkglist: minor improvements
* Wed Feb 13 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190213.fe23e8d:
  * repo_checker: Simplify cycle check
* Tue Feb 12 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190212.6f70fe2:
  * compare_pkglist: update version to Leap 15.1 and SLE15 SP1
* Mon Feb 11 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190211.38c1c42:
  * Fix rebuildpacs for installation-images
* Fri Feb  8 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190208.9984223:
  * osclib/list_command: 24ae4ba81 broke formatting.
* Thu Feb  7 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190207.4e24164:
  * Remove openSUSE-images from rebuildpacs - long gone
* Thu Feb  7 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190207.6d706a6:
  * rebuildpacs: Check the binary version not just the bdep itself
  * Take over rebuildpac problems from packagelists VM and tidy
* Thu Feb  7 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190207.b99d841:
  * Fix arch-whitelist to apply to staging projects
  * Filter the repositories_pairs depending on the target archs
  * Don't try to filter staging archs
  * Calculcate the whitelist for letter stagings purely on config
  * Expand all repositories but ignore archs with 404
  * repo_checker: remove explicit target project repository layer for letter stagings.
  * repo_checker: provide repo_checker-binary-whitelist-ring config option.
* Wed Feb  6 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190206.61c0f67:
  * Map i686 packages to i586 to find kernel-pae-devel
* Tue Feb  5 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190205.ee7cdc2:
  * ReviewBot: catch exception for adding devel project review
  * conf: use backports-reviewers for backports
* Wed Jan 30 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190130.7d1fa2f:
  * Fix E117: over-indented (flake8 update on TW)
  * Fix format in rabbitmq debug
* Wed Jan 30 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190130.f66fd52:
  * fix incompatible repo id tagging for openSUSE products
* Sat Jan 26 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190126.da4ba5d:
  * Support connecting suse in PubSubConsumer
  * Only use amqp_prefix as config
  * Reduce debug level for channel close
* Thu Jan 24 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190124.535533d:
  * accept_command: no longer need to triggering product converter service
* Tue Jan 22 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190122.8d29352:
  * osc cycle: correctly handle comma-separated arg list
  * leaper: fix cross instance obs links
  * leaper: tune origin change reporting
  * leaper: check 15.1 explicitly
  * ReviewBot: refactor logic
  * deptool: only skip disabled repos when not listed explicitly
* Mon Jan 21 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190121.a524c04:
  * Replace weakremovers.inc in 000release-packages
  * Handle weakremovers.inc special
  * Fix handle_update_repos for Factory and leap
  * Store it as susetags light
  * Refresh solv files for leap
* Thu Jan 17 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190117.7ccdd76:
  * pkglistgen: Reset the tool between projects
* Thu Jan 17 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190117.16fdb71:
  * Fix base container for tumbleweed
* Thu Jan 17 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190117.f3466fc:
  * Fix check for "no change in snapshot version"
* Thu Jan 17 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190117.954ec73:
  * Install pkglistgen files
* Thu Jan 17 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190117.f8b4b43:
  * Kill create_test_dvds.sh
  * Moved the nocleanup-packages setting into remote config
  * Set some version for staging projects
  * pkglistgen: Don't crash in powerpc on i586 entries
  * Revert the change to copy_files
  * Don't hardcode architectures - take it from the project
  * pkglistgen: Replace empty version with OSRT:ProductVersion
  * pkglistgen: Ignore locked packages for expansion
  * pkglistgen: Add all recommends and supplements
  * pkglistgen: require set_namespaceproviders for now (it's old enough)
  * pkglistgen: Move droplist generation aside
  * pkglistgen: Fix test failures (including flake8)
  * pkglistgen: Don't update 000package-summary anymore, but diff
  * pkglistgen: Write group stubs for --only-release-packages
  * pkglistgen: Move one more function to solv_utils
  * pkglistgen: Trim down CommandLine interface to the minimum
  * pkglistgen: Introduce file_utils functions
  * pkglistgen: Move dump_solv into its own file
  * pkglistgen: move do_solve into tools class
  * pkglistgen: Bugfixes for create_sle_weakeremovers
  * pkglistgen: move create_sle_weakremovers to tool class
  * pkglistgen: Drop list commands
  * pkglistgen: Drop update command
  * pkglistgen: Move suggested from global to package level
  * pkglistgen: Take the architectures from tool not opts
  * pkglistgen: Move into a folder and split into 3 files
* Wed Jan 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190116.af61a2f:
  * ttm: Follow Tumbleweed move to new pkglistgen pkg layout
* Wed Jan 16 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190116.9ab4c3c:
  * accept_command: add additional version number to OSRT:ProductVersion
* Thu Jan 10 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190110.a9eeeb0:
  * Only decline delete requests that affect linked packages within the target
* Wed Jan  9 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190109.df13caa:
  * ttm: remove set_snapshot_number in ToTest151PowerPC
* Fri Jan  4 2019 opensuse-releaseteam@opensuse.org
- Update to version 20190104.537bdd5:
  * ARM: don't set the snapshot version
* Wed Dec 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181219.960b7ba:
  * suppkg_rebuild: use the binaryverions query instead
* Tue Dec 18 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181218.d14a232:
  * check_duplicate_binaries: set arch key to string instead of the list
* Mon Dec 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181210.75e065f:
  * Add JeOS and containers to TW
* Wed Dec  5 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181205.180ca46:
  * fcc_submitter: ignore removed package in the previous version
* Tue Dec  4 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181204.aa1c004:
  * droplist: Ignore Leap:15.1 for Leap:15.1:ARM
  * Do not generate drop list for leap:15.1:arm at the moment
  * No longer default to all scopes but make it configurable
  * Also remove 'arm' scope
  * Remove 'ports' scope - powerpc uses target project
  * Fix deleting of files
  * Delete kiwi by glob
  * Add option to only generate release packages
  * Remove skip_release option
  * Set OBS_NAME ourselves on api.suse.de
  * pkglistgen: Add --staging option for easier scoping
* Thu Nov 29 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181129.f45087d:
  * osclib/cache: remove double comment introduced in #1802.
  * metrics: sync config key with recent Leap changes.
  * tests/metrics: add basic test to ensure code is executable.
  * travis: use ecrypted e-mail address to avoid spam from forks.
* Tue Nov 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181127.ad48ebf:
  * If we can't resolve the package name, it's no reason to decline
* Tue Nov 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181127.edba5dc:
  * Revert extracted kiwi again
* Mon Nov 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181126.590fd22:
  * dist/k8s/app.yaml: disable check-source and repo-checker components.
  * dist/kubernetes: utilize new image home in openSUSE:Tools:Images.
  * dist/package: include worker kiwi to allow extraction via _service.
  * dist/kiwi/worker: include obs-operator subpackage.
  * obs_operator: use unbuffered output to work properly in systemd.
  * dist/kubernetes: provide OBS Operator component.
* Mon Nov 26 2018 Jimmy Berry <jberry@suse.com>
- Extract osrt-worker-obs.kiwi via _service and reference in spec.
* Mon Nov 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181126.4331271:
  * ttm: add minimal staging config for pseudometa package
  * Add workaround for failing JeOS comparison on ARM
* Mon Nov 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181126.f333b2d:
  * Readability cleanups
  * Follow flake8 import order
  * Iterate over product arch list
* Sat Nov 24 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181124.c1a7698:
  * Adjust JeOS for 15.1 images
* Fri Nov 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181123.b280e8a:
  * fcc_submitter: update version to 15.1
* Thu Nov 22 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181122.aaef149:
  * leaper: just pass if only origin change left to decide
  * leaper: fix comment about package not in Factory
  * leaper: silence output of checking older dists
* Wed Nov 21 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181121.5a43f6f:
  * Disable caching project _meta
* Wed Nov 21 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181121.c2d8065:
  * Disable publishing for the product_repo in the test_project directly
* Tue Nov 20 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181120.1f0e92c:
  * pkglistgen: nonefree repo handling should update to tool's repos rather than commandline's repos
* Tue Nov 20 2018 Stephan Kulow <coolo@suse.com>
- Remove kiwi file again as it was causing problems within openSUSE:Factory,
  moved it to its own webhook triggered container on
  openSUSE:Tools:Images/osrt-worker-obs
* Tue Nov 20 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181120.4be5ff3:
  * Replace urlparse.urlparse for python3
  * Import url functions properly for python3
  * Use more print from the future
  * ttm: Add ToTest151PowerPC for Leap 15.1 PowerPC
* Mon Nov 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181119.1714c58:
  * staging-report: ignore projects not in a final state.
  * osclib/stagingapi: provide project_status_final().
* Mon Nov 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181119.efa6674:
  * stagingapi: No longer build disable to sub packages
* Fri Nov 16 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181116.065ab5e:
  * userscript/README: include more details about usage and troubleshooting.
* Fri Nov 16 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181116.416172c:
  * Checked with aplanas: using stringio is preferred
* Fri Nov 16 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181116.31e97b0:
  * In some cases the return value of yaml.load(description_text) can be a string containing 'none'.
* Fri Nov 16 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181116.e3f260f:
  * Import urllib2 python agnostic
  * Store data as binary in the cache
  * Remove the reduce call the brute force way
  * basestring is gone - in favor or str (which also works for python2)
  * rabbit-openqa: fix imports for python3
  * Port more code to run under python3
  * Use Leap:15.1:Images for testing instead of openSUSE:Factory
  * Add the base container to container_products of openSUSE:Factory
  * Add release workflow for container products
  * Add new ImageProduct class to allow images with different enabled architectures
  * Only look at/toggle publishing of the the product repo in :ToTest
  * Define products in ToTestBase
  * Allow to specify repository and target in _release_package
* Thu Nov 15 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181115.1c92d8a:
  * travis: add test jobs against osc python3 branch for both python 2 and 3.
* Wed Nov 14 2018 Jimmy Berry <jberry@suse.com>
- Extract osrt-worker-obs.kiwi via _service and reference in spec.
* Tue Nov 13 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181113.f936dc2:
  * travis: configure notification e-mail to internal list.
* Tue Nov 13 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181113.56a2f40:
  * ReviewBot: accept patchinfo action reviews instead of ignore.
  * pkglistgen: Start documentation
  * pkglistgen: Support a recommends flag in the OUTPUT
  * Adapt the unselect test to the current state
  * Disable DEBUG for obs requests, it makes reading test failures very hard
  * Do not crash on staging projects without status (gcc7)
  * Support OBS checks instead of openqa
* Sat Nov 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181110.2a9183f:
  * Caching attributes is not worth it and creates problems
* Sat Nov 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181110.3310ec0:
  * systemd/staging-report: include --debug flag to provide actual output.
  * Rename openqa-comments to staging-report to more accurately reflect new role.
  * osclib/comments: force encoding to ascii to avoid OBS 400 errors.
  * openqa-comments: replace custom comment marker with standard, simplify and correct comment logic.
  * openqa-comments: rework openQA report as status check report.
  * openqa-comments: utilize StagingAPI.project_status() instead of duplicating.
  * openqa-comments: cleanup help text wording and defaults.
* Fri Nov  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181109.c39fa33:
  * [ttm] remove ppc64 (BE) for TW bypass boo#1112920
* Fri Nov  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181109.3aae284:
  * adi: Fix format for untracked requests
* Thu Nov  8 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181108.f4371f4:
  * dist/spec: provide obs-operator subpackage.
  * userscript/staging-move-drag-n-drop: rework to utilize OBS Operator server.
  * obs_operator: provide initial version of server.
  * userscript/staging-move-drag-n-drop: provide option to click to start.
  * userscript/staging-move-drag-n-drop: move browser compatability check to init.
* Thu Nov  8 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181108.09fd2ba:
  * Remove map_ring_package_to_subject - it always return project
  * No longer build disable on selecting non-ring packages to letter prjs
* Thu Nov  8 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181108.e8daf87:
  * new bugowner tool
* Thu Nov  8 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181108.151a4fe:
  * [ARM] Skip build number comparison
* Thu Nov  8 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181108.4293b6b:
  * Avoid httppretty 0.9.6 for now
* Wed Nov  7 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181107.1fec88f:
  * userscript/staging-move-drag-n-drop: provide initial version.
* Wed Nov  7 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181107.fc99800:
  * check_source: check if member of staging group before attempting to skip.
* Wed Nov  7 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181107.c85f26e:
  * Don't report that a package is ok if the resultlist is empty
* Mon Nov  5 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181105.1f8bf21:
  * Fail rabbit-openqa and have systemd restart it
* Mon Nov  5 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181105.22b89d4:
  * abichecker: fix for updated osc api
* Thu Nov  1 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181101.33a4a3b:
  * osclib/request_splitter: provide stageable option and make default True.
* Thu Nov  1 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181101.9f21c86:
  * devel-projects: remove workaround for OBS xpath bug during request search.
* Wed Oct 31 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181031.0d9cde5:
  * osclib/core: repository_published() make x86_64 dependent on i586.
* Tue Oct 30 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181030.c7fd9ba:
  * osclib/select: only check filter-from logic if argument was passed.
* Tue Oct 30 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181030.76bb32a:
  * Fix indentation in is_snapshottable
* Fri Oct 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181026.9f82d01:
  * leaper: block on pending factory submissions also for new packages
* Thu Oct 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181025.78a0172:
  * osc-staging: handle None value for --filter-from.
* Thu Oct 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181025.5558473:
  * repo_checker: filter repository published check by arch.
  * repo_checker: repository_state_last(): switch to simulate_merge as arg.
  * repo_checker: repository_state(): limit meta revision to simulate merge.
  * repo_checker: repository_state(): filter by relevant archs.
  * repo_checker: extract arch determination as target_archs_from_prairs().
  * osclib/core: provide archs filter for repository state and published queries.
* Thu Oct 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181025.3ad87ff:
  * manager_42: remove extra newline to avoid flake8 E301.
  * flake8: utilize raw strings to avoid invalid escape character warnings.
  * flake8: ignore W504.
* Tue Oct 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181023.f7ea85e:
  * Fix deployment problems on rabbit-openqa
* Tue Oct 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181023.9b1618e:
  * If OBS or openQA raise an exception, restart
  * Require python-pika in CI
  * First connect to AMQP then fetch initial state
  * Refactored rabbit-openqa to be based on PubSubConsumer
  * Adopt pika example on async
  * Moved the ISO replace_string into OBS attributes
  * Find a sed like syntax for Staging ISOs
  * Package rabbit-openqa
  * Make the names of the openQA checks unique
  * No need to if loop - we do the same for all of openqa
  * Link to failed test modules
  * Fetch all openQA jobs for the ISO every time
  * Gather initial buildid of repositories
  * Add helper bot to listen to rabbit bus and feed OBS with openQA Status
* Sun Oct 21 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181021.14837b3:
  * pkglistgen: fix AttributeError since update_repos() moved to PkgListGen class
  * osc-staging: select: document --move and --filter-from options.
  * osc-staging: select: replace --from with --filter-from.
* Fri Oct 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181019.649529a:
  * metrics/grafana/openqa: set minimum interval of 10s to avoid gaps.
* Fri Oct 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181019.7d58952:
  * repo_checker: utilize 'staging' config option for instantiating StagingAPI.
  * osclib/cycle: remove need for StagingApi instance in favor of apiurl.
  * ReviewBot: staging_api(): allow for Staging subproject to be used.
* Fri Oct 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181019.b184670:
  * osclib/conf: include NonFree subproject in openSUSE patterns.
  * osclib/conf: remove Ports subprojects as they no longer exist.
* Fri Oct 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181019.61d9082:
  * We need the images repo published to have a status check
* Wed Oct 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181017.3282c9a:
  * leaper: disable maintainer review addition for incidents.
* Wed Oct 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181017.1b25b75:
  * dist/ci/obs-build-target: utilize TAR_SCM_TESTMODE to avoid URL check.
  * dist/ci/obs-build-target: stop at first error.
  * metrics: Fetch openqa jobs in influxdb format
* Mon Oct 15 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181015.c6ff801:
  * check_maintenance_incidents: skip action if the action is for patchinfo
* Thu Oct 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181011.61e1049:
  * Move unlink_list to pkglistgen class too
  * Move update_repos into Pkglistgen class
  * Don't make missing repos (per arch) a fatal error
* Thu Oct 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181011.37ac71d:
  * [ARM 15.1] Include JeOS images in ToTest
* Thu Oct 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181011.5d542a8:
  * Add openSUSE-Tumbleweed-Kubic-dvd5-dvd-aarch64 to openSUSE:Factory:ARM
* Wed Oct 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181010.e90ac73:
  * pkglistgen: Fix copy&paste error on uploading results
* Wed Oct 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181010.97f1eda:
  * Fix overlap calculation: modules only have filtered archs
* Thu Oct  4 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181004.97e58e1:
  * Do no longer CC submitters in request comments
* Thu Oct  4 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181004.caee905:
  * pkglistgen: Make sure we don't calculate non-existant architectures in stagings
* Thu Oct  4 2018 opensuse-releaseteam@opensuse.org
- Update to version 20181004.5ba0b87:
  * Refactor conditional_PUT as core function
  * pkglistgen: only PUT new data if it changed
* Sat Sep 29 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180929.39a3f83:
  * repo_checker: re-instate staging build failure check after generic rework.
  * pkglistgen: Only check repository check per arch
  * Optimize repository_state
* Thu Sep 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180927.2deda1a:
  * osclib/core: repository_state(): rework to utilize binarylist view.
* Thu Sep 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180927.ed9afea:
  * Move creation of the Solver object out of loop
* Wed Sep 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180926.ea94191:
  * dist/kubernetes: provide README covering basic operation.
  * dist/kubernetes: provide repo-checker module.
  * dist/kubernetes: provide check-source module.
  * dist/kubernetes: provide base review_bot component prototype.
  * dist/kubernetes: provide basic ksonnet setup for heroes cluster.
  * dist/kiwi: provide kiwi for building worker-obs container.
  * k8s-secret: provide tool to generate kubernetes secrets containing oscrc.
  * osclib/cache_manager: rework base directory handling.
  * dist/ci/osc-init: allow output file location to be set via OSCRC env var.
* Wed Sep 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180926.015677f:
  * Don't take unsorted.group as reference for SP1 product changes
* Mon Sep 24 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180924.1527c61:
  * check_tags_in_requests: factory property is actually an array
* Fri Sep 21 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180921.e409a67:
  * pkglistgen: compare repository state to determine when to update solv.
* Thu Sep 20 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180920.35ea0e1:
  * systemd/metrics-access.timer: utilize compatible calendar format.
* Tue Sep 18 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180918.38e2d3f:
  * metrics/access/aggregate: correct empty seen key handling.
* Tue Sep 18 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180918.d3afb68:
  * osclib/core: project_pseudometa_file_ensure(): correct comparison logic.
* Tue Sep 18 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180918.aeb3b8c:
  * ReviewBots: utilize delete_package check where it was already assumed.
  * check_source: split out delete repository check to new sub action check.
  * check_source: decline all delete project requests.
  * ReviewBot: break down sub-types of delete requests.
* Fri Sep 14 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180914.628c1a1:
  * metrics/grafana/access: add new row and graphs for image totals by product.
  * metrics/access/aggregate: process and summarize image totals by product.
  * metrics/access/aggregate: extract merge_product_plus_key() from merge().
  * metrics/access/ingest: detect product image paths and included in dump.
  * metrics/grafana/access: remove left-over raw queries.
  * metrics/access/aggregate: include Leap 15.1 in published metrics.
* Thu Sep 13 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180913.d102240:
  * check_source: reset skip_add_reviews for each request
* Thu Sep 13 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180913.47324ff:
  * check_source: ignore _product package check
* Tue Sep 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180910.3cf8055:
  * metrics: check for action/target instead of submit/target since removed.
  * metrics: remove workaround for OBS xpath bug during request search.
* Wed Sep  5 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180905.67200cd:
  * metrics: correct reference to Leap config defaults pattern.
* Wed Sep  5 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180905.c5ceab9:
  * osclib/cache: provide mechanism to init multiple times.
  * Utilize CacheManager for all existing caches.
  * osclib/cache_manager: provide general cache manager for all tools.
  * osclib/common: provide project name and version constants.
* Sat Sep  1 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180901.9e8018f:
  * travis: increment targetted versions to openSUSE Leap 15.0 and SLE 15.
* Fri Aug 31 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180831.8d17136:
  * dist/spec: add obs-service-* requirements of check_source.pl.
* Fri Aug 31 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180831.1cedb3d:
  * compare_pkglist: queries with withlinked=1 to ignore inherited package
* Fri Aug 31 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180830.814f5f6:
  * dist/spec: include as requirement of check-source sub package.
* Fri Aug 31 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180830.e23fb18:
  * tests/factory_source_tests: update query after osc@f1c3156.
* Thu Aug 30 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180830.99898de:
  * README: include section about using obs_clone tool.
* Wed Aug 29 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180829.e943dab:
  * metrics: provide initial telegraf setup for ingesting historical snapshots.
* Wed Aug 29 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180829.6a972fa:
  * leaper: proper maintainer review rule
* Mon Aug 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180827.541b94d:
  * Remove SUSE copyright, warranty, and license headers.
  * LICENSE: add proper GPLv2 license.
* Mon Aug 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180827.491706c:
  * leaper: comment_handler_lines_deduplicate() remove as no longer applicable.
* Fri Aug 24 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180824.754012f:
  * README: completely rewrite and provide workflow overview SVG.
* Thu Aug 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180823.b2be0e2:
  * README: update coveralls badge for new repository name.
* Thu Aug 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180823.57ef49a:
  * Revert "repo_checker: change build to state in comment info."
* Thu Aug 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180823.db50e79:
  * repo_checker: include repository as bot name suffix in direct package comment.
  * repo_checker: include repository as bot name suffix for staging comments.
  * osclib/conf: utilize repo_checker-project-skip for OBS SLE projects.
  * repo_checker: provide repo_checker-project-skip option.
  * repo_checker: change build to state in comment info.
* Thu Aug 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180823.ebec421:
  * repo_checker: change package comment default to be direct instead of devel.
* Thu Aug 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180822.a676367:
  * repo_checker: CreatePackageDescr: exclude build-env requirement.
* Thu Aug 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180822.a02488e:
  * leaper: replace maintbot usage with ReviewBot methods.
  * check_source: replace maintbot usage with ReviewBot methods.
  * ReviewBot: add devel_project_review_*() methods adapted from maintbot.
* Thu Aug 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180822.7fa84f7:
  * repo_checker: repository_check(): drop left over development comment.
  * repo_checker: rework install_check() to use target project consistently.
* Wed Aug 22 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180822.4cbeaa5:
  * leaper: remove duplicate maintainer review check for IBS in default action.
* Wed Aug 22 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180822.7f26309:
  * repo_checker: project_only: hook up --post-comments flag.
* Wed Aug 22 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180822.a9f1bc0:
  * osclib/core: repository_path_expand(): skip adding duplicate path.
* Wed Aug 22 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180821.fa39e68:
  * StagingAPI: drop inferior expanded_repos() implementation for osclib.core.
  * pkglistgen: utilize osclib.core.repository_path_expand().
  * repo_checker: complete rework to handle arbitrary repos and maintenance.
  * osclib/util: provide sha1_short() adapted from repo_checker.
  * osclib/core: provide project_meta_revision() adapted from repo_checker.
  * osclib/core: provide repository state and published functions.
  * osclib/core: provide repository_path_search().
  * osclib/core: provide repository_path_expand() adapted from StagingAPI.
  * osclib/core: target_archs(): expose repository argument.
  * osclib/conf: drop main-repo default for all projects.
  * ReviewBot: utilize osclib.Cache for all bots by default.
  * ReviewBot: utilize memoize cached config.
* Tue Aug 21 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180820.d7d5724:
  * osc-staging: update "config" documentation to point to OSRT:Config.
  * osclib/core: source_file_save(): always include host in message.
  * osclib/stagingapi: rename dashboard_content_* methods to pseudometa_file_*.
  * Replace relevant 'dashboard' package references with pseudometa lookup.
  * osclib/stagingapi: drop {load,save}_file_content() methods.
  * osclib/core: provide project_pseudometa_*() functions.
  * osclib/core: provide source_file_save() adapted from StagingAPI.
* Fri Aug 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180817.c11f78e:
  * osclib/conf: remove staging default for generic projects.
* Fri Aug 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180817.f0fadd6:
  * osclib/conf: provide Leap:N:Update default settings.
  * osclib/conf: exclude sub-projects from matching project patterns.
* Fri Aug 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180817.8092671:
  * ReviewBot: drop self.staging_config post switch to Config.get().
  * repo_checker: use osclib.conf.str2bool() instead of bool().
  * ReviewBots: utilize Config.get() instead of self.staging_config.
  * osclib/conf: provide cached get() method to supersede ReviewBot cache.
  * check_source: drop staging_group() for target_project_config().
* Fri Aug 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180817.55116d3:
  * osclib/stagingapi: utilize osclib.core.attribute_value_*() implementations.
  * tests/obs: improve format of default Config attribute.
  * osclib/conf: decouple from StagingAPI and always fetch remote config.
  * osclib/conf: utilize osclib.core.attribute_value_load() instead of StagingAPI.
  * osclib/conf: drop dashboard/config migration to attribute.
  * osclib/core: provide attribute_value_(load|save) adapted from StagingAPI.
* Fri Aug 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180817.93038db:
  * osc-staging: add documentation for setprio command.
  * osclib/prio: support non-important priority.
* Thu Aug 16 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180816.fb3d580:
  * osclib/core: maintainers_get(): rework to properly supports groups.
  * osclib/core: provide groups_members() to expand muliple groups users.
  * Utilize ET.fromstringlist() intead of joining strings.
* Thu Aug 16 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180816.7b0f756:
  * repo_checker: CreatePackageDescr: remove more unnecessary special cases.
* Wed Aug 15 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180815.fa1f929:
  * repo_checker: drop whitelist_clean sub-command.
  * repo_checker: determine existing problems based on project_only output.
* Wed Aug 15 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180815.eed6dde:
  * repo_checker: support multi-layer projects during project_only run.
  * repo_checker: properly support multi-layer projects during request mode.
* Wed Aug 15 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180815.cec5fa6:
  * repo_checker: whitelist_clean(): correct attribute_value_save().
* Tue Aug 14 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180814.f629ed8:
  * ReviewBot: check_one_request(): correct logic to return "lowest" result.
  * leaper: remove only_one_action limitation.
  * leaper: provide maintenance_incident support.
* Tue Aug 14 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180814.17dddb4:
  * check_source: allow for dot in package name during in-air rename check.
* Mon Aug  6 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180806.0296ba5:
  * manager42: don't consider ignored packages vanished
* Fri Aug  3 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180803.b58b4e4:
  * pkglistgen: fix calling expand_repos() in CommandLineInterface
  * pkglistgen: respect main_repo setup for other variant
* Thu Aug  2 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180802.dec881d:
  * leaper: fix error with no lookup_150 attribute exist after introduced PackageLookup
* Wed Aug  1 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180801.cc79ce0:
  * Lazy evaluation the ring projects
* Wed Aug  1 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180801.174755e:
  * pkglistgen: Support passing multiple scopes
  * Rename superseded_by_id to superseded_by
* Fri Jul 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180727.27f0056:
  * Add salt packages to DVD for Staging tests
* Fri Jul 20 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180720.7920baa:
  * pkglistgen: Commit a summary.yml into 000product-summary if existant
  * pkglist: Review the proper package (000release-packages)
  * pkglistgen: allow to pass staging:a as scope
  * pkglistgen: remove default-support-status option
* Thu Jul 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180719.9951b45:
  * Move expanded_repos into staging api
  * repo_checker: Expand repositories of target project
  * repo_checker: Fix the review loop
* Thu Jul 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180719.c9030ef:
  * Revert "dist/ci/Dockerfile: add python2-pyOpenSSL as dependency."
* Thu Jul 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180718.2f192f1:
  * Obsoletes create_test_Factory_dvd-2.testcase
  * Remove debug code accidentally part of #1615
  * Fix openQA group for Leap 15.1
  * Add support for SLE12SP4 and SLE15SP1
  * Add Leap 15.1 ARM support
  * Apply remote config in openqa-comments
  * Remove more of :DVD subproject handling
  * tests: remove all subproject related part
  * openqa-comments: do not need to check subproject
  * check_command: subproject method is no longer exists in dashboard
  * stagingapi: remove staging_walk() function
  * stagingapi: remove project_status_walk() function
* Wed Jul 18 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180718.2f192f1:
  * Obsoletes create_test_Factory_dvd-2.testcase
* Tue Jul 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180717.a83493b:
  * Remove debug code accidentally part of #1615
* Tue Jul 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180717.4ced4ce:
  * Fix openQA group for Leap 15.1
  * Add support for SLE12SP4 and SLE15SP1
* Tue Jul 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180717.35e7657:
  * Add Leap 15.1 ARM support
* Mon Jul 16 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180716.d161634:
  * Apply remote config in openqa-comments
* Sun Jul  8 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180708.2c59f5e:
  * Remove more of :DVD subproject handling
* Thu Jul  5 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180705.c561663:
  * tests: remove all subproject related part
  * openqa-comments: do not need to check subproject
  * check_command: subproject method is no longer exists in dashboard
* Thu Jul  5 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180705.0b67025:
  * stagingapi: remove staging_walk() function
  * stagingapi: remove project_status_walk() function
* Tue Jul  3 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180703.72eb7dc:
  * pkglistgen: Don't crash on empty groups (unsorted is one)
  * pkglistgen: Add --stop-after-solve option to ease debugging
  * pkglistgen: Add --no-checkout option to accelerate reruns
  * pkglistgen: Calculate the repos list instead of hardcoding
  * stagingapi: add support for Backports
  * pkglistgen: drop ring 2
  * stagingapi: apply default config first
* Tue Jul  3 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180703.29c4b6a:
  * Include deptool in spec file
  * Tool to debug dependencies
* Fri Jun 29 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180629.4355859:
  * No longer have Ring2 and staging :DVD subproject
* Fri Jun 29 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180629.2ed2f4e:
  * check_source: skip adding reviews for incidents in favor of maintbot.
  * check_source: replace one action limitation with configurable rule.
  * check_source: override rename project setting for maintenance_incident.
  * check_source: rework rename check to allow for suffixed :Update packages.
  * ReviewBot: provide self.action for direct access in sub-classes.
  * ReviewBot: check_action_maintenance_incident(): clarify src_package magic.
  * ReviewBot: downgrade patchinfo message to debug and include for release.
  * check_maintenance_incidencts: utilize _is_patchinfo().
  * leaper: adjust for SLE 15SP1 and SLE12SP4
  * Leaper: adjust for 15.1
* Fri Jun 29 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180629.b29cbe4:
  * Adjust opensuse-leap-image references for multibuild
  * Add packages for Leap 15.0 JeOS
* Thu Jun 28 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180628.fdc0978:
  * obs_clone: start from :Rings:1-MinimalX instead of :Rings:2-TestDVD.
* Thu Jun 28 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180628.fc8db67:
  * osclib/stagingapi: attribute_value_load(): ensure using desired value.
* Wed Jun 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180627.d5144d3:
  * Fix JeOS snapshotable detection for Factory:ARM
* Tue Jun 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180626.ca7fec3:
  * TTM for Leap 15.1
  * Fix norelease
* Tue Jun 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180626.15618eb:
  * repo_checker: Fix config read/load
* Mon Jun 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180625.89c6f1c:
  * devel-project: reword notifier
* Thu Jun 21 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180621.c38f9ca:
  * metrics/access/aggregate: write zeros for empty product data.
* Thu Jun 21 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180621.58f5c91:
  * metrics/access/ingest: update pattern to handle most recent log format.
  * metrics/grafana/access: add explanation about loss of custom log format.
  * metrics/access/aggregate: change PONTIFEX base URL based on poo#36862.
  * metrics/grafana/access: remove broken datasource templating from export.
  * metrics/access/aggregate: remove left over sprintf() from PONTIFEX lines.
  * metrics/access/aggregate: skip the current day since the logs are incomplete.
  * dist/spec: move access.json dashboard to metrics-access package.
* Thu Jun 21 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180621.f2875ce:
  * pkglistgen: Don't warn about locked packages not found
  * pkglistgen: Copy away inc files too
  * pkglistgen: Output more infos about overlap
* Wed Jun 20 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180620.d4172e6:
  * osclib/stagingapi: superseded_request(): revert poor indentation changes.
  * metrics: thankfully we lived past the days of assembly variable name limits.
  * metrics: ingest_dashboard(): replace max_revision duplicate variable nonsense
  * Revert "Output Attribute metrics (not well tested)"
* Wed Jun 20 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180620.78e8212:
  * requestfinder: make devel project configurable
  * ttm: Do not put openqa comment if dryrun
  * ttm: Set snapshot number for Leap 15.0 Ports
  * ttm: Use openSUSE Leap 15.0 AArch64 not Ports
* Tue Jun 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180619.67121e2:
  * systemd/metrics-access.timer: skip Monday to avoid conflict with metrics.timer.
  * Output Attribute metrics (not well tested)
  * Catch 404 in metrics
  * Fix test cases
  * Don't store empty config attribute and propose migration
  * Catch 404 for attributes (python3 way)
  * Read lock attribute from remote config
  * Migrate SUSE config into attributes
  * Make remote-config mandatory
  * Move config into an OBS attribute
* Tue Jun 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180618.d41cbda:
  * metrics/access: add summary README.md.
  * dist: package metrics/access tool and related.
  * metrics/grafana: add access dashboard and data source.
  * metrics/access: initial aggregate script.
  * metrics/access: initial ingest script.
* Mon Jun 18 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180618.18c2ba3:
  * Make norelease the default for SLE
* Mon Jun 18 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180618.b646e55:
  * Generate an unsorted.group if configured
* Fri Jun 15 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180615.b05d559:
  * request_splitter: gcc8 is the default compiler now
* Fri Jun 15 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180615.3f7ae41:
  * Run ttm by systemd timer to prevent mem leaks
  * TTM: Remove project-base option
* Thu Jun 14 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180614.3b99137:
  * dist/ci/Dockerfile: add python2-pyOpenSSL as dependency.
  * TTM: Add norelease option for use with OSD
  * Refactor _check_project into ReviewBot
  * Also release 000product:openSUSE-ftp-ftp-armv7hl for Leap 15.0 ports
  * dist: Require python2-pika by totest-manager (new amqp dependency)
  * legal-auto: autopep8
  * Add retried_GET
  * Do not pass md5 but revision
  * Use UTC for created
  * Add project sub command to legal auto
  * pkglistgen: log unsorted locale packages
  * update-crawler: also log where requests came from
  * Handle armv6/armv7 with totest manager as well
* Mon Jun  4 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180604.ce0a143:
  * oqamaint: use the proper key to add incident repo
  * oqamaint: Make debuging of incident list in repohash easier
* Mon Jun  4 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180604.fb82c46:
  * metrics/grafana/release: score yaxis max 100.
* Thu May 31 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180531.95e0616:
  * Fix punctuation
  * Update announcer.py to ask people to report bugs
* Thu May 24 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180524.432237a:
  * openqa-maintenance: Make sure we don't go through requests twice
* Thu May 24 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180524.7ee44e7:
  * [openqa-maintenance] Add kernel incidents for SLE11
* Sun May 20 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180520.b621775:
  * openqabot: Quote the module name
* Fri May 18 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180518.3a01e88:
  * metrics: drop release schedule before writing.
* Fri May 18 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180518.6c6bccc:
  * metrics/annotation/leap:15.0: update final release date.
* Fri May 18 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180518.ef92c2f:
  * Add AMQP support to TTM
* Thu May 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180517.f446be2:
  * Freeze adi: do not check the first package in frozenlinks but metadata
* Wed May 16 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180516.9f20fc7:
  * repo_checker: whitelist_clean: handle binaries_common being None.
* Wed May 16 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180516.6459937:
  * repo_checker: sort whitelist before writing to config.
  * repo_checker: include final newline in dashboard/repo_checker file.
* Wed May 16 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180516.629cada:
  * [openqa-maint] fix apimap for SLE12SP2 HA
* Tue May 15 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180515.75b8a82:
  * Skip nonfree for ports scope
  * pkglistgen: Add ppc64le for Leap 15.0 Ports
* Tue May 15 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180515.fd25d09:
  * ttm: Load and Store the ignored issues in an OBS attribute
  * ttm: Store the last seen build number for each issue
* Mon May 14 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180514.8af3e4a:
  * Add maxsize for JeOS to handle openSUSE:Factory:ARM
* Mon May 14 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180514.f35a199:
  * ttm: Allow to ignore job failures without bug reference
* Mon May 14 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180514.5f4f4ef:
  * Begin porting to python3 (osc branch)
* Mon May 14 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180514.3ca5e48:
  * config/manager_42/leap:15.0: increase priority of SLE-workarounds.
* Fri May 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180511.eff4e45:
  * systemd: add service retry to support-rebuild which 502s regularly.
  * systemd: include SyslogIdentifier in each service to improve journal.
  * systemd: ensure all services have a relaxed RuntimeMaxSec.
  * systemd: drop Type=simple to be consistent since default not required.
* Fri May 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180511.4952872:
  * openqa-comments: drop openSUSE: prefix to allow for generic usage.
  * openqa-comments: meant to be executable thus should include a shebang.
* Fri May 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180511.af4e85a:
  * dist/spec: bump copyright year.
  * dist/spec: sort requirements.
  * dist/spec: update to new license standard.
  * dist/spec: move ExclusiveArch up to apply to all packages instead of devel.
* Fri May 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180510.a8b760d:
  * dist/spec: exclusively build on x86_64 to avoid needless builds and OBS bugs.
* Thu May 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180510.b4943dc:
  * osclib/conf: update nocleanup-packages post migration to new pkglistgen.
  * osclib/conf: change pkglistgen-include-suggested to False.
* Thu May 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180510.ae00f10:
  * dist: provide osrt-staging-bot-check_duplicate_binaries@.service.
* Thu May 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180510.846b2bd:
  * dist: provide openqa-comments service as part of staging-bot.
  * dist: package openqa-comments as executable.
* Thu May 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180510.afbd03d:
  * systemd/leaper-crawler.service: wrap script with bash to handle colon.
  * dist/package/spec: leaper package requires maintenance.
* Thu May 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180510.6fd17f1:
  * [oqamaint] Don't start and resolve incident job before is fully build
  * [oqamaint] Fix data for KGraft
* Wed May  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180509.90155fc:
  * osclib/comments: command_find: use MULTILINE mode.
  * osclib/comments: command_find: stupid \r line endings.
* Wed May  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180509.41bbae7:
  * manager_42: check if SLE-workarounds are no longer utilized and request removal.
* Wed May  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180509.324f7cc:
  * config/manager_42/Leap:15.0: update for Leap:15.0 source project reality.
  * config/manager_42/Leap:15.0: include from_proj in order to work properly.
  * config/manager_42/Leap:15.0: remove duplicate SLE-workarounds entry.
* Wed May  2 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180502.978881d:
  * [oqamaint] Take build number as last resort to avoid crash
  * [openqa-maintenance] Use to_xml method of Request object
  * [oqamaint] Do not export variables not necessary for scheduling
* Mon Apr 30 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180430.eb1d0be:
  * ReviewBot: runner: reload checker and reset memoize session caches.
  * osclib/memoize: provide memoize_session_reset().
* Fri Apr 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180427.1730947:
  * systemd/osrt-repo-checker-project_only@.timer: increase frequency to hourly.
  * repo_checker: project_only: store build hash and skip when unchanged.
* Fri Apr 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180427.adbbde2:
  * repo_checker: invoke whitelist_clean() as part of project_only.
  * repo_checker: whitelist_clean: provide interactive flag.
* Fri Apr 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180427.add0eb7:
  * [openqa-maintenance] Don't accept incidents waiting for build
  * osclib/check_duplicate_binaries: ignore any package arch that differs from arch.
  * osclib/check_duplicate_binaries: rewrite to use package_binary_list().
  * osclib/core: binary_src_debug: include nosrc as ignored arch.
  * osclib/core: package_binary_list: provide strip_multibuild option.
  * osclib/check_duplicate_binaries: drop unused imports post lnussel rework.
* Thu Apr 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180426.2550cb4:
  * osclib/check_duplicate_binaries: ignore s/glibc.i686/glibc:i686/.
* Thu Apr 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180426.2282f15:
  * metrics/grafana/dashboard: remove y-axis max from "Weekly Revisions".
* Thu Apr 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180426.2aba87c:
  * freeze_command: rebase staging project do not erase users data
* Thu Apr 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180425.abd03b3:
  * metrics: ingest_dashboard_config: rename seen to previous.
  * metrics: ingest_dashboard_config: initialize seen with last record keys.
  * metrics: ingest_dashboard_config: only fill missing values once.
* Thu Apr 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180425.94fefaf:
  * metrics/grafana/dashboard: add release schedule annotation.
  * metrics/grafana/dashboard: include dashboard description.
  * metrics/grafana/dashboard: change all selectors to last.
* Thu Apr 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180425.ade9313:
  * metrics: dashboard: drop dashboard measurement in favor of dashboard_revision.
  * metrics: dashboard: include revisions graph.
* Thu Apr 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180425.adab26c:
  * repo_checker: provide whitelist_clean subcommand.
  * osclib/core: correct BINARY_REGEX by making it greedy.
* Wed Apr 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180425.8bb627d:
  * [oqamaint] Reset the hashes on every review round
  * [oqamaint] Fix re-reviewing requests
  * [oqamaint] Do not append to OS_TEST_ISSUES
  * [oqamaint] Look at all open release requests for Updates
  * [oqamaint] Reschedule Updates test if the list of incidents changed
  * [oqamaint] Remove wrong entries in json
* Wed Apr 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180424.2010288:
  * osclib/accept_command: avoid making empty commit to dashboard.
* Tue Apr 24 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180424.855f660:
  * unmaintained: utilize package_binary_list(exclude_src_debug).
  * osclib/core: package_binary_list(): provide exclude_src_debug option.
* Tue Apr 24 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180423.fe2e20a:
  * metrics/grafana: add dashboard.json.
  * metrics: ingest relevant dashboard files and extract metrics.
  * metrics: provide dashboard revision walking function and cache patterns.
  * metrics: instead of wiping cache place ephemeral patterns behind flag.
  * osclib/stagingapi: dashboard_content_load(): expose revision parameter.
* Mon Apr 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180423.6d46e97:
  * metrics/grafana/staging: move legend to right side on pie charts.
  * metrics/grafana/review: increase hieght on lists to accomodate size.
  * metrics/grafana/release: increase width to 100%% grid width.
* Mon Apr 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180423.884aa1f:
  * [openqa-maintenance] Add openSUSE Leap 15.0 configuration
* Mon Apr 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180423.dce40cb:
  * [oqamaint] Fix indentation
  * [oqamaint] Use reviewbot's comment API
  * [oqamaint] Add OS_TEST_ISSUES as openSUSE repo settings
  * [oqamaint] Make settings a hash instead of an array
  * [oqamaint] Remove symlinks - not necessary according to my experiments
  * [oqamaint] Create mesh compatible data for openSUSE
  * [oqamaint] Fetch the list of packages for openSUSE
  * [oqamaint] Fix openSUSE support
  * Rename openqa-maintenance2 to openqa-maintenance
* Mon Apr 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180423.750f091:
  * metrics/annotation: add openSUSE:Leap:15.0 schedule.
  * Handle the JeOS multibuild package for Factory:ARM:Live
  * leaper: update diff link to also link to package itself
  * leaper: fix link to SLE-workarounds
  * Handle Leap:15.0:Ports images_arm repository
* Thu Apr 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180419.3dcaf5c:
  * Handle more products for Factory:ARM
* Wed Apr 18 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180418.c725593:
  * devel-project: notify: utilize osclib.core.package_list_without_links().
  * osclib/core: provide package_list_without_links().
  * devel-project: remove unused imports.
* Tue Apr 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180417.5b2296e:
  * dist/ci/obs-build-target: in include --always to git describe.
  * Makefile: package all executable files in bindir.
  * metrics_release: remove executable flag left over from development.
* Tue Apr 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180417.e92d7bf:
  * check_tags_in_requests: replace check_action__default() with built-in.
  * legal-auto: replace check_action__default() with built-in.
* Tue Apr 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180417.038cb94:
  * ReviewBot: disable comment handler for default action handler.
* Tue Apr 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180417.b8337f4:
  * [openqabot-maintenance] Catch HTTPError when try get REPOHASH
  * [openqa-maintenance] SLE 12 SP2 LTSS
  * [openqa-maintenance] start HA/SES jobs only wheen are required
  * [openqa-mainteance] Add data for SES5
  * [openqa-maintenance] catch removed incident project
  * [openqa-maintenance] add missing arch for Live Patching apimap
  * [openqa-maintenance] Allow OS_TEST_ISSUES different than product prefix
  * [openqa-maintenance] Fix WSM and TCM issues data
  * [openqa-maintenance] Add correct issues for SLE-HA to apimap
  * [openqa-maintenance] Survive malformed repomd.xml
  * [openqa-maintenance] Add SLE-HA incidents
  * [openqa-maintenance] Allow and correctly use other distri from apimap.json
  * [openqa-maintenance] Add data for CAASP
  * [openqa-maintenance] Add data for KGraft on ppc64le
  * [openqa-maintenance] Start Incidents-Kernel flavour also for kernel packages
  * [openqa-maintenance] Add support for kGraft jobs
  * [openqa-maintenance] Rewrite of openqa-maintenace bot pt.1
  * [openqa-maintenance] Add apimap and incidents data for kGraft
  * [openqa-naintenance] Remove uneeded kGraft data
* Mon Apr 16 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180416.dc30723:
  * unmaintained: tool to find umaintained binaries sourced from SLE.
  * osclib/core: provide source_file_load() from StagingAPI.
* Fri Apr 13 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180413.71fd5fe:
  * pkglistgen: do_update_and_solve(): print exception and continue for all projects.
* Wed Apr 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180411.820d103:
  * issue-diff: utilize entity_mail() as adapted into osclib.core.
  * devel-project: provide notify sub-command.
  * osclib/util: provide mail_send(), modified from announcer.py.
  * osclib/core: provide entity_email(), modified from issue-diff.py.
* Fri Apr  6 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180406.ace73fe:
  * ttm: adjust regexp to include Snapshot
  * ttm: fix leap 15 docker image handling
* Thu Apr  5 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180405.e96a27a:
  * Staging2-DVD: Drop pattern gnome_laptop
  * create_test_dvds: Gcc7 staging project was resurrected
* Tue Apr  3 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180403.78ea7dd:
  * check_source: skip checks for packages without spec file
* Thu Mar 29 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180329.1ab84c3:
  * Change remaining usage of _product to 000product
  * leaper: set maintainer review early
  * leaper: also look into :Live subproject of Factory
* Thu Mar 29 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180329.9ad18cf:
  * Staging accept: run service in ports 000product
* Thu Mar 29 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180329.8097ab6:
  * conf: make sure variable is not None before do lower()
* Wed Mar 28 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180328.f195bc7:
  * repo-checker: Check delete requests for provided runtime dependencies
  * API: move fileinfo_ext[_all] from StagingAPI to core
* Mon Mar 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180326.b4c885d:
  * totest_manager: Also release openSUSE:Leap:15.0:Images/opensuse-leap-image
  * totest-manager: Tumbleweed moved to the new product builder
* Fri Mar 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180323.5d0c024:
  * leaper: allow comment override also on openSUSE
  * Add create_sle_weakremovers command
* Mon Mar 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180319.133d87b:
  * Change references to osc-plugin-factory to openSUSE-release-tools.
  * check_source: make use of ReviewBot request_default_return.
  * check_source_in_factory: allow repo-checker reviews.
* Sat Mar 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180317.88a6e97:
  * check_source: delete: place maintainer review check behind ignore_devel.
  * osclib/conf: SLE-15: set check-source-in-air-rename-allow to True.
  * check_source: provide in-air-rename-allow config setting.
* Fri Mar 16 2018 jberry@suse.com
- Point to new source location.
* Thu Mar 15 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180315.d11501f:
  * check_source: skip all checks for 00* packages
  * Use opensuse/tumbleweed in the Dockerfile
  * Avoid boolean dependencies for repo checker
* Thu Mar 15 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180314.3bd6833:
  * metrics_release: only works for openSUSE:Factory.
  * metrics: do not drop entire database, but instead measurements.
  * metrics: switch over to grafana 5.x provisioning.
  * metrics: remove TW snapshots graph from release dashboard.
  * metrics: migrate grafana dashboards to 5.x format.
* Mon Mar 12 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180312.9a26912:
  * pkglistgen: do_dump_solv(): include hash in update solv to avoid download.
  * pkglistgen: do_dump_solv(): utilize os.path.join().
* Mon Mar 12 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180312.054eef2:
  * ReviewBot: make interval work without tty
* Mon Mar 12 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180312.35e7c51:
  * services: Add Install section to totest-manager service
* Sun Mar 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180311.ad60562:
  * ReviewBot: don't crash if staging-group is None
  * check_source: make adding review team configurable
  * check_source: fix boolean option
  * pkglistgen: Fix reading boolean values
* Fri Mar  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180309.d001daf:
  * issue-diff: rename --config-dir as --cache-dir to be more accurate.
  * issue-diff: replace git sync functionality with osclib.git.
  * osclib/git: provide git utilities: clone() and sync().
* Fri Mar  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180309.fe4edd6:
  * Treat stagings differently
* Fri Mar  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180309.7484722:
  * pkglistgen: do_dump_solv: flush after write before reading back.
  * pkglistgen: do_dump_solv: verify primary repo gziped content sha256.
  * pkglistgen: do_dump_solv: use BytesIo instead of StringIO.
* Fri Mar  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180309.f20816d:
  * pkglistgen: Do not run local service check when committing to release package
* Fri Mar  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180309.f607883:
  * leaper: fix can_accept_review for combined user/group usage
  * create_test_Factory: No longer block kdelibs4-branding-upstream
* Fri Mar  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180309.d9773c3:
  * metrics: provide release metrics ingestion and dashboard.
* Thu Mar  8 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180308.568be98:
  * osclib/stagingapi: rename main_repo to cmain_repo.
  * osclib/stagingapi: rename delreq_review to cdelreq_review.
  * osclib/stagingapi: rename cstaging_nocleanup to cnocleanup_packages.
  * osclib/staging-api: lazy-load all config values to allow for placement in remote config.
* Thu Mar  8 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180308.17ebaaa:
  * ReviewBot: allow both group and user review
* Thu Mar  8 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180308.defd995:
  * osclib/conf: change priority to be string to work with ConfigParser.
* Thu Mar  8 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180308.3e83a1f:
  * leaper: do not decline SLE requests, but rather ask managers for input.
  * osclib/conf: configure SLE-15 leaper-override-group.
  * leaper: move review groups to osclib.conf.
* Wed Mar  7 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180307.f6eae67:
  * repo_checker: format what_depends_on as markdown bulleted list.
* Wed Mar  7 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180307.d30db7e:
  * repo_checker: provide comment command to skip-cycle for group.
  * repo_checker: utilize ReviewBot.comment_api instead of new instance.
  * ReviewBot: provide comment command override.
  * osclib/core: maintainers_get(): utilize new group_members() function.
  * osclib/core: provide group_members() function.
  * osclib/comments: provide command_find() for comment commands.
* Tue Mar  6 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180306.a9ec91f:
  * ReviewBot: do not bother commenting for unhandled request type.
* Thu Mar  1 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180301.bac6644:
  * fix a typo that currently breaks token authentication
* Tue Feb 27 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180227.adb01e2:
  * ttm: use dashboard_content_ensure()
* Fri Feb 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180223.e8c002d:
  * ttm: handle Leap 15 live images separately
  * requestfinder: make sure exclude-project is a list
  * requestfinder: fix exclude-user and add exclude-group
  * leaper: allow turning FORK into something else
* Fri Feb 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180223.af01909:
  * Staging2-DVD: should be Mesa-demo-x for glxgear test
* Thu Feb 22 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180222.db87a62:
  * Do not complain 000* package has defined in the two different ring
* Thu Feb 22 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180222.21777cc:
  * TW Staging media: Add Mesa-demo to Staging2 DVD for openQA test
* Thu Feb 22 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180222.009712a:
  * ttm: Follow package name changes of Tumbleweed live media
* Wed Feb 21 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180221.355c0b4:
  * Revert "staging: add exceptions for new 000* product files"
* Wed Feb 21 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180220.f56ccb8:
  * pkglistgen: solv_cache_update(): support update repo and 4 way merge.
  * pkglistgen: do_dump_solv(): support update repos.
  * pkglistgen: solv_merge(): allow array of solv files to merge.
  * pkglistgen: solv_merge(): skip when inputs are older than merged.
  * osclib/conf: leap: set download-baseurl-update.
* Tue Feb 20 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180220.945bf4f:
  * metrics: ingest_release_schedule(): disable for Tumbleweed until #1250.
  * metrics: update Leap config key to match osclib/conf post #1386.
* Tue Feb 20 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180220.fc7e60b:
  * pkglistgen: use set_namespaceproviders function
* Thu Feb 15 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180215.60cfab2:
  * osclib/conf: leap: repo_checker-arch-whitelist to x86_64.
* Tue Feb 13 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180213.c589ef1:
  * autopep8 to fix indenting
  * Move package hints into unsorted.yml
  * Support unneeded.yml as list of regular expressions
* Tue Feb 13 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180213.3e3f458:
  * conf: SLE-15: set pkglistgen-product-family-last to SLE-11:GA.
  * pkglistgen: expose pkglistgen-product-family-last config option.
  * osclib/util: project_list_family_prior(): provide last parameter.
  * osclib/util: project_list_family(): handle IBS SLE naming style.
  * pkglistgen: do_update_and_solve(): check for existence of :DVD instead of rings.
* Tue Feb 13 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180212.7f93dbe:
  * Skip automatic rebuild for more pattern packages
  * Avoid hitting the request limit
  * Fix rebuildpacs for armv6/armv7 architectures
* Mon Feb 12 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180212.87ab899:
  * leaper: don't check maintainer for other requests
* Fri Feb  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180209.ad077ab:
  * leaper: switch off maintainer review for updates from Factory
* Wed Feb  7 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180207.878b87b:
  * osc-staging: select: reword documentation to include XML reference.
  * osc-staging: select: mention additional supplemented request values.
  * osc-staging: select: mention quick strategy in documentation.
  * osc-staging: select: add filter-by example using hashtag in description.
* Wed Feb  7 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180206.56df1cf:
  * osclib/conf: include Leap for Factory during pkglistgen.
  * pkglistgen: include some hints about the difference between solv files.
  * pkglistgen: integrate drop list creation into update_and_solve.
  * pkglistgen: do_dump_solv(): handle old-style product repo format.
  * pkglistgen: do_create_droplist(): print to file when output_dir available.
  * pkglistgen: provide update_merge() to combine free and nonfree solv.
  * osclib/util: provide project_list_family* and project_version().
  * osclib/stagingapi: get_staging_projects(): utilize project_list_prefix().
  * osclib/core: provide project_list_prefix().
  * osclib/conf: add download-baseurl for Leap and Factory.
  * osclib/conf: support version in project pattern as value replacement.
* Wed Feb  7 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180206.faa028a:
  * osclib/conf: leap: incorporate proven unselect settings.
  * osclib/conf: leap: incorporate proven splitter settings.
* Tue Feb  6 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180206.453868a:
  * remove Leap 42.2 from tests
* Sat Feb  3 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180203.cd1fa5d:
  * CreatePackageDescr: ignore debuginfo.build deps for i-i-debuginfodeps* packages
* Thu Feb  1 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180201.10fd5ae:
  * pkglistegen: Fix overlap generation
* Wed Jan 31 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180131.b78d3b9:
  * build-faul-reminder: Small rewording of the 2nd mail
* Wed Jan 31 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180131.d88eefe:
  * adi: place :NonFree requests in separate adi with :NonFree path.
* Tue Jan 30 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180130.40c4c14:
  * status: fallback to request_age() even if no comment.
* Tue Jan 30 2018 jberry@suse.com
- Update to version 20180129.5a472eb:
  * osclib/core: request_age() return delta and handle Request object.
  * create_test_dvds: do not lock vim-data
  * fcc_submitter: skip revoked request
* Fri Jan 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180126.574cfe8:
  * status: provide exit code based on status.
  * status: provide initial implementation for checking bot status.
  * osclib/request_splitter: utilize osclib.core.request_age().
  * devel-project: utilize osclib.core.request_age().
  * osclib/core: provide request_age().
* Fri Jan 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180126.2c8c597:
  * osclib/accept: print todo from staging config after completion.
* Fri Jan 26 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180125.39c9cce:
  * check_source: add hint about how to whitelist a devel projects.
* Thu Jan 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180125.a5dbcd1:
  * dist/spec: place config under %%config(noreplace) directive.
  * announcer: handle dot in build version detected from iso.
  * config/announcer: add openSUSE:Factory config.
  * announcer: provide defaults for sender, to, and relay.
  * config/announcer: create Leap 15.0 config from 42.3.
  * config/announcer: drop repeated keys in favor of final values.
  * config/announcer: include config used for Leap 42.3.
  * announcer: provide proper packaging and generic templated service.
* Thu Jan 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180125.3cf74b3:
  * dist/ci/obs-deploy: replace `osc request list` with `osc api` call.
* Thu Jan 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180125.753f6c7:
  * dist/ci/docker-compose-obs: print osc output on timeout for debugging.
* Thu Jan 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180125.d383073:
  * repo_checker: skip packages for which not devel project exits.
  * repo_checker: project_only(): correct not published check.
* Thu Jan 25 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180125.9a91597:
  * dist/ci/obs-deploy: only commit if new source revision.
  * dist/ci/obs-deploy: require greater than six lines changed to create request.
* Tue Jan 23 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180123.d074c5b:
  * Remove Vim config in favor of EditorConfig.
  * Add EditorConfig.
* Mon Jan 22 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180122.b5fe7e7:
  * dist/ci/obs-deploy: only bother making request if diff.
  * dist/ci/obs-deploy: limit `request list` by user to avoid source requests.
  * docs/pkglistgen: update in the wake of wrapper script rewrite.
* Fri Jan 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180119.a7c4bcf:
  * repo_checker: package_comments(): provide option to post on target package.
  * repo_checker: package_comments(): switch to devel_project_fallback().
  * repo_checker: package_comments(): support mutiple target projects.
  * ReviewBot: comment_write(): provide bot_name_suffix parameter.
  * repo_checker: package_comments(): include link to target package.
* Fri Jan 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180119.2d6b957:
  * check_source: add_role: utilize devel project fallback.
* Fri Jan 19 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180119.38fd846:
  * osclib/request_splitter: replace devel_project_get() with core.devel_project_fallback().
  * osclib/stagingapi: replace get_devel_project() with core.devel_project_get().
  * update_crawler: replace get_devel_project() with osclib.core.devel_project_get().
  * fcc_submitter: replace get_devel_project() with osclib.core.devel_project_get().
  * ReviewBot: replace get_devel_project() with osclib.core.devel_project_get().
  * osclib/core: devel_project_fallback(): do not fallback if openSUSE:Factory.
  * osclib/core: provide devel_project_fallback() based on request_splitter.
  * osclib/core: provide devel_project_get() adapted from ReviewBot.
  * news/web: allow dot in version.
  * cleanup_rings: Fix for 000product
  * cleanup_rings: first attempt to fix for multibuild
* Wed Jan 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180117.b6d80ea:
  * fcc_submitter: fix a regression from previous commit
* Wed Jan 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180117.e41b40e:
  * requestfinder: fix comment output
* Wed Jan 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180117.b335868:
  * pkglistgen: delete kiwis by scope
* Wed Jan 17 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180115.2da7981:
  * osclib/request_splitter: rework quick strategy to handle Leap 15.0 workflow.
  * obs_clone: reword comment in project_workaround() since not temporary.
  * obs_clone: clone rings.
  * obs_clone: handle project links.
  * osclib/request_splitter: allow special packages to be empty.
  * fcc_submitter: ignore multibuild flavor package when creating frozenlinks
  * fcc_submitter: move FCC project to :Staging:Factory:Candidates
  * new requestfinder tool
* Fri Jan 12 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180112.41846c5:
  * systemd/metrics: change service to be non-incremental and weekly.
  * metrics: provide --wipe-cache option.
* Thu Jan 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180111.54880d3:
  * dist/spec: license: s/and/AND/ to follow standard.
* Thu Jan 11 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180110.9ab0211:
  * obs_clone: workaround openSUSE:Factory meta revision 429 self reference.
  * obs_clone: set the exit code to 1 when HTTPError encountered.
* Wed Jan 10 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180110.453674c:
  * pkglistgen: typo locals vs locales
  * pkglistgen: add correct staging DVD repo
  * pkglistgen: use xdg.BaseDirectory
* Tue Jan  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180109.29108bd:
  * pkglistgen: do_update_and_solve: staging correct :DVD subproject append.
  * pkglistgen: first pass __file__ through realpath due to packaging symlink.
  * dist/spec: move pkglistgen.py under subpackage ownership.
  * dist/spec: add python-requests requirement were applicable.
* Tue Jan  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180109.09a98cd:
  * osclib/conf: intial SLE configuration for pkglistgen.
  * pkglistgen: update_and_solve: include step in output for debugging.
  * pkglistgen: update_and_solve: handle --dry for undelete_package().
  * pkglistgen: update_and_solve: include ignore_unresolvable and local options for solve.
  * pkglistgen: update_and_solve: set input_dir to group_dir for solve.
  * osclib/conf: correct Leap 15.0 default locales-from from - to . product.
  * systemd/pkglistgen: add update_and_solve subcommand.
* Tue Jan  9 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180109.2b037a0:
  * osclib/conf: allow devel projects to utilize tools that require conf.
  * osclib/conf: order config defaults by priority.
* Fri Jan  5 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180105.7eaed34:
  * Revert "osclib/conf: allow devel projects to utilize tools that require conf."
* Thu Jan  4 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180104.43dea82:
  * tests/ReviewBot_tests: add test_dryrun().
  * tests/ReviewBot_tests: add test_only_replace_none().
  * tests/ReviewBot_tests: add test_workflow() complex test.
  * tests/ReviewBot_tests: add test_basic_logger() as initial test.
* Thu Jan  4 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180104.656cba4:
  * tests/comment_test: add test_delete_nested().
  * tests/comment_test: add test_delete_batch().
  * tests/comment_test: add test_basic() against OBSLocal.
  * tests/comment_test: move COMMENT* constants to file level.
  * tests/OBSLocal: re-parse config and reset authentication when changing user.
  * tests/OBSLocal: setup test separate cookiejar.
  * tests/comment_tests: add test_comment_find().
  * tests/comment_tests: add test_remove_marker().
  * tests/comment_tests: add test_add_marker().
* Thu Jan  4 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180104.b0cd970:
  * osclib/conf: allow devel projects to utilize tools that require conf.
* Thu Jan  4 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180104.e1b5d75:
  * osclib/stagingapi: detect baselibs.conf in adi package and ensure archs enabled.
  * check_source: load target project config during check_action_delete().
  * osclib/stagingapi: load_file_content(): provide optional revision param.
  * osclib/stagingapi: load_file_content(): convert to makeurl() query builder.
* Tue Jan  2 2018 opensuse-releaseteam@opensuse.org
- Update to version 20180102.98a659c:
  * manager42: ignore meta packages
  * manager42: refactor
  * manager42: don't turn dropped packages into fork
  * manager42: warn about inconsistent packages
  * reochecker: avoid accessing empty status
  * repo_checker: only update comment if published or message changed.
  * ReviewBot: comment_write(): provide info_extra_identical parameter.
  * fcc_submitter: handle multibuild package in build_succeeded package list
  * check_duplicate_binaries: better yaml
  * pkglistgen: migrate bash scripts to python.
  * osclib/stagingapi: provide is_staging_bootstrapped() from request_splitter.
  * ToolBase: provide -d alias for --debug for consistency.
* Tue Dec 26 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171226.96a3eec:
  * rebuildpacs: rebuild perf
* Wed Dec 20 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171220.ba8a357:
  * Be more forgiving with ttm ignore comments
* Tue Dec 19 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171219.ce7c0d9:
  * freeze_command: use result call to get proper multibuild package information for aggregatepac
* Tue Dec 19 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171219.55e468e:
  * Fix travis failure introduced with 3e5f3b137
  * Fix packaging after commit 3e5f3b137
  * Don't checkout master
  * Add 15.0 Ports to totest-manager
  * pkglistgen: Actually remove overlapping packages
  * Add support for non-x86_64 products (Leap 15.0/aarch64)
  * Scripts and templates to create stagings
  * systemd units: remove oneshot type
* Mon Dec 18 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171218.09707c0:
  * Update staging dvd template for firewalld and xfsprogs
  * rebuildpacs: ignore hdf5:serial
* Thu Dec 14 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171214.0fecf50:
  * osc-cycle: strip commas from package names
* Wed Dec 13 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171213.3dde523:
  * pkglistgen: Output the overlaping packages into overlap.group
* Tue Dec 12 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171212.bffe857:
  * totest-manager: Make sure internal object for notifications is always valid
* Fri Dec  8 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171208.d7c5a3e:
  * compare_pkglist: do not submit package if it has removed from target
  * pkglistgen: dump_solv function
  * pkglistgen: add droplist generator
  * pkglistgen: include locales and suggested
  * biarchtool: blacklist 000release-packages
  * biarchtool: also work for rings
  * biarchtool: blacklist patterns that are in ring1
  * biarchtool: fetch all packagemetas at once
* Tue Dec  5 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171205.1769209:
  * compare_pkglist: improve submission message
  * compare_pkglist: add feature to limits submission creating
  * compare_pkglist: fix a typo
* Mon Dec  4 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171204.4661a09:
  * rebuildpacs: Ignore some more multibuild packages
  * repochecker: filter out self requirement
  * repochecker: add --force and --limit-group options
* Mon Dec  4 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171204.86cd536:
  * compare_pkglist: fallback to old route if submitfrom and submitto has not defined
* Fri Dec  1 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171201.913531e:
  * osclib/cycles: only cache target project builddepinfo to avoid excessive cache.
  * osclib/cycles: drop _get_builddepinfo and _get_builddepinfo_cycles since unused.
  * Add more details to openQA job group description about current status
* Thu Nov 30 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171130.3b99a9d:
  * compare_pkglist: add more features
* Mon Nov 27 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171127.60cdcec:
  * check_source: Ignore download_files failure in some cases
* Mon Nov 27 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171127.3368dd5:
  * Implement namespace callback for locales
  * pkglistgen: Optionally include suggested packages too
  * fcc_submitter: update to Leap 15.0
  * ttm: Add support for SLE 15
* Wed Nov 22 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171122.ea9f948:
  * Split EDITOR environment variable to handle flags in prefix.
* Wed Nov 22 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171122.b428ed3:
  * compare_pkglist: Add --submit param to submit new package
* Tue Nov 21 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171121.734e384:
  * pkglistgen: need to expand link
  * pkglistgen: require python-solv
* Tue Nov 21 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171121.0d31ae5:
  * pkglistgen: Fix script name
  * Skip maintainer review for certain Leap 15 submissions
* Mon Nov 20 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171120.fc6eb19:
  * pkglistgen: require obs-service-product_converter
  * pkglistgen: add systemd units
  * pkglistgen: use new cache format of repo_checker
  * pkglistgen: process DVD subproject first
* Mon Nov 20 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171120.87649f1:
  * suppkg_rebuild: count Support tag also
* Wed Nov 15 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171115.6140695:
  * compare_pkglist: displays deleted package
  * compare_pkglist: misc improvements
* Sun Nov 12 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171112.b690943:
  * pkglistgen: fix up coolo's code
  * pkglistgen: Output overlapping packages as yaml
  * pkglistgen: Allow new recommended flag to take over recommends
  * pkglistgen: Ignore modules recursively
  * pkglistgen: Implement UNWANTED support
  * pkglistgen: Do not ignore recommendes from other modules
  * pkglistgen: Have update command exit 1 if it updated something
  * pkglistgen: Create an unsorted.yml and output duplications
* Fri Nov 10 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171110.5906e5c:
  * dist/spec: appease the exit status gods with || true.
  * dist/spec: restart totest-manager instances properly.
  * dist/spec: only run %%systemd_postun for oneshot services.
* Thu Nov  9 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171109.f927c57:
  * metrics: rework to store points as named tuple and write in batches.
  * metrics: rework request pagination to provide as generator.
  * metrics: call ET.clear() to release unneeded memory used by search result.
* Thu Nov  9 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171109.bcdea68:
  * Don't die on delete requests
* Thu Nov  9 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171109.3e191ca:
  * repo_checker: review failed stagings with only openQA failures.
* Thu Nov  9 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171109.1efadc5:
  * metrics/grafana/review: include opensuse-review-team who graphs.
  * metrics/grafana/review: default to openSUSE:Factory.
  * metrics/grafana/review: disable annotations by default.
  * metrics/grafana/staging: "Project stats" to "Totals"
  * metrics/grafana/staging: remove 1s interval as it causes RAM issues.
  * metrics/grafana: standardize title prefix with 'OSRT: '.
  * dist/ci: grafana dir must be owned by grafana user since it writes lock.
  * dist/spec: correct metrics postun to reference systemctl by absolute path.
  * metrics: prefix release schedule file with source dir path.
* Thu Nov  9 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171109.3d34370:
  * ttm: publish non-oss for Leap 15 too
* Fri Nov  3 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171103.593c900:
  * dist: provide metrics service and timer.
  * dist: install exported dashboards in grafana dashboard directory.
  * dist: include metrics.py in bindir.
  * dist: move package_name variable to Makefile.common.
* Fri Nov  3 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171103.f5bc6b6:
  * vdelreq: add to the package
  * osc vdelreq: new command lists pending virtually accepted delete request status
* Thu Nov  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171102.0a45aba:
  * accept_command: remove the ring package if it is 2nd specfile is removed
  * accept_command: force to accept the staging if --force parameter is given
* Wed Nov  1 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171031.d8cd193:
  * systemd/devel-list: allow three retry attempts to handle regular OBS crash.
* Wed Nov  1 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171031.0e1733f:
  * repo_checker: add newline to cycles comment to format properly.
  * repo_checker: project_only place dashboard update behind dryrun check.
  * repo_checker: project_only ensure project repository is published.
  * repo_checker: store and compare build hash to skip more aggressively.
* Tue Oct 31 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171031.c32b59b:
  * devel-project: override osc.core.search() to include withfullhistory for get_review_list().
* Sat Oct 28 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171028.9cded5c:
  * pkglistgen: also output suggested packages
* Fri Oct 27 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171027.63cde26:
  * pkglistgen: don't export skip_releases
* Wed Oct 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171025.42b8b4d:
  * osclib/memoize: include first argument, sometimes instance, in cache key.
* Tue Oct 24 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171024.32d1a97:
  * tests/OBSLocal: invoke scripts using `coverage` to include in report.
  * tests/OBSLocal: split out execute() to provide osc and generic versions.
  * tests/OBSLocal: include assertOBS() to clarify OBS status before test.
  * tests/OBSLocal: add email and include spaces in generated oscrc file.
  * tests/OBSLocal: rework OSCRC handling to use non-default file.
  * tests/OBSLocal: add workaround for obs.py leakage.
  * travis: before_cache: include -R in chmod .docker-tmp.
  * obs_clone: remove whole repositories rather than just path when fenced.
  * obs_clone: provide --cache feature.
  * osclib/cache: allow  ttl of 0 to prevent caching.
  * dist/spec: disable `make check` during %%check until integration tests resolved.
  * Exclude .open-build-service/ from docker, flake8, and git.
  * travis: provide local OBS setup and clone base data.
  * tests/devel_project: provide basic test against local OBS.
  * tests/OBSLocal: provide based class for testing against local OBS.
  * obs_clone: clone projects and dependencies between OBS instances.
  * devel-project: list: only remove self if in devel project list.
* Tue Oct 24 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171024.443b432:
  * osclib/conf: prefer already parsed conffile over OSC_CONFIG env variable.
  * tests/obs: move Cache.delete_all() after CACHE_DIR changed.
* Tue Oct 24 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171024.1c17971:
  * Blacklist new warnings introduced by flake8 3.5.0
* Tue Oct 24 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171024.737d39a:
  * pkglistgen: dont mirror debug packages
  * pkglistgen: skip one cycle when undeleting
* Sat Oct 21 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171021.9465b2f:
  * dist: add subpackage for pkglistgen
  * pkglisten: add some docu
  * pkglistgen: shell scripts to actually commit
* Sat Oct 21 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171020.0479513:
  * travis: chmod .docker-tmp so non-root can read for caching.
  * travis: extend cache timeout to 7 days.
  * travis: optimize `osc build` cache by removing build-root.
  * travis: enable pip cache.
  * travis: install realpath to allow docker-run to correctly mount volume.
* Sat Oct 21 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171020.ee34178:
  * travis: include all files instead of just osclib in coverage.
* Fri Oct 20 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171020.7d266d5:
  * Another set of low-noise flake8 cleanups
  * Parallelize flake8 run
* Fri Oct 20 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171019.24ea059:
  * dist/ci/docker-run: utilize throwaway credentials to workaround OBS issue.
  * dist/ci/osc-init: print OBS_API and OBS_USER for debugging.
  * dist/ci: use hidden directory .docker-tmp instead of HOME and cache on travis.
  * dist/ci: fallback to /public OBS API in the event of no OBS_PASS
  * dist/ci: provide OBS_API parameter.
  * travis: add distribution builds for Leap 42.3 and SLE-12-SP3.
  * dist/ci: rework spec.sh as obs-build-target using `osc build`.
  * dist/ci: extract common osc setup as osc-init and provide in /usr/bin.
  * dist/ci/Dockerfile: include obs-deploy in /usr/bin.
  * dist/ci: rename deploy.obs.sh to obs-deploy.
  * dist/ci/deploy: only commit if changes available to commit.
  * dist/ci/deploy: only add line if missing from _servicedata.
  * dist/ci/Dockerfile: switch to base tumbleweed image.
* Fri Oct 20 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171019.6b7fd1b:
  * Enable F405,F811 (Unused imports)
  * Add Flake8 travis infrastructure
  * Import all dependencies
  * White space / consistent usage of spaces / indentation of 4 fixes
  * Remove outdated script
* Thu Oct 19 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171019.be5b3ec:
  * devel-project: utilize get_request_list(withfullhistory) param provided by osc 0.160.0.
* Thu Oct 19 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171018.44e44a6:
  * Python 2.6+ / 3.x style except clauses
  * osclib/request_splitter: provide splitter-special-packages config variable.
  * osclib/request_splitter: reduce default list of special packages.
  * Rename checknewer to checknewer.py and fix Flake8 fallout
* Tue Oct 17 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171017.53f281e:
  * osc-staging: select -i: include remaining requests in comment.
  * osc-staging: select -i: s/merged/mergeable/ in stat comment.
* Tue Oct 17 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171017.1168d47:
  * Fix undefined variables 'release'
* Tue Oct 17 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171017.7058f07:
  * check_source: decline the delete request if duplicated
* Fri Oct 13 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171013.406f870:
  * pkglistgen: initial work for openSUSE
  * pkglistgen: make --repositories option use an array
  * pkglistgen: add --ignore-unresolvable and --ignore-recommends options
* Fri Oct 13 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171013.b00a8f5:
  * osclib/stagingapi: get_staging_projects(): provide include_dvd option.
  * check_source: print message if checking devel project.
  * check_source: move all relevant flags to config to work properly without flags.
  * ttm: update for Leap 15.0
  * osclib: provide ConfigCommand and expose via osc-staging.
  * repo_checker: utilize staging configuration for whitelist additions.
  * repo_checker: filter empty whitelist entries.
  * osclib/stagingapi: set_prj_pseudometa(): only change if different.
  * osclib/freeze: clear staging config during freeze as well.
* Tue Oct 10 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171010.a2ba667:
  * dist: provide check-source subpackage.
* Tue Oct 10 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171010.73cec11:
  * dist: provide maintenance subpackage.
* Tue Oct 10 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171010.3ed4156:
  * dist: rework totest-manager subpackage to provide new style service.
  * dist/spec: add python-openqa_client as Requires for totest-manager.
  * dist/spec: totest-manager: reword to avoid dollar sign.
* Tue Oct 10 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171010.f50ea95:
  * dist: provide leaper services and related configuration.
* Tue Oct 10 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171010.de533a2:
  * dist: provide staging-bot subpackage for related services.
  * dist/spec: include project_only repo-checker service in pre/post.
  * dist: provide staging-bot-devel-list service (changed from leaper).
  * dist: include suppkg_rebuild in staging-bot subpackage.
  * dist: include supersede service in staging-bot subpackage.
* Tue Oct 10 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171010.02e5000:
  * staging: add exceptions for new 000* product files
* Mon Oct  9 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171009.afbe149:
  * check_source: Ensure the source and destination package name matches
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.e1c7377:
  * dist/ci/deploy: handle expanded links during target project loookup.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.4b7fb2f:
  * dist/ci/deploy: wait for service to complete before create submit request.
  * dist/ci/deploy: automatically detect target project and package.
  * dist/ci/deploy: pipe `osc sr --diff` to cat to ensure same behavior manually run.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.49fa091:
  * travis: include OBS_TARGET_PROJECT env variable during deploy script.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.e6d2ffc:
  * dist/ci/deploy: create submit request if none currently exists.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.e8e1a3d:
  * Initial metrics ingestion, processing, write to influxdb, and grafana dashboards.
  * docs/metrics.md: initial documentation of metrics workflow.
  * dist/spec: create metrics sub-package.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.9621116:
  * check_source: drop unnecessary dest from add_option().
  * check_source: drop inaccurate "with > 8 diff" from --review-team option.
  * check_source: interpret "None" as python None for review-team and repo-checker.
  * check_source: lookup staging group using StagingAPI rather than flag.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.b325f15:
  * dist: provide repo-checker sub-package with binary in path, service, and user.
  * repo_checker: project_only(): correct result_comment() usage.
  * dist/spec: include perl script requirements.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.b129a13:
  * ReviewBot: comment_write(): add info_extra parameter.
  * ReviewBot: comment_write(): add overview documentation.
  * ReviewBot: comment_write(): pre-truncate for correct comparison.
  * ReviewBot: comment_write() no need to str() since None is exits above.
* Fri Oct  6 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171006.a63d00c:
  * leaper: ignore 404
* Wed Oct  4 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171004.d163170:
  * maintbot: no maintainer review for SLE15 submissions
  * compare_pkglist: up to Leap 15.0 and SLE15
* Mon Oct  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171002.0087bc6:
  * Initial version of pkglistgen
  * Handle groups files also
  * Exclude missing packages
  * Solve based on explicit package list
  * Implement extra and discard
  * Solve more groups
  * Add options for input and output directories
  * Warn about supplements
  * Add all devel packages
  * Write unsorted packages
  * Don't abort on unresolvable
  * Catch missing arch specific packages
  * Always output all archs - even if empty
  * Remove duplicated packages during merge and autopep
  * Support silents
  * Use project instead of FACTORY
  * Solve the packages one by one instead of a group
  * Output devel packages per module
  * Generic OUTPUT handling
  * Generate errors into group comments
  * Generate development packages into group comments
  * Generate recommends (requires new python-solv)
  * Lock all binaries duplicated between repos - the first one wins
* Mon Oct  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171002.655a959:
  * conf: given default value to main_repo
* Mon Oct  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171002.167e744:
  * conf: given default value to delreq_review
* Mon Oct  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20171002.a306181:
  * virtually accept: virtually accept the delete request
  * tests: fix testsuite for virtually accept
* Thu Sep 28 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170928.3bbeacd:
  * adi_command: do not checking adi staging status if there is no selected_requests
  * Include CLEANUP => 1 during temp directory creation in perl scripts.
* Thu Sep 21 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170920.4011159:
  * osclib/stagingapi: accept_status_comment(): avoid making comments for empty projects.
  * osclib/adi: include force=True when invoking delete_project().
* Wed Sep 20 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170920.0167a82:
  * totest-manager: Adapt zSystems to new productbuilder
* Mon Sep 18 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170918.035c367:
  * Disable ppc64le for now in Tumbleweed stagings
* Sat Sep 16 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170916.af9750d:
  * rm_from_prj: always use the origin project path to set_review()
* Fri Sep 15 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170915.6b1fad5:
  * stagingapi: refactor get_sub_packages() to support adi package
  * stagingapi: rm_from_prj() remove the main package in the last
  * stagingapi: submit_to_prj() create sub-package for adi request
* Thu Sep 14 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170913.92a3a28:
  * osclib/list: only present submit and delete requests in main list.
  * osclib/list: rework change_devel_requests to include set_bugowner.
  * osclib/request_finder: restrict to submit and delete request types.
* Mon Sep 11 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170911.3c1a264:
  * suppkg_rebuild: VMInstall is also valid on build service
* Mon Sep 11 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170911.2c899cf:
  * Remove local config for sle15 - it's remote
* Fri Sep  8 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170908.4077149:
  * Generate minimals with set compression
* Fri Sep  8 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170907.ca3c504:
  * [openqa-maintenance bot] fix accidentaly removed wrong line
  * stagingapi: carry over build state during supersede.
  * leaper: fix iterating through list
* Tue Sep  5 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170905.bd162b9:
  * Schedule incidents earlier
  * Only schedule one setting per target for now
  * add ltss
  * Add comment
  * Refresh incident comment
  * one more
  * Activate sp3
  * Fix variable name
  * Clone flavors
  * move the test loop into review
  * Do not schedule incidents twice
  * Skip kgraft target
  * move variable
  * Fix comments
  * Fix duplicated posts
  * Convert MINIMALS to set type
  * Remove usage of temporary files
* Mon Sep  4 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170904.2bbaa62:
  * totest-manager: Prevent old tests in same build blocking release with "latest=1"
* Mon Sep  4 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170904.c261049:
  * freeze_command: update product version for openSUSE only
* Sat Sep  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170902.bedca4c:
  * osclib/request_splitter: for SLE, fallback to openSUSE:Factory devel projects.
  * osclib/list: remove SUSE:SLE from hide_source now that devel groupings are used.
  * osclib/list: strip openSUSE.org: prefix from source projects to reduce verbosity.
  * Do not use direct flag for images
  * dist/package/spec: include version on osc Requires.
* Fri Sep  1 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170901.7c18d96:
  * Fix typo in bootstrap
* Thu Aug 31 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170831.b6c17fe:
  * osclib/stagingapi: lazy-load nocleanup-packages to allow for placement in remote config.
* Thu Aug 31 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170831.819da53:
  * ReviewBot: downgrade message about skipping duplicate review to debug.
  * ReviewBot: comment_write(): skip posting empty comments extracted from handler.
  * repo_checker: rename package-whitelist to binary-whitelist to be more accurate.
* Thu Aug 31 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170831.266f398:
  * travis: install libxml2-utils which provides xmllint.
* Wed Aug 30 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170830.68da325:
  * osclib/stagingapi: create_adi_project(): add :Staging passthru project.
* Wed Aug 30 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170829.ddb1395:
  * leaper: fix syntax error
  * leaper: avoid comments about unhandled request types
* Tue Aug 29 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170829.7357c5f:
  * SUSE: wants to build test dvds on 'local' workers
* Tue Aug 29 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170829.73b803a:
  * osclib/conf: do not disable remote config for SLE-15.
* Mon Aug 28 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170828.ed70089:
  * totest-manager: follow another live media setup change (no multibuild)
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170825.ca2db71:
  * totest-manager: do not attempt to put/post in --dry mode
  * totest-manager: Follow changes in Tumbleweed for the new live image setup
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170825.4ea3820:
  * dist/package/spec: utilzie %%osc_plugin_dir provided by osc post sr#512849.
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170825.1d5c197:
  * stagingapi: Fix typo in _frozenlinks
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170825.a2eb80c:
  * accept: call accept_other_new() for all projects instead of just openSUSE.
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170824.bf5ae3d:
  * repo_checker: only bother to parse if --post-comments.
  * repo_checker: move result_comment() headers into respective check methods.
  * repo_checker.pl: support multiple directories to check.
  * repo_checker: replace separate ignore methods with new algorithm.
  * osclib/conf: set staging-dvd-archs to empty for SUSE:* projects.
  * stagingapi: provide staging_walk() to cleanly handle :DVD subproject.
  * core: add memoize(session=True) to package_binary_list().
  * repo_checker: rework to handle multiple stagings per group (ie :DVD).
  * cycle: cycles() rename group parameter to staging to better reflect usage.
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170824.2aae21d:
  * repo_checker: delete: explicitly indicate build requirement.
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170824.a0a461f:
  * repo_checker: delete: do not decline instead ignore.
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170824.c0ede24:
  * ReviewBot: comment_write(): place debug_key at the end for consistency.
  * ReviewBot: comment_write(): pull dryrun protected bit out individually.
  * ReviewBot: comment_write(): provide only_replace option.
  * repo_checker: post passed comment only if previous failed comment.
  * commentapi: provide truncate() and apply during add_comment().
  * repo_checker: package_comments(): drop truncation in favor of commentapi.
  * cycle: remove ugly ignore code from _get_builddepinfo_graph().
  * repo_checker.pl: ensure that parser does not bleed over to other sections.
  * repo_checker: use <pre> instead of ``` to avoid html entity escaping.
* Fri Aug 25 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170824.8338287:
  * ReviewBot: simplify logger format.
* Thu Aug 24 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170824.7bbd005:
  * Use configured staging group for adi
* Thu Aug 24 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170824.adeb4c4:
  * Freeze Cmd: Implement freezing adi staging project
* Wed Aug 23 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170823.7502d6a:
  * stagingapi: avoid making an empty package-diff comment.
* Tue Aug 22 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170822.55aeefa:
  * check_source: remove DIFFCOUNT algorithm and instead always add review_team.
  * check_source: rename perl and asciidoc to match name.
* Tue Aug 22 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170822.2873a27:
  * core.owner_fallback(): check if startswith() instead of equal.
* Tue Aug 22 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170822.09b046f:
  * ReviewBot: get_devel_project(): correct error handling to only allow 404.
  * ReviewBot: add_review(): remove left-over print() line.
* Tue Aug 22 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170822.9bd2789:
  * stagingapi: Ensure the links is valid before processing
  * Add amarok to test-2 DVD
  * Remove sw_management_kde pattern from test-2 DVD
* Fri Aug 18 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170818.f230438:
  * dist/ci/Dockerfile: include `dup` before `in` to handle major base changes.
* Fri Aug 18 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170818.bf1662b:
  * ReviewBot: add_review(): raise exception instead of returning boolean.
  * ReviewBot: add_review(): provide allow_duplicate parameter and default of False.
* Fri Aug 18 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170818.54fcc90:
  * FccSubmitter: drop add_review() since never used and handled by other bots.
  * repo_checker: ignore non-existant binaries during lookup.
* Fri Aug 18 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170818.52cce8d:
  * switch to php7 in staging project
  * totest-manager: update Kubic name to openSUSE-Tumbleweed-Kubic
  * Staging DVDs: add x86 pattern to the media
  * suppkg_rebuild: Clean up supportpkg list also
* Mon Aug 14 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170814.8711b45:
  * check_source: change repo_checker default to new OBS username.
* Fri Aug 11 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170811.1cefbfc:
  * update-crawler: handle devel projects
* Tue Aug  8 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170808.c994bc8:
  * update crawler: latest_packages across instances
* Mon Aug  7 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170807.a64d27c:
  * Catch more errors, fixes
  * Fix biarch logic to make --force work
  * Update blacklist and whiteliste
  * Don't use product filter by default
  * Add libjpeg62-turbo to whitelist
  * add openSUSE-EULAs to blacklist
  * warn about linked packages
  * Remove leftover debug statements
  * Refactor getting file list
  * Speed up duplicate binaries check
* Mon Aug  7 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170807.2c08e40:
  * The first steps toward sle15 :)
* Fri Aug  4 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170804.072d1eb:
  * ReviewBot: comment_write(): support package.
  * osclib/core: provide BINARY_REGEX named group pattern and utilize.
  * osclib/core: add package to BinaryParsed tuple.
  * osclib/core: provide package_binary_list() to efficiently obtain binary to package map.
  * repo_checker: package_whitelist() does not need to support group splitting to find product.
  * repo_checker: provide optional parsing of install check output and mapping to package.
  * repo_checker: provide --post-comments option on project_only subcommand.
  * repo_checker: truncate long messages to avoid crashing OBS.
  * ReviewBot: comment_write(): include target in debug message when too similar.
* Wed Aug  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170802.cdde2bf:
  * repo_checker: add whitelist for adoption phase.
  * osclib/cycle: remove extra leading slash.
  * repo_checker: point to repo_checker file instead of old installcheck in project comment.
* Wed Aug  2 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170802.99df9c5:
  * leaper: transition from SLE-12-SP3 and Leap:42.3 to SLE-15 and Leap:15.0.
* Tue Aug  1 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170731.ad89a77:
  * dist/ci/Dockerfile: drop hard-coded mirror now that Tumbleweed issues resolved.
* Tue Aug  1 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170731.a5e3143:
  * repo-checker.pl: replace [^-]* with [^-]+ as it is more accurate.
  * repo-checker.pl: drop old debug lines.
  * Rename repo-checker.pl to repo_checker.pl to be consistent.
  * repo_checker.pl: switch from multi-line regex to single line and full.
  * repo_checker.pl: s/INSTALL/CONFLICTS/ for file pointer for more clarity.
  * repo_checker.pl: rework installcheck parsing like fileconflicts to resolve bugs.
* Fri Jul 28 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170728.1ecdcfd:
  * check_source: add devel review for delete request using MaintenanceChecker logic.
  * stagingapi: provide dashboard_content_{load,save,ensure}() and utilize.
  * repo_checker.pl: allow empty $repodir allowing just a project-wide check.
  * repo_checker: provide project_only subcommand to write result to installcheck.
* Fri Jul 28 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170728.03ba255:
  * Factory test dvd: upgrade to postgresql96
* Thu Jul 27 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170726.b7cff32:
  * osc-cycle: ignore invalid packages
* Thu Jul 27 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170724.4d5ba92:
  * openqa-maintenance: update data for schedule 12sp3 jobs
* Wed Jul 19 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170719.e4c11a6:
  * dist/ci/Dockerfile: add obs-service-set_version based on changes made for Factory.
* Wed Jul 19 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170719.00c88d1:
  * ReviewBot: provide staging_api() from repo_checker.
  * check_source: utilize project config to allow for remote entries.
  * cache: unquote() all URLs before processing to ensure correctness.
* Wed Jul 19 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170719.0a0bec5:
  * devel-project: get(): utilize osc.core.search() and improve xpath loop.
  * devel-project: provide maintainer command to check for relevant groups.
* Tue Jul 18 2017 jberry@suse.com
- Change set_version service to be disabled instead of buildtime.
  The change will appease the source check for Factory.
* Mon Jul 17 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170717.ce00330:
  * dist/spec: add missing osc requires.
  * dist/spec: include %%defattr on all %%files entries.
  * travis: include OBS_EMAIL environment variable when deploying.
  * dist/spec: utilize obs_scm renaming which properly includes version in source.
  * travis: target proper home in openSUSE:Tools for deployment.
  * dist/ci/Dockerfile: include obs-service-{download_files,format_spec_file} for deployment.
  * dist/ci/deploy.obs.sh: include apiurl in general so email is used during service run.
* Mon Jul 17 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170713.262d988:
  * Makefile & disc/spec: include version in installed osc-staging plugin.
  * travis: include list email address in changes entry during deployment.
* Mon Jul 17 2017 jberry@suse.com
- Change _service to rename in obs_scm instead of tar which handles
  rename properly.
- Correct previous change entries email address.
* Fri Jul 14 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170713.0a84043:
  * dist/ci/deploy.obs.sh: remove previous source.
* Fri Jul 14 2017 opensuse-releaseteam@opensuse.org
- Update to version 20170713.bc8cb75:
  * travis: add deployment to OBS package on master branch commit.
* Tue Jul 11 2017 jberry@suse.com
- Initial package.
